@@ -1,7 +1,7 @@
 /*
  * ct_actions.h
  *
- * Copyright 2009-2023
+ * Copyright 2009-2024
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -70,6 +70,7 @@ private:
 private:
     CtMainWin* const _pCtMainWin;
     CtConfig* const _pCtConfig;
+    bool _in_action{false};
 
 private:
     CtExportOptions _export_options;
@@ -114,17 +115,18 @@ public:
     void dialog_preferences();
     void preferences_import();
     void preferences_export();
+    void command_selnode();
     void command_palette();
 
 private:
     // helpers for tree actions
-    void          _node_add(const bool is_duplicate,
-                            const bool add_as_child,
-                            const CtTreeIter* pCtTreeIterFrom = nullptr,
-                            CtMainWin* pWinToCopyFrom = nullptr);
+    void _node_add(const CtDuplicateShared duplicate_shared,
+                   const bool add_as_child,
+                   const CtTreeIter* pCtTreeIterFrom = nullptr,
+                   CtMainWin* pWinToCopyFrom = nullptr);
     Gtk::TreeIter _node_add_with_data(Gtk::TreeIter curr_iter,
                                       CtNodeData& nodeData,
-                                      bool add_as_child,
+                                      const bool add_as_child,
                                       std::shared_ptr<CtNodeState> node_state);
 
 public:
@@ -146,17 +148,22 @@ private:
 
 public:
     // tree actions
-    void node_add()                {
-        _node_add(false/*is_duplicate*/, false/*add_as_child*/);
+    void node_add() {
+        _node_add(CtDuplicateShared::None, false/*add_as_child*/);
     }
-    void node_duplicate()          {
+    void node_duplicate() {
         if (not _is_there_selected_node_or_error()) return;
         CtTreeIter treeIter = _pCtMainWin->curr_tree_iter();
-        _node_add(true/*is_duplicate*/, false/*add_as_child*/, &treeIter, _pCtMainWin);
+        _node_add(CtDuplicateShared::Duplicate, false/*add_as_child*/, &treeIter, _pCtMainWin);
     }
-    void node_child_add()          {
+    void node_make_shared() {
         if (not _is_there_selected_node_or_error()) return;
-        _node_add(false/*is_duplicate*/, true/*add_as_child*/);
+        CtTreeIter treeIter = _pCtMainWin->curr_tree_iter();
+        _node_add(CtDuplicateShared::Shared, false/*add_as_child*/, &treeIter, _pCtMainWin);
+    }
+    void node_child_add() {
+        if (not _is_there_selected_node_or_error()) return;
+        _node_add(CtDuplicateShared::None, true/*add_as_child*/);
     }
     void node_subnodes_duplicate();
     void node_subnodes_copy();
@@ -194,11 +201,12 @@ public:
 private:
     // helpers for find actions
     void _find_init();
-    bool _parse_given_node_content(CtTreeIter node_iter,
-                                   Glib::RefPtr<Glib::Regex> re_pattern,
-                                   bool forward,
-                                   bool first_fromsel,
-                                   bool all_matches);
+    CtMatchType _parse_given_node_content(CtTreeIter node_iter,
+                                          Glib::RefPtr<Glib::Regex> re_pattern,
+                                          bool forward,
+                                          bool first_fromsel,
+                                          bool all_matches,
+                                          CtMatchType thisNodeLastMatchType);
     bool _parse_node_content_iter(const CtTreeIter& tree_iter,
                                   Glib::RefPtr<Gtk::TextBuffer> text_buffer,
                                   Glib::RefPtr<Glib::Regex> re_pattern,
@@ -210,8 +218,8 @@ private:
                                       Glib::RefPtr<Glib::Regex> re_pattern,
                                       const bool all_matches);
     Gtk::TextIter _get_inner_start_iter(Glib::RefPtr<Gtk::TextBuffer> text_buffer,
-                                        bool forward,
-                                        const gint64& node_id);
+                                        const bool forward,
+                                        const bool all_matches);
     bool _is_node_within_time_filter(const CtTreeIter& node_iter);
     Glib::RefPtr<Glib::Regex> _create_re_pattern(Glib::ustring pattern);
     bool _find_pattern(CtTreeIter tree_iter,
@@ -220,20 +228,27 @@ private:
                        Gtk::TextIter start_iter,
                        bool forward,
                        bool all_matches);
-    std::string         _get_line_content(Glib::RefPtr<Gtk::TextBuffer> text_buffer,
-                                          Gtk::TextIter text_iter);
-    std::string         _get_first_line_content(Glib::RefPtr<Gtk::TextBuffer> text_buffer);
-    Glib::ustring       _check_pattern_in_object(Glib::RefPtr<Glib::Regex> pattern,
-                                                 CtAnchoredWidget* obj);
-    std::pair<int, int> _check_pattern_in_object_between(CtTreeIter tree_iter,
-                                                         Glib::RefPtr<Gtk::TextBuffer> text_buffer,
-                                                         Glib::RefPtr<Glib::Regex> pattern,
-                                                         int start_offset,
-                                                         int end_offset,
-                                                         bool forward,
-                                                         std::string& obj_content);
+    bool _check_pattern_in_object(Glib::RefPtr<Glib::Regex> re_pattern,
+                                  CtAnchoredWidget* pAnchWidg,
+                                  CtAnchMatchList& anchMatchList);
+    bool _check_pattern_in_object_between(CtTreeIter tree_iter,
+                                          Glib::RefPtr<Glib::Regex> pattern,
+                                          int start_offset,
+                                          int end_offset,
+                                          const bool forward,
+                                          const bool all_matches,
+                                          CtAnchMatchList& anchMatchList);
     int  _get_num_objs_before_offset(Glib::RefPtr<Gtk::TextBuffer> text_buffer, int max_offset);
     void _update_all_matches_progress();
+public:
+    void find_matches_store_reset();
+    static void find_match_in_obj_focus(const int obj_offset,
+                                        Glib::RefPtr<Gtk::TextBuffer> pTextBuffer,
+                                        const CtTreeIter& tree_iter,
+                                        const CtAnchWidgType anch_type,
+                                        const size_t anch_cell_idx,
+                                        const int anch_offs_start,
+                                        const int anch_offs_end);
 
 public:
     // find actions
@@ -252,6 +267,10 @@ public:
     // helpers for find actions
     void find_again_iter(const bool fromIterativeDialog);
     void find_back_iter(const bool fromIterativeDialog);
+    void find_in_selected_node_ok_clicked();
+    void find_in_multiple_nodes_ok_clicked();
+    void find_replace_in_selected_node();
+    void find_replace_in_multiple_nodes();
 
 private:
     // helper for view actions
@@ -352,6 +371,7 @@ public:
                           const Glib::ustring& image_justification);
     void image_insert_anchor(Gtk::TextIter iter_insert,
                              const Glib::ustring& name,
+                             const CtAnchorExpCollState expCollState,
                              const Glib::ustring& image_justification);
     void image_insert_latex(Gtk::TextIter iter_insert,
                             const Glib::ustring& latex_text,
@@ -399,6 +419,7 @@ private:
                              Gtk::TextIter* iter_bound);
     bool _on_embfiles_sentinel_timeout();
     void _exec_code(const bool is_all);
+    void _link_right_click_pre_action();
 
 public:
     // others actions
@@ -436,6 +457,7 @@ public:
 
     void codebox_cut();
     void codebox_copy();
+    void codebox_copy_content();
     void codebox_delete();
     void codebox_delete_keeping_text();
     void codebox_change_properties();
@@ -471,30 +493,30 @@ public:
 
 private:
     // helper for import actions
-    void _import_from_file(CtImporterInterface* importer, const bool dummy_root = false) noexcept;
-    void _import_from_dir(CtImporterInterface* importer, const std::string& custom_dir) noexcept;
+    void _import_from_file(CtImporterInterface* importer, const bool dummy_root = false);
+    void _import_from_dir(CtImporterInterface* importer, const std::string& custom_dir);
     void _create_imported_nodes(CtImportedNode* imported_nodes, const bool dummy_root = false);
 
 public:
     // import actions
-    void import_node_from_html_file() noexcept;
-    void import_node_from_html_directory() noexcept;
-    void import_node_from_plaintext_file() noexcept;
-    void import_nodes_from_plaintext_directory() noexcept;
-    void import_nodes_from_ct_file() noexcept;
-    void import_nodes_from_ct_folder() noexcept;
-    void import_nodes_from_zim_directory() noexcept;
-    void import_node_from_md_file() noexcept;
-    void import_nodes_from_md_directory() noexcept;
-    void import_nodes_from_gnote_directory() noexcept;
-    void import_nodes_from_tomboy_directory() noexcept;
-    void import_nodes_from_keepnote_directory() noexcept;
-    void import_nodes_from_mempad_file() noexcept;
-    void import_nodes_from_indented_list_file() noexcept;
-    void import_nodes_from_treepad_file() noexcept;
-    void import_nodes_from_leo_file() noexcept;
-    void import_nodes_from_rednotebook_html() noexcept;
-    void import_nodes_from_notecase_html() noexcept;
+    void import_node_from_html_file();
+    void import_node_from_html_directory();
+    void import_node_from_plaintext_file();
+    void import_nodes_from_plaintext_directory();
+    void import_nodes_from_ct_file();
+    void import_nodes_from_ct_folder();
+    void import_nodes_from_zim_directory();
+    void import_node_from_md_file();
+    void import_nodes_from_md_directory();
+    void import_nodes_from_gnote_directory();
+    void import_nodes_from_tomboy_directory();
+    void import_nodes_from_keepnote_directory();
+    void import_nodes_from_mempad_file();
+    void import_nodes_from_indented_list_file();
+    void import_nodes_from_treepad_file();
+    void import_nodes_from_leo_file();
+    void import_nodes_from_rednotebook_html();
+    void import_nodes_from_notecase_html();
 
 private:
     // helper for export actions
