@@ -42,9 +42,13 @@ void CtActions::requested_step_back()
             _pCtMainWin->load_buffer_from_state(step_back, currTreeIter);
         }
     }
-    else if (currTreeIter.get_node_text_buffer()->can_undo()) {
-        currTreeIter.get_node_text_buffer()->undo();
-        _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf);
+    else {
+        Glib::RefPtr<Gtk::TextBuffer> pTextBuffer = currTreeIter.get_node_text_buffer();
+        auto pGtkSourceBuffer = GTK_SOURCE_BUFFER(pTextBuffer->gobj());
+        if (gtk_source_buffer_can_undo(pGtkSourceBuffer)) {
+            gtk_source_buffer_undo(pGtkSourceBuffer);
+            _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf);
+        }
     }
 }
 
@@ -61,9 +65,13 @@ void CtActions::requested_step_ahead()
             _pCtMainWin->load_buffer_from_state(step_ahead, currTreeIter);
         }
     }
-    else if (currTreeIter.get_node_text_buffer()->can_redo()) {
-        currTreeIter.get_node_text_buffer()->redo();
-        _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf);
+    else {
+        Glib::RefPtr<Gtk::TextBuffer> pTextBuffer = currTreeIter.get_node_text_buffer();
+        auto pGtkSourceBuffer = GTK_SOURCE_BUFFER(pTextBuffer->gobj());
+        if (gtk_source_buffer_can_redo(pGtkSourceBuffer)) {
+            gtk_source_buffer_redo(pGtkSourceBuffer);
+            _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf);
+        }
     }
 }
 
@@ -93,7 +101,7 @@ void CtActions::image_insert()
         rPixbuf = Gdk::Pixbuf::create_from_file(filename);
     }
     catch (Glib::Error& error) {
-        spdlog::error("{} {}", __FUNCTION__, error.what());
+        spdlog::error("{} {}", __FUNCTION__, error.what().raw());
     }
     if (rPixbuf)
         _image_edit_dialog(rPixbuf, _curr_buffer()->get_insert()->get_iter(), nullptr/*pIterBound*/);
@@ -155,12 +163,11 @@ void CtActions::table_insert()
     else {
         pCtTable = new CtTableHeavy{_pCtMainWin, tbl_matrix, col_width, charOffset, "", CtTableColWidths{}};
     }
-    Glib::RefPtr<Gsv::Buffer> gsv_buffer = Glib::RefPtr<Gsv::Buffer>::cast_dynamic(_curr_buffer());
-    pCtTable->insertInTextBuffer(gsv_buffer);
+    pCtTable->insertInTextBuffer(_curr_buffer());
 
     _pCtMainWin->get_tree_store().addAnchoredWidgets(_pCtMainWin->curr_tree_iter(),
-        {pCtTable}, &_pCtMainWin->get_text_view());
-    //pCtTable->get_text_view().grab_focus();
+        {pCtTable}, &_pCtMainWin->get_text_view().mm());
+    //pCtTable->get_text_view().mm().grab_focus();
 }
 
 void CtActions::codebox_insert()
@@ -192,13 +199,12 @@ void CtActions::codebox_insert()
                                           _pCtConfig->codeboxWidthPixels,
                                           _pCtConfig->codeboxMatchBra,
                                           _pCtConfig->codeboxLineNum};
-    Glib::RefPtr<Gsv::Buffer> gsv_buffer = Glib::RefPtr<Gsv::Buffer>::cast_dynamic(_curr_buffer());
-    pCtCodebox->insertInTextBuffer(gsv_buffer);
+    pCtCodebox->insertInTextBuffer(_curr_buffer());
 
     _pCtMainWin->get_tree_store().addAnchoredWidgets(_pCtMainWin->curr_tree_iter(),
                                                      {pCtCodebox},
-                                                     &_pCtMainWin->get_text_view());
-    pCtCodebox->get_text_view().grab_focus();
+                                                     &_pCtMainWin->get_text_view().mm());
+    pCtCodebox->get_text_view().mm().grab_focus();
 }
 
 void CtActions::embfile_insert_path(const std::string& filepath)
@@ -228,12 +234,11 @@ void CtActions::embfile_insert_path(const std::string& filepath)
                                                            _curr_buffer()->get_insert()->get_iter().get_offset(),
                                                            "",
                                                            CtImageEmbFile::get_next_unique_id()};
-    Glib::RefPtr<Gsv::Buffer> gsv_buffer = Glib::RefPtr<Gsv::Buffer>::cast_dynamic(_curr_buffer());
-    pAnchoredWidget->insertInTextBuffer(gsv_buffer);
+    pAnchoredWidget->insertInTextBuffer(_curr_buffer());
 
     _pCtMainWin->get_tree_store().addAnchoredWidgets(_pCtMainWin->curr_tree_iter(),
                                                      {pAnchoredWidget},
-                                                     &_pCtMainWin->get_text_view());
+                                                     &_pCtMainWin->get_text_view().mm());
 }
 
 void CtActions::embfile_insert()
@@ -282,54 +287,38 @@ struct TocEntry
 {
     std::string anchor_link;
     std::string text;
-    bool is_node = false;
-    unsigned int depth = 0;
-    unsigned int h_level = 0;
+    bool is_node{false};
+    unsigned int depth{0};
+    unsigned int h_level{0};
     std::list<TocEntry> children;
-    TocEntry(std::string a_link, bool is_n, std::string txt, unsigned int dep, unsigned int h_lvl = 0)
-     : anchor_link(std::move(a_link))
-     , text(std::move(txt))
-     , is_node(is_n)
-     , depth(dep)
-     , h_level(h_lvl)
+    TocEntry(std::string a_link, bool is_node_, std::string txt, unsigned int dep, unsigned int h_lvl = 0)
+     : anchor_link{std::move(a_link)}
+     , text{std::move(txt)}
+     , is_node{is_node_}
+     , depth{dep}
+     , h_level{h_lvl}
     {}
 };
 
-std::optional<Glib::ustring> iter_in_tag(const Gtk::TextIter& iter, const Glib::ustring& tag)
-{
-    for (const auto& iter_tag : iter.get_tags()) {
-        Glib::ustring tag_name;
-        iter_tag->get_property("name", tag_name);
-        //spdlog::debug("TAG: {}", tag_name);
-        if (str::startswith(tag_name, tag)) {
-            return tag_name;
-        }
-    }
-    return std::nullopt;
-}
-
 TocEntry find_toc_entries(CtActions& actions, CtTreeIter& node, unsigned depth)
 {
-    int node_id = node.get_node_id();
-    TocEntry entry{fmt::format("node {}", node_id), true, node.get_node_name(), depth};
-    std::string scale_tag{"scale_"};
+    const int node_id = node.get_node_id();
+    TocEntry entry{fmt::format("node {}", node_id), true/*is_node*/, node.get_node_name(), depth};
+    const std::string scale_tag{"scale_"};
     std::unordered_map<int, int> encountered_headers;
-    Glib::RefPtr<Gsv::Buffer> rTextBuffer = node.get_node_text_buffer();
+    Glib::RefPtr<Gtk::TextBuffer> rTextBuffer = node.get_node_text_buffer();
     if (not rTextBuffer) {
-        throw std::runtime_error(str::format(_("Failed to retrieve the content of the node '%s'"), node.get_node_name()));
+        throw std::runtime_error(str::format(_("Failed to retrieve the content of the node '%s'"), node.get_node_name().raw()));
     }
     Gtk::TextIter text_iter = rTextBuffer->begin();
 
     do {
-        std::optional<Glib::ustring> tag_name = iter_in_tag(text_iter, scale_tag);
+        std::optional<Glib::ustring> tag_name = CtTextIterUtil::iter_get_tag_startingwith(text_iter, scale_tag);
         if (tag_name and not Glib::str_has_suffix(tag_name.value(), CtConst::TAG_PROP_VAL_SMALL)) {
-            auto h_start = tag_name->find(scale_tag) + scale_tag.length() + 1;
-            auto begin = tag_name->begin();
-            std::advance(begin, h_start);
-            Glib::ustring h_level_str{begin, tag_name->end()};
+            const Glib::ustring h_level_str = tag_name.value().substr(scale_tag.length() + 1);
             try {
-                int h_lvl = std::stoi(h_level_str);
-                encountered_headers[h_lvl] += 1;
+                const int h_lvl = std::stoi(h_level_str);
+                ++encountered_headers[h_lvl];
 
                 Gtk::TextIter start_iter{text_iter};
                 Gtk::TextIter end_iter{text_iter};
@@ -342,17 +331,20 @@ TocEntry find_toc_entries(CtActions& actions, CtTreeIter& node, unsigned depth)
                 }
 
                 Glib::ustring txt{start_iter, end_iter};
-                //spdlog::debug("{} - {}", txt, txt.size());
+                spdlog::debug("{} - {}", txt.raw(), txt.size());
 
                 auto mark = rTextBuffer->create_mark(end_iter, false);
 
+                CtAnchorExpCollState expCollState{CtAnchorExpCollState::Expanded};
                 Glib::RefPtr<Gtk::TextChildAnchor> rChildAnchor = end_iter.get_child_anchor();
                 if (rChildAnchor) {
                     CtAnchoredWidget* pCtAnchoredWidget = node.get_anchored_widget(rChildAnchor);
                     if (pCtAnchoredWidget) {
                         auto pCtImageAnchor = dynamic_cast<CtImageAnchor*>(pCtAnchoredWidget);
-                        static Glib::RefPtr<Glib::Regex> rRegExpAnchorName = Glib::Regex::create("h\\d+-\\d+");
-                        if (pCtImageAnchor and rRegExpAnchorName->match(pCtImageAnchor->get_anchor_name())) {
+                        if (pCtImageAnchor and 0 != CtStrUtil::is_header_anchor_name(pCtImageAnchor->get_anchor_name())) {
+                            if (CtAnchorExpCollState::None != pCtImageAnchor->get_exp_coll_state()) {
+                                expCollState = pCtImageAnchor->get_exp_coll_state();
+                            }
                             const int endOffset = end_iter.get_offset();
                             auto iter_bound = end_iter;
                             iter_bound.forward_char();
@@ -362,15 +354,15 @@ TocEntry find_toc_entries(CtActions& actions, CtTreeIter& node, unsigned depth)
                     }
                 }
                 const std::string anchor_txt = fmt::format("h{}-{}", h_lvl, encountered_headers[h_lvl]);
-                actions.image_insert_anchor(end_iter, anchor_txt, "right");
+                actions.image_insert_anchor(end_iter, anchor_txt, expCollState, CtConst::TAG_PROP_VAL_RIGHT);
 
                 text_iter = mark->get_iter();
                 rTextBuffer->delete_mark(mark);
                 //spdlog::debug("INSERT DONE");
-                entry.children.emplace_back(fmt::format("node {} {}", node_id, anchor_txt), false, txt, depth + 1, h_lvl);
+                entry.children.emplace_back(fmt::format("node {} {}", node_id, anchor_txt), false/*is_node*/, txt, depth + 1, h_lvl);
             }
             catch(std::invalid_argument&) {
-                spdlog::error("Could not convert [{}] to an integer", h_level_str);
+                spdlog::error("Could not convert [{}] to an integer", h_level_str.raw());
             }
         }
 
@@ -882,7 +874,7 @@ void CtActions::replace_tabs_with_spaces()
 
     int replaced_tabs{0};
     Gtk::TextIter curr_iter = text_buffer->begin();
-    const int tab_width = proof.text_view->get_tab_width();
+    const int tab_width = gtk_source_view_get_tab_width(GTK_SOURCE_VIEW(proof.text_view->gobj()));
     const Glib::ustring replaceStr = str::repeat(CtConst::CHAR_SPACE, tab_width);
 
     text_buffer->begin_user_action();
@@ -973,11 +965,10 @@ void CtActions::image_insert_latex(Gtk::TextIter iter_insert,
     if (latex_text.empty()) return;
     const int charOffset = iter_insert.get_offset();
     CtAnchoredWidget* pAnchoredWidget = new CtImageLatex{_pCtMainWin, latex_text, charOffset, justification, CtImageEmbFile::get_next_unique_id()};
-    Glib::RefPtr<Gsv::Buffer> gsv_buffer = Glib::RefPtr<Gsv::Buffer>::cast_dynamic(_curr_buffer());
-    pAnchoredWidget->insertInTextBuffer(gsv_buffer);
+    pAnchoredWidget->insertInTextBuffer(_curr_buffer());
     _pCtMainWin->get_tree_store().addAnchoredWidgets(_pCtMainWin->curr_tree_iter(),
                                                      {pAnchoredWidget},
-                                                     &_pCtMainWin->get_text_view());
+                                                     &_pCtMainWin->get_text_view().mm());
 }
 
 // Insert/Edit Image Dialog
@@ -1005,23 +996,24 @@ void CtActions::image_insert_png(Gtk::TextIter iter_insert,
     if (not rPixbuf) return;
     const int charOffset = iter_insert.get_offset();
     CtAnchoredWidget* pAnchoredWidget = new CtImagePng{_pCtMainWin, rPixbuf, link, charOffset, image_justification};
-    Glib::RefPtr<Gsv::Buffer> gsv_buffer = Glib::RefPtr<Gsv::Buffer>::cast_dynamic(_curr_buffer());
-    pAnchoredWidget->insertInTextBuffer(gsv_buffer);
+    pAnchoredWidget->insertInTextBuffer(_curr_buffer());
     _pCtMainWin->get_tree_store().addAnchoredWidgets(_pCtMainWin->curr_tree_iter(),
                                                      {pAnchoredWidget},
-                                                     &_pCtMainWin->get_text_view());
+                                                     &_pCtMainWin->get_text_view().mm());
 }
 
-void CtActions::image_insert_anchor(Gtk::TextIter iter_insert, const Glib::ustring &name, const Glib::ustring &image_justification)
+void CtActions::image_insert_anchor(Gtk::TextIter iter_insert,
+                                    const Glib::ustring& name,
+                                    const CtAnchorExpCollState expCollState,
+                                    const Glib::ustring& image_justification)
 {
-    int charOffset = iter_insert.get_offset();
-    CtAnchoredWidget* pAnchoredWidget = new CtImageAnchor{_pCtMainWin, name, charOffset, image_justification};
-    Glib::RefPtr<Gsv::Buffer> gsv_buffer = Glib::RefPtr<Gsv::Buffer>::cast_dynamic(_curr_buffer());
-    pAnchoredWidget->insertInTextBuffer(gsv_buffer);
+    const int charOffset = iter_insert.get_offset();
+    CtAnchoredWidget* pAnchoredWidget = new CtImageAnchor{_pCtMainWin, name, expCollState, charOffset, image_justification};
+    pAnchoredWidget->insertInTextBuffer(_curr_buffer());
 
     _pCtMainWin->get_tree_store().addAnchoredWidgets(_pCtMainWin->curr_tree_iter(),
                                                      {pAnchoredWidget},
-                                                     &_pCtMainWin->get_text_view());
+                                                     &_pCtMainWin->get_text_view().mm());
 }
 
 // Change the Case of the Selected Text/the Underlying Word"""
