@@ -38,17 +38,27 @@
 #include <vte/vte.h>
 #endif // HAVE_VTE
 
+void CtActions::_link_right_click_pre_action()
+{
+    if (_curr_buffer()->get_has_selection() and _pCtMainWin->hovering_link_iter_offset() >= 0) {
+        Gtk::TextIter target_iter = _curr_buffer()->get_iter_at_offset(_pCtMainWin->hovering_link_iter_offset());
+        if (target_iter) _curr_buffer()->place_cursor(target_iter);
+    }
+}
+
 void CtActions::link_cut()
 {
     if (not _is_curr_node_not_read_only_or_error()) return;
-    if (!_link_check_around_cursor().empty()) {
+    _link_right_click_pre_action();
+    if (not _link_check_around_cursor().empty()) {
         g_signal_emit_by_name(G_OBJECT(_pCtMainWin->get_text_view().gobj()), "cut-clipboard");
     }
 }
 
 void CtActions::link_copy()
 {
-    if (!_link_check_around_cursor().empty()) {
+    _link_right_click_pre_action();
+    if (not _link_check_around_cursor().empty()) {
         g_signal_emit_by_name(G_OBJECT(_pCtMainWin->get_text_view().gobj()), "copy-clipboard");
     }
 }
@@ -56,7 +66,8 @@ void CtActions::link_copy()
 void CtActions::link_dismiss()
 {
     if (not _is_curr_node_not_read_only_or_error()) return;
-    if (!_link_check_around_cursor().empty()) {
+    _link_right_click_pre_action();
+    if (not _link_check_around_cursor().empty()) {
         remove_text_formatting();
     }
 }
@@ -64,9 +75,10 @@ void CtActions::link_dismiss()
 void CtActions::link_delete()
 {
     if (not _is_curr_node_not_read_only_or_error()) return;
-    if (!_link_check_around_cursor().empty()) {
-        _curr_buffer()->erase_selection(true, _pCtMainWin->get_text_view().get_editable());
-        _pCtMainWin->get_text_view().grab_focus();
+    _link_right_click_pre_action();
+    if (not _link_check_around_cursor().empty()) {
+        _curr_buffer()->erase_selection(true, _pCtMainWin->get_text_view().mm().get_editable());
+        _pCtMainWin->get_text_view().mm().grab_focus();
     }
 }
 
@@ -85,9 +97,9 @@ void CtActions::anchor_copy()
 void CtActions::anchor_delete()
 {
     object_set_selection(curr_anchor_anchor);
-    _curr_buffer()->erase_selection(true, _pCtMainWin->get_text_view().get_editable());
+    _curr_buffer()->erase_selection(true, _pCtMainWin->get_text_view().mm().get_editable());
     curr_anchor_anchor = nullptr;
-    _pCtMainWin->get_text_view().grab_focus();
+    _pCtMainWin->get_text_view().mm().grab_focus();
 }
 
 void CtActions::anchor_edit()
@@ -119,9 +131,9 @@ void CtActions::embfile_copy()
 void CtActions::embfile_delete()
 {
     object_set_selection(curr_file_anchor);
-    _curr_buffer()->erase_selection(true, _pCtMainWin->get_text_view().get_editable());
+    _curr_buffer()->erase_selection(true, _pCtMainWin->get_text_view().mm().get_editable());
     curr_file_anchor = nullptr;
-    _pCtMainWin->get_text_view().grab_focus();
+    _pCtMainWin->get_text_view().mm().grab_focus();
 }
 
 void CtActions::embfile_save()
@@ -225,9 +237,9 @@ void CtActions::latex_copy()
 void CtActions::latex_delete()
 {
     object_set_selection(curr_latex_anchor);
-    _curr_buffer()->erase_selection(true, _pCtMainWin->get_text_view().get_editable());
+    _curr_buffer()->erase_selection(true, _pCtMainWin->get_text_view().mm().get_editable());
     curr_latex_anchor = nullptr;
-    _pCtMainWin->get_text_view().grab_focus();
+    _pCtMainWin->get_text_view().mm().grab_focus();
 }
 
 void CtActions::image_save()
@@ -275,9 +287,9 @@ void CtActions::image_copy()
 void CtActions::image_delete()
 {
     object_set_selection(curr_image_anchor);
-    _curr_buffer()->erase_selection(true, _pCtMainWin->get_text_view().get_editable());
+    _curr_buffer()->erase_selection(true, _pCtMainWin->get_text_view().mm().get_editable());
     curr_image_anchor = nullptr;
-    _pCtMainWin->get_text_view().grab_focus();
+    _pCtMainWin->get_text_view().mm().grab_focus();
 }
 
 void CtActions::image_link_edit()
@@ -371,9 +383,10 @@ void CtActions::link_clicked(const Glib::ustring& tag_property_value, bool from_
             return;
         }
         _pCtMainWin->get_tree_view().set_cursor_safe(tree_iter);
-        _pCtMainWin->get_text_view().grab_focus();
-        _pCtMainWin->get_text_view().get_window(Gtk::TEXT_WINDOW_TEXT)->set_cursor(Gdk::Cursor::create(Gdk::XTERM));
-        _pCtMainWin->get_text_view().set_tooltip_text("");
+        auto& textView = _pCtMainWin->get_text_view().mm();
+        textView.grab_focus();
+        textView.get_window(Gtk::TEXT_WINDOW_TEXT)->set_cursor(Gdk::Cursor::create(Gdk::XTERM));
+        textView.set_tooltip_text("");
         if (not link_entry.anch.empty()) {
             current_node_scroll_to_anchor(link_entry.anch);
         }
@@ -404,7 +417,7 @@ void CtActions::current_node_scroll_to_anchor(Glib::ustring anchor_name)
     else {
         Gtk::TextIter iter_anchor = _curr_buffer()->get_iter_at_child_anchor(imageAnchor->getTextChildAnchor());
         _curr_buffer()->place_cursor(iter_anchor);
-        _pCtMainWin->get_text_view().scroll_to(_curr_buffer()->get_insert(), CtTextView::TEXT_SCROLL_MARGIN);
+        _pCtMainWin->get_text_view().mm().scroll_to(_curr_buffer()->get_insert(), CtTextView::TEXT_SCROLL_MARGIN);
     }
 }
 
@@ -425,7 +438,7 @@ void CtActions::codebox_copy()
 void CtActions::codebox_copy_content()
 {
     if (not _is_there_anch_widg_selection_or_error('c')) return;
-    Glib::RefPtr<Gsv::Buffer> pBuffer = curr_codebox_anchor->get_buffer();
+    Glib::RefPtr<Gtk::TextBuffer> pBuffer = curr_codebox_anchor->get_buffer();
     pBuffer->select_range(pBuffer->begin(), pBuffer->end());
     g_signal_emit_by_name(G_OBJECT(curr_codebox_anchor->get_text_view().gobj()), "copy-clipboard");
 }
@@ -434,9 +447,9 @@ void CtActions::codebox_delete()
 {
     if (not _is_there_anch_widg_selection_or_error('c')) return;
     object_set_selection(curr_codebox_anchor);
-    _curr_buffer()->erase_selection(true, _pCtMainWin->get_text_view().get_editable());
+    _curr_buffer()->erase_selection(true, _pCtMainWin->get_text_view().mm().get_editable());
     curr_codebox_anchor = nullptr;
-   _pCtMainWin->get_text_view().grab_focus();
+   _pCtMainWin->get_text_view().mm().grab_focus();
 }
 
 void CtActions::codebox_delete_keeping_text()
@@ -445,9 +458,9 @@ void CtActions::codebox_delete_keeping_text()
     if (not _is_curr_node_not_read_only_or_error()) return;
     Glib::ustring content = curr_codebox_anchor->get_text_content();
     object_set_selection(curr_codebox_anchor);
-    _curr_buffer()->erase_selection(true, _pCtMainWin->get_text_view().get_editable());
+    _curr_buffer()->erase_selection(true, _pCtMainWin->get_text_view().mm().get_editable());
     curr_codebox_anchor = nullptr;
-    _pCtMainWin->get_text_view().grab_focus();
+    _pCtMainWin->get_text_view().mm().grab_focus();
     _curr_buffer()->insert_at_cursor(content);
 }
 
@@ -563,7 +576,7 @@ void CtActions::_exec_code(const bool is_all)
     }
     else {
         const int retVal = std::system(terminal_cmd.c_str());
-        if (retVal != 0) spdlog::error("system({}) returned {}", terminal_cmd, retVal);
+        if (retVal != 0) spdlog::error("system({}) returned {}", terminal_cmd.raw(), retVal);
     }
 }
 
@@ -602,8 +615,8 @@ void CtActions::codebox_increase_width()
     if (_pCtMainWin->curr_tree_iter().get_node_read_only()) return;
     int prevFrameWidth = curr_codebox_anchor->get_frame_width();
     if (curr_codebox_anchor->get_width_in_pixels()) {
-        if (_pCtConfig->codeboxAutoResize and prevFrameWidth < curr_codebox_anchor->get_text_view().get_allocated_width() ) {
-            prevFrameWidth = curr_codebox_anchor->get_text_view().get_allocated_width();
+        if (_pCtConfig->codeboxAutoResize and prevFrameWidth < curr_codebox_anchor->get_text_view().mm().get_allocated_width() ) {
+            prevFrameWidth = curr_codebox_anchor->get_text_view().mm().get_allocated_width();
         }
         curr_codebox_anchor->set_width_height(prevFrameWidth + CtCodebox::CB_WIDTH_HEIGHT_STEP_PIX, 0);
         _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf);
@@ -639,8 +652,8 @@ void CtActions::codebox_increase_height()
     if (not _is_there_anch_widg_selection_or_error('c')) return;
     if (_pCtMainWin->curr_tree_iter().get_node_read_only()) return;
     int prevFrameHeight = curr_codebox_anchor->get_frame_height();
-    if (_pCtConfig->codeboxAutoResize and prevFrameHeight < curr_codebox_anchor->get_text_view().get_allocated_height() ) {
-        prevFrameHeight = curr_codebox_anchor->get_text_view().get_allocated_height();
+    if (_pCtConfig->codeboxAutoResize and prevFrameHeight < curr_codebox_anchor->get_text_view().mm().get_allocated_height() ) {
+        prevFrameHeight = curr_codebox_anchor->get_text_view().mm().get_allocated_height();
     }
     curr_codebox_anchor->set_width_height(0, prevFrameHeight + CtCodebox::CB_WIDTH_HEIGHT_STEP_PIX);
     _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf);
@@ -674,9 +687,9 @@ void CtActions::table_delete()
 {
     if (not _is_there_anch_widg_selection_or_error('t')) return;
     object_set_selection(curr_table_anchor);
-    _curr_buffer()->erase_selection(true/*interactive*/, _pCtMainWin->get_text_view().get_editable());
+    _curr_buffer()->erase_selection(true/*interactive*/, _pCtMainWin->get_text_view().mm().get_editable());
     curr_table_anchor = nullptr;
-    _pCtMainWin->get_text_view().grab_focus();
+    _pCtMainWin->get_text_view().mm().grab_focus();
 }
 
 void CtActions::table_column_add()
@@ -829,10 +842,10 @@ void CtActions::table_edit_properties()
         table_delete();
         auto pCtTable = is_light ? static_cast<CtTableCommon*>(pStateCommon->to_widget_light(_pCtMainWin)) :
             static_cast<CtTableCommon*>(pStateCommon->to_widget_heavy(_pCtMainWin));
-        Glib::RefPtr<Gsv::Buffer> gsv_buffer = Glib::RefPtr<Gsv::Buffer>::cast_dynamic(_curr_buffer());
-        pCtTable->insertInTextBuffer(gsv_buffer);
+        pCtTable->insertInTextBuffer(_curr_buffer());
         _pCtMainWin->get_tree_store().addAnchoredWidgets(_pCtMainWin->curr_tree_iter(),
-            {pCtTable}, &_pCtMainWin->get_text_view());
+                                                         {pCtTable},
+                                                         &_pCtMainWin->get_text_view().mm());
         curr_table_anchor = pCtTable;
     }
     else {
@@ -866,8 +879,13 @@ void CtActions::table_export()
 
 void CtActions::_anchor_edit_dialog(CtImageAnchor* anchor, Gtk::TextIter insert_iter, Gtk::TextIter* iter_bound)
 {
-    Glib::ustring dialog_title = anchor == nullptr ? _("Insert Anchor") :  _("Edit Anchor");
-    Glib::ustring name = anchor == nullptr ? "" : anchor->get_anchor_name();
+    const Glib::ustring dialog_title = anchor == nullptr ? _("Insert Anchor") : _("Edit Anchor");
+    CtAnchorExpCollState expCollState{CtAnchorExpCollState::None};
+    Glib::ustring name;
+    if (anchor) {
+        name = anchor->get_anchor_name();
+        expCollState = anchor->get_exp_coll_state();
+    }
     Glib::ustring ret_anchor_name = CtDialogs::img_n_entry_dialog(*_pCtMainWin, dialog_title, name, "ct_anchor");
     if (ret_anchor_name.empty()) return;
 
@@ -878,7 +896,7 @@ void CtActions::_anchor_edit_dialog(CtImageAnchor* anchor, Gtk::TextIter insert_
         _curr_buffer()->erase(insert_iter, *iter_bound);
         insert_iter = _curr_buffer()->get_iter_at_offset(image_offset);
     }
-    image_insert_anchor(insert_iter, ret_anchor_name, image_justification);
+    image_insert_anchor(insert_iter, ret_anchor_name, expCollState, image_justification);
 }
 
 bool CtActions::_on_embfiles_sentinel_timeout()
@@ -886,7 +904,7 @@ bool CtActions::_on_embfiles_sentinel_timeout()
     for (auto& item : _embfiles_opened) {
         const fs::path& tmp_filepath = item.second.tmp_filepath;
         if (not fs::is_regular_file(tmp_filepath)) {
-            spdlog::debug("embdrop {}", tmp_filepath);
+            spdlog::debug("embdrop {}", tmp_filepath.string());
             _embfiles_opened.erase(item.first);
             break;
         }
