@@ -1,7 +1,7 @@
 /*
  * ct_app.cc
  *
- * Copyright 2009-2022
+ * Copyright 2009-2024
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -31,8 +31,9 @@
 
 CtApp::CtApp(const Glib::ustring application_id_postfix)
  : Gtk::Application{Glib::ustring{"net.giuspen.cherrytree"} + application_id_postfix, Gio::APPLICATION_HANDLES_OPEN}
+ , _pCtConfig{CtConfig::GetCtConfig()}
 {
-    Gsv::init();
+    gtk_source_init();
 
     // action to call from second instance
     // user wanted to create a new window from command line
@@ -49,6 +50,11 @@ CtApp::CtApp(const Glib::ustring application_id_postfix)
     register_application();
 }
 
+CtApp::~CtApp()
+{
+    gtk_source_finalize();
+}
+
 /*static*/Glib::RefPtr<CtApp> CtApp::create(const Glib::ustring application_id_postfix)
 {
     return Glib::RefPtr<CtApp>(new CtApp{application_id_postfix});
@@ -78,8 +84,6 @@ void CtApp::_on_startup()
             spdlog::warn("Could not create config dir {}", config_dir.c_str());
         }
     }
-    _uCtCfg.reset(new CtConfig{});
-    //std::cout << _uCtCfg->specialChars.size() << "\t" << _uCtCfg->specialChars << std::endl;
 
     const fs::path user_dir_icons = config_dir / "icons";
     _rIcontheme = Gtk::IconTheme::get_default();
@@ -92,25 +96,31 @@ void CtApp::_on_startup()
 
     _rTextTagTable = Gtk::TextTagTable::create();
 
-    _rLanguageManager = Gsv::LanguageManager::create();
-    std::vector<std::string> langSearchPath = _rLanguageManager->get_search_path();
+    GtkSourceLanguageManager* pGtkSourceLanguageManager = gtk_source_language_manager_get_default();
+    const gchar * const * pLMSearchPath = gtk_source_language_manager_get_search_path(pGtkSourceLanguageManager);
+    std::vector<gchar const *> langSearchPath;
+    for (auto pPath = pLMSearchPath; *pPath; ++pPath) {
+        langSearchPath.push_back(*pPath);
+    }
     fs::path ctLanguageSpecsData = fs::get_cherrytree_datadir() / CtConfig::ConfigLanguageSpecsDirname;
-    langSearchPath.push_back(ctLanguageSpecsData.string());
+    langSearchPath.push_back(ctLanguageSpecsData.c_str());
     fs::path ctLanguageSpecsConfig = fs::get_cherrytree_config_language_specs_dirpath();
-    langSearchPath.push_back(ctLanguageSpecsConfig.string());
-    _rLanguageManager->set_search_path(langSearchPath);
+    langSearchPath.push_back(ctLanguageSpecsConfig.c_str());
+    langSearchPath.push_back(nullptr);
+    /* At the moment this function can be called only before the language files are loaded for the first time.
+       In practice to set a custom search path for a GtkSourceLanguageManager, you have to call this function right after creating it. */
+    _pGtkSourceLanguageManager = gtk_source_language_manager_new();
+    gtk_source_language_manager_set_search_path(_pGtkSourceLanguageManager, (gchar **)langSearchPath.data());
 
-    _rStyleSchemeManager = Gsv::StyleSchemeManager::create();
-    std::vector<std::string> styleSearchPath = _rStyleSchemeManager->get_search_path();
+    GtkSourceStyleSchemeManager* pGtkSourceStyleSchemeManager = gtk_source_style_scheme_manager_get_default();
     fs::path ctStylesData = fs::get_cherrytree_datadir() / CtConfig::ConfigStylesDirname;
-    styleSearchPath.push_back(ctStylesData.string());
+    gtk_source_style_scheme_manager_append_search_path(pGtkSourceStyleSchemeManager, ctStylesData.c_str());
     fs::path ctStylesConfig = fs::get_cherrytree_config_styles_dirpath();
-    styleSearchPath.push_back(ctStylesConfig.string());
-    _rStyleSchemeManager->set_search_path(styleSearchPath);
+    gtk_source_style_scheme_manager_append_search_path(pGtkSourceStyleSchemeManager, ctStylesConfig.c_str());
 
     _rCssProvider = Gtk::CssProvider::create();
 
-    _uCtStatusIcon.reset(new CtStatusIcon{*this, _uCtCfg.get()});
+    _uCtStatusIcon.reset(new CtStatusIcon{*this, _pCtConfig});
 
     if (not _no_gui) {
         _pCtApp = this;
@@ -131,8 +141,8 @@ void CtApp::on_activate()
     if (get_windows().size() == 0) {
         // start of main instance
         CtMainWin* pAppWindow = _create_window();
-        if (CtApp::_uCtCfg->reloadDocLast && not CtApp::_uCtCfg->recentDocsFilepaths.empty()) {
-            Glib::RefPtr<Gio::File> r_file = Gio::File::create_for_path(CtApp::_uCtCfg->recentDocsFilepaths.front().string());
+        if (_pCtConfig->reloadDocLast && not _pCtConfig->recentDocsFilepaths.empty()) {
+            Glib::RefPtr<Gio::File> r_file = Gio::File::create_for_path(_pCtConfig->recentDocsFilepaths.front().string());
             if (r_file->query_exists()) {
                 const std::string canonicalPath = fs::canonical(r_file->get_path()).string();
                 if (not pAppWindow->start_on_systray_is_active()) {
@@ -145,13 +155,13 @@ void CtApp::on_activate()
                 }
             }
             else {
-                const fs::path last_doc_path{CtApp::_uCtCfg->recentDocsFilepaths.front()};
-                spdlog::info("{} Last doc not found: {}", __FUNCTION__, last_doc_path);
-                CtApp::_uCtCfg->recentDocsFilepaths.move_or_push_back(last_doc_path);
+                const fs::path last_doc_path{_pCtConfig->recentDocsFilepaths.front()};
+                spdlog::info("{} Last doc not found: {}", __FUNCTION__, last_doc_path.string());
+                _pCtConfig->recentDocsFilepaths.move_or_push_back(last_doc_path);
                 pAppWindow->menu_set_items_recent_documents();
             }
         }
-        if (CtApp::_uCtCfg->checkVersion) {
+        if (_pCtConfig->checkVersion) {
             pAppWindow->get_ct_actions()->check_for_newer_version();
         }
     }
@@ -236,7 +246,7 @@ void CtApp::on_open(const Gio::Application::type_vec_files& files, const Glib::u
             }
             if (get_windows().size() == 1) {
                 // start of main instance
-                if (CtApp::_uCtCfg->checkVersion) {
+                if (_pCtConfig->checkVersion) {
                     pAppWindow->get_ct_actions()->check_for_newer_version();
                 }
             }
@@ -262,13 +272,12 @@ void CtApp::on_window_removed(Gtk::Window* window)
 CtMainWin* CtApp::_create_window(const bool no_gui)
 {
     CtMainWin* pCtMainWin = new CtMainWin{no_gui,
-                                          _uCtCfg.get(),
+                                          _pCtConfig,
                                           _uCtTmp.get(),
                                           _rIcontheme.get(),
                                           _rTextTagTable,
                                           _rCssProvider,
-                                          _rLanguageManager.get(),
-                                          _rStyleSchemeManager.get(),
+                                          _pGtkSourceLanguageManager,
                                           _uCtStatusIcon.get()};
     add_window(*pCtMainWin);
 
@@ -334,12 +343,12 @@ bool CtApp::_quit_or_hide_window(CtMainWin* pCtMainWin, const bool from_delete,
 
     if (not _no_gui) {
         pCtMainWin->config_update_data_from_curr_status();
-        _uCtCfg->write_to_file();
+        _pCtConfig->write_to_file();
     }
 
     if (not fromKillCallback) {
-        _uCtCfg->move_from_tmp();
-        if (_uCtCfg->systrayOn and not pCtMainWin->force_exit()) {
+        _pCtConfig->move_from_tmp();
+        if (_pCtConfig->systrayOn and not pCtMainWin->force_exit()) {
             pCtMainWin->save_position();
             pCtMainWin->set_visible(false);
             return false; // stop deleting window
