@@ -1,7 +1,7 @@
 /*
  * ct_app.h
  *
- * Copyright 2009-2022
+ * Copyright 2009-2024
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -37,6 +37,7 @@ class CtApp : public Gtk::Application
 {
 protected:
     CtApp(const Glib::ustring application_id_postfix = Glib::ustring{});
+    ~CtApp() override;
 
 public:
     static Glib::RefPtr<CtApp> create(const Glib::ustring application_id_postfix = Glib::ustring{});
@@ -44,13 +45,12 @@ public:
     void                       systray_show_hide_windows();
 
 protected:
-    std::unique_ptr<CtConfig> _uCtCfg;
+    CtConfig* const _pCtConfig;
     std::unique_ptr<CtTmp> _uCtTmp;
     Glib::RefPtr<Gtk::IconTheme> _rIcontheme;
     Glib::RefPtr<Gtk::TextTagTable> _rTextTagTable;
     Glib::RefPtr<Gtk::CssProvider> _rCssProvider;
-    Glib::RefPtr<Gsv::LanguageManager> _rLanguageManager;
-    Glib::RefPtr<Gsv::StyleSchemeManager> _rStyleSchemeManager;
+    GtkSourceLanguageManager* _pGtkSourceLanguageManager{nullptr};
     std::unique_ptr<CtStatusIcon> _uCtStatusIcon;
 
 protected:
