@@ -1,7 +1,7 @@
 /*
  * ct_clipboard.cc
  *
- * Copyright 2009-2023
+ * Copyright 2009-2024
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -223,7 +223,7 @@ void CtClipboard::table_row_paste(CtTableCommon* pTable)
     std::vector<Glib::ustring> targets = Gtk::Clipboard::get()->wait_for_targets();
     if (vec::exists(targets, CtConst::TARGET_CTD_TABLE)) {
         auto win = _pCtMainWin;
-        Gtk::TextView* view = &_pCtMainWin->get_text_view();
+        Gtk::TextView* view = &_pCtMainWin->get_text_view().mm();
         auto received_table = [win, view, pTable](const Gtk::SelectionData& s) {
             CtClipboard{win}.on_received_to_table(s, view, false, pTable);
         };
@@ -236,7 +236,7 @@ void CtClipboard::node_link_to_clipboard(CtTreeIter node)
     CtClipboardData* clip_data = new CtClipboardData{};
     std::string tml = R"XML(<?xml version="1.0" encoding="UTF-8"?><root><slot><rich_text link="node {}">{}</rich_text></slot></root>)XML";
     clip_data->rich_text = fmt::format(tml, node.get_node_id(), str::xml_escape(node.get_node_name()));
-    clip_data->plain_text = "node: " + node.get_node_name();
+    clip_data->plain_text = fmt::format("{} - {}", node.get_cherrytree_filepath(), CtMiscUtil::get_node_hierarchical_name(node, " / ", false/*for_filename*/).c_str());
 
     _set_clipboard_data({CtConst::TARGET_CTD_RICH_TEXT, CtConst::TARGET_CTD_PLAIN_TEXT}, clip_data);
 }
@@ -246,7 +246,7 @@ void CtClipboard::anchor_link_to_clipboard(CtTreeIter node, const Glib::ustring&
     CtClipboardData* clip_data = new CtClipboardData{};
     std::string tml = R"XML(<?xml version="1.0" encoding="UTF-8"?><root><slot><rich_text link="node {} {}">{}</rich_text></slot></root>)XML";
     clip_data->rich_text = fmt::format(tml, node.get_node_id(), str::xml_escape(anchor_name), str::xml_escape(anchor_name));
-    clip_data->plain_text = "anchor: " + anchor_name;
+    clip_data->plain_text = fmt::format("{} - {} - {}", node.get_cherrytree_filepath(), CtMiscUtil::get_node_hierarchical_name(node, " / ", false/*for_filename*/).c_str(), anchor_name.raw());
 
     _set_clipboard_data({CtConst::TARGET_CTD_RICH_TEXT, CtConst::TARGET_CTD_PLAIN_TEXT}, clip_data);
 }
@@ -311,10 +311,9 @@ void CtClipboard::from_xml_string_to_buffer(Glib::RefPtr<Gtk::TextBuffer> text_b
         if (slot_node->get_name() != "slot")
             continue;
         for (xmlpp::Node* child_node : slot_node->get_children()) {
-            Glib::RefPtr<Gsv::Buffer> gsv_buffer = Glib::RefPtr<Gsv::Buffer>::cast_dynamic(text_buffer);
             Gtk::TextIter insert_iter = text_buffer->get_insert()->get_iter();
             CtStorageXmlHelper{_pCtMainWin}.get_text_buffer_one_slot_from_xml(
-                gsv_buffer,
+                text_buffer,
                 child_node,
                 widgets,
                 &insert_iter,
@@ -323,10 +322,9 @@ void CtClipboard::from_xml_string_to_buffer(Glib::RefPtr<Gtk::TextBuffer> text_b
         }
     }
     if (not widgets.empty()) {
-        _pCtMainWin->get_tree_store().addAnchoredWidgets(
-                    _pCtMainWin->curr_tree_iter(),
-                    widgets,
-                    &_pCtMainWin->get_text_view());
+        _pCtMainWin->get_tree_store().addAnchoredWidgets(_pCtMainWin->curr_tree_iter(),
+                                                         widgets,
+                                                         &_pCtMainWin->get_text_view().mm());
         if (pPasteHadWidgets) {
             *pPasteHadWidgets = true;
         }
@@ -518,8 +516,9 @@ void CtClipboard::on_received_to_plain_text(const Gtk::SelectionData& selection_
                 Gtk::TextIter iter_sel_start = curr_buffer->get_iter_at_offset(start_offset + offset.first);
                 Gtk::TextIter iter_sel_end = curr_buffer->get_iter_at_offset(start_offset + offset.second);
                 Glib::ustring link_url = iter_sel_start.get_text(iter_sel_end);
-                if (not str::startswith(link_url, "htt") and not str::startswith(link_url, "ftp"))
+                if (not str::startswith(link_url, "htt") and not str::startswith(link_url, "ftp") and not str::startswith_url(link_url.c_str())) {
                     link_url = "http://" + link_url;
+                }
                 Glib::ustring property_value = "webs " + link_url;
                 curr_buffer->apply_tag_by_name(_pCtMainWin->get_text_tag_name_exist_or_create(CtConst::TAG_LINK, property_value),
                                                iter_sel_start, iter_sel_end);
@@ -645,20 +644,18 @@ void CtClipboard::on_received_to_table(const Gtk::SelectionData& selection_data,
     }
     else {
         std::list<CtAnchoredWidget*> widgets;
-        Glib::RefPtr<Gsv::Buffer> gsv_buffer = Glib::RefPtr<Gsv::Buffer>::cast_dynamic(pTextView->get_buffer());
         Gtk::TextIter insert_iter = pTextView->get_buffer()->get_insert()->get_iter();
         CtStorageXmlHelper{_pCtMainWin}.get_text_buffer_one_slot_from_xml(
-            gsv_buffer,
+            pTextView->get_buffer(),
             parser.get_document()->get_root_node()->get_first_child("table"),
             widgets,
             &insert_iter,
             insert_iter.get_offset(),
             "");
         if (not widgets.empty()) {
-            _pCtMainWin->get_tree_store().addAnchoredWidgets(
-                _pCtMainWin->curr_tree_iter(),
-                widgets,
-                &_pCtMainWin->get_text_view());
+            _pCtMainWin->get_tree_store().addAnchoredWidgets(_pCtMainWin->curr_tree_iter(),
+                                                             widgets,
+                                                             &_pCtMainWin->get_text_view().mm());
             _pCtMainWin->get_state_machine().update_state();
         }
 
@@ -756,7 +753,7 @@ void CtClipboard::on_received_to_uri_list(const Gtk::SelectionData& selection_da
                 property_value = "webs " + element;
             }
             else if (str::startswith(element, "file://")) {
-                Glib::ustring file_path = element.substr(7);
+                std::string file_path = element.substr(7);
                 file_path = str::replace(file_path, "%20", CtConst::CHAR_SPACE);
                 g_autofree gchar* mimetype = g_content_type_guess(file_path.c_str(), nullptr, 0, nullptr);
                 if (mimetype and str::startswith(mimetype, "image/") and Glib::file_test(file_path, Glib::FILE_TEST_IS_REGULAR)) {
@@ -794,7 +791,7 @@ void CtClipboard::on_received_to_uri_list(const Gtk::SelectionData& selection_da
                     _pCtMainWin->get_ct_actions()->embfile_insert_path(element);
                 }
                 else {
-                    spdlog::debug("'{}' not dir or file", element);
+                    spdlog::debug("'{}' not dir or file", element.raw());
                 }
             }
             if (not property_value.empty()) {
@@ -883,10 +880,10 @@ void CtClipboard::_yaml_to_codebox(const Glib::ustring& yaml_text, Gtk::TextView
         _xml_to_codebox(xml_doc.write_to_string(), pTextView);
     }
     catch (std::exception& e) {
-        spdlog::error("_yaml_to_codebox exception: {}\n{}", e.what(), yaml_text);
+        spdlog::error("_yaml_to_codebox exception: {}\n{}", e.what(), yaml_text.raw());
     }
     catch (...) {
-        spdlog::error("_yaml_to_codebox unknown exception\n{}", yaml_text);
+        spdlog::error("_yaml_to_codebox unknown exception\n{}", yaml_text.raw());
     }
 }
 
@@ -902,13 +899,18 @@ void CtClipboard::_xml_to_codebox(const Glib::ustring &xml_text, Gtk::TextView*
     }
 
     std::list<CtAnchoredWidget*> widgets;
-    Glib::RefPtr<Gsv::Buffer> gsv_buffer = Glib::RefPtr<Gsv::Buffer>::cast_dynamic(pTextView->get_buffer());
     Gtk::TextIter insert_iter = pTextView->get_buffer()->get_insert()->get_iter();
-    CtStorageXmlHelper{_pCtMainWin}.get_text_buffer_one_slot_from_xml(gsv_buffer, parser.get_document()->get_root_node()->get_first_child("codebox"), widgets, &insert_iter, insert_iter.get_offset(), "");
+    CtStorageXmlHelper{_pCtMainWin}.get_text_buffer_one_slot_from_xml(
+        pTextView->get_buffer(),
+        parser.get_document()->get_root_node()->get_first_child("codebox"),
+        widgets,
+        &insert_iter,
+        insert_iter.get_offset(),
+        "");
     if (not widgets.empty()) {
-        _pCtMainWin->get_tree_store().addAnchoredWidgets(
-                    _pCtMainWin->curr_tree_iter(),
-                    widgets, &_pCtMainWin->get_text_view());
+        _pCtMainWin->get_tree_store().addAnchoredWidgets(_pCtMainWin->curr_tree_iter(),
+                                                         widgets,
+                                                         &_pCtMainWin->get_text_view().mm());
         _pCtMainWin->get_state_machine().update_state();
     }
     pTextView->scroll_to(pTextView->get_buffer()->get_insert());
