@@ -37,6 +37,7 @@ const fs::path CtConfig::ConfigStylesDirname{"styles"};
 const fs::path CtConfig::ConfigIconsDirname{"icons"};
 const fs::path CtConfig::UserStyleTemplate{"user-style.xml"};
 
+/* This is the core instance which is unique and lives with the app */
 CtConfig::CtConfig()
  : _configFilepath{fs::get_cherrytree_config_filepath()}
  , _configFilepathTmp{_configFilepath.string() + ".tmp"}
@@ -45,17 +46,30 @@ CtConfig::CtConfig()
     _ensure_user_styles_exist();
 }
 
+/* This is a temporary instance (used for e.g. import) */
 CtConfig::CtConfig(const std::string filepath)
  : _configFilepath{filepath}
 {
     _initLoadFromFileOk = _load_from_file();
 }
 
+/*static*/CtConfig* CtConfig::_pCtConfig{nullptr};
+/*static*/std::mutex CtConfig::_getInstanceMutex;
+
+/*static*/CtConfig* CtConfig::GetCtConfig()
+{
+    std::lock_guard<std::mutex> lock(_getInstanceMutex);
+    if (not _pCtConfig) {
+        _pCtConfig = new CtConfig{};
+    }
+    return _pCtConfig;
+}
+
 void CtConfig::move_from_tmp()
 {
     if (not _configFilepathTmp.string().empty() and fs::exists(_configFilepathTmp)) {
         if (not fs::move_file(_configFilepathTmp, _configFilepath)) {
-            spdlog::error("{} -> {}", _configFilepathTmp, _configFilepath);
+            spdlog::error("{} -> {}", _configFilepathTmp.string(), _configFilepath.string());
         }
     }
 }
@@ -78,15 +92,15 @@ bool CtConfig::_load_from_file()
             _uKeyFile->load_from_file(_configFilepath.string());
         }
         catch (Glib::Error& error) {
-            spdlog::error("CtConfig {}: {}", _configFilepath, error.what());
+            spdlog::error("CtConfig {}: {}", _configFilepath.string(), error.what().raw());
             return false;
         }
         _populate_data_from_keyfile();
         _uKeyFile.reset(nullptr);
-        spdlog::debug("{} parsed", _configFilepath);
+        spdlog::debug("{} parsed", _configFilepath.string());
         return true;
     }
-    spdlog::warn("{} missing", _configFilepath);
+    spdlog::warn("{} missing", _configFilepath.string());
     return false;
 }
 
@@ -407,6 +421,12 @@ void CtConfig::_populate_keyfile_from_data()
     _uKeyFile->set_string(_currentGroup, "custom_backup_dir", customBackupDir);
     _uKeyFile->set_integer(_currentGroup, "limit_undoable_steps", limitUndoableSteps);
 
+    // [proxy]
+    _currentGroup = "proxy";
+    _uKeyFile->set_string(_currentGroup, "proxy_urlcolonport", proxyUrlColonPort);
+    _uKeyFile->set_string(_currentGroup, "proxy_username", proxyUsername);
+    _uKeyFile->set_string(_currentGroup, "proxy_password", proxyPassword);
+
     // [keyboard]
     _currentGroup = "keyboard";
     _populate_current_group_from_map(customKbShortcuts);
@@ -742,6 +762,12 @@ void CtConfig::_populate_data_from_keyfile()
     _populate_string_from_keyfile("custom_backup_dir", &customBackupDir);
     _populate_int_from_keyfile("limit_undoable_steps", &limitUndoableSteps);
 
+    // [proxy]
+    _currentGroup = "proxy";
+    _populate_string_from_keyfile("proxy_urlcolonport", &proxyUrlColonPort);
+    _populate_string_from_keyfile("proxy_username", &proxyUsername);
+    _populate_string_from_keyfile("proxy_password", &proxyPassword);
+
     // [keyboard]
     _currentGroup = "keyboard";
     _populate_map_from_current_group(&customKbShortcuts);
