@@ -33,8 +33,8 @@
 class CtConfig
 {
 public:
-    CtConfig();
-    CtConfig(const std::string filepath);
+    static CtConfig* GetCtConfig(); /* This is the core instance which is unique and lives with the app */
+    CtConfig(const std::string filepath); /* This is a temporary instance (used for e.g. import) */
 
     static const fs::path ConfigFilename;
     static const fs::path PrintPageSetupFilename;
@@ -119,7 +119,7 @@ public:
     int                                         textMarginLeft{7};
     int                                         textMarginRight{7};
     int                                         tabsWidth{4};
-    int                                         anchorSize{16};
+    int                                         anchorSize{20};
     int                                         latexSizeDpi{140};
     int                                         embfileIconSize{48};
     bool                                        embfileShowFileName{true};
@@ -194,11 +194,18 @@ public:
 
     // [fonts]
     Glib::ustring                               rtFont{CtConst::FONT_RT_DEFAULT};
+    int                                         rtResetFontSize{0};
     Glib::ustring                               ptFont{CtConst::FONT_PT_DEFAULT};
+    int                                         ptResetFontSize{0};
     Glib::ustring                               treeFont{CtConst::FONT_TREE_DEFAULT};
+    int                                         treeResetFontSize{0};
     Glib::ustring                               codeFont{CtConst::FONT_CODE_DEFAULT};
+    int                                         codeResetFontSize{0};
     Glib::ustring                               vteFont{CtConst::FONT_VTE_DEFAULT};
     Glib::ustring                               fallbackFontFamily{"Sans"};
+    bool                                        msDedicatedFont{false};
+    Glib::ustring                               monospaceFont{CtConst::FONT_MS_DEFAULT};
+    int                                         msResetFontSize{0};
 
     // [colors]
     std::string                                 ttDefFg{CtConst::TREE_TEXT_LIGHT_FG};
@@ -207,8 +214,6 @@ public:
     std::string                                 ttSelBg{CtConst::TREE_TEXT_SEL_BG};
     std::string                                 monospaceFg{CtConst::DEFAULT_MONOSPACE_FG};
     std::string                                 monospaceBg;
-    bool                                        msDedicatedFont{false};
-    Glib::ustring                               monospaceFont{CtConst::FONT_MS_DEFAULT};
     CtScalableTag                               scalableH1{CtConst::SCALABLE_H1_DEFAULT};
     CtScalableTag                               scalableH2{CtConst::SCALABLE_H2_DEFAULT};
     CtScalableTag                               scalableH3{CtConst::SCALABLE_H3_DEFAULT};
@@ -253,6 +258,11 @@ public:
     std::string                                 customBackupDir{""};
     int                                         limitUndoableSteps{10};
 
+    // [proxy]
+    std::string                                 proxyUrlColonPort;
+    std::string                                 proxyUsername;
+    std::string                                 proxyPassword;
+
     // [keyboard]
     std::map<std::string, std::string>          customKbShortcuts;
 
@@ -271,6 +281,8 @@ public:
                                                               &scalableSmall};
 
 protected:
+    CtConfig(); /* This is the core instance which is unique and lives with the app */
+
     template<class String> bool _populate_string_from_keyfile(std::string key, String* pTarget) {
         bool gotIt{false};
         if (_uKeyFile->has_group(_currentGroup) && _uKeyFile->has_key(_currentGroup, key)) {
@@ -296,6 +308,9 @@ protected:
     bool _load_from_file();
     void _ensure_user_styles_exist();
 
+    static CtConfig* _pCtConfig;
+    static std::mutex _getInstanceMutex;
+
     static const size_t _maxTempKeySize{20};
 
     gchar _tempKey[_maxTempKeySize];
