@@ -240,7 +240,7 @@ void CtDialogs::dialog_search(CtMainWin* pCtMainWin,
     search_entry->grab_focus();
 
     reg_exp_help_button->signal_clicked().connect([](){
-        fs::open_weblink("https://developer-old.gnome.org/glib/stable/glib-regex-syntax.html");
+        fs::open_weblink("https://www.geany.org/manual/gtk/glib/glib-regex-syntax.html");
     });
 
     auto press_enter = [button_ok](GdkEventKey* pEventKey){
@@ -526,7 +526,7 @@ void CtDialogs::match_dialog(const std::string& str_find,
     pButtonNext->set_image_position(Gtk::PositionType::POS_RIGHT);
     CtMenuAction* pAction = pCtMainWin->get_ct_menu().find_action("toggle_show_allmatches_dlg");
     Glib::ustring label = CtStrUtil::get_accelerator_label(pAction->get_shortcut(pCtMainWin->get_ct_config()));
-    Gtk::Button* pButtonHide = pMatchesDialog->add_button(str::format(_("Hide (Restore with '%s')"), label), Gtk::RESPONSE_CLOSE);
+    Gtk::Button* pButtonHide = pMatchesDialog->add_button(str::format(_("Hide (Restore with '%s')"), label.raw()), Gtk::RESPONSE_CLOSE);
     pButtonHide->set_image_from_icon_name("ct_close", Gtk::ICON_SIZE_BUTTON);
 
     rModel->load_current_page();
@@ -583,9 +583,8 @@ void CtDialogs::match_dialog(const std::string& str_find,
 
         const int start_offset = list_iter->get_value(s_state.match_store->columns.start_offset);
         const int end_offset = list_iter->get_value(s_state.match_store->columns.end_offset);
-        rCurrBuffer->select_range(rCurrBuffer->get_iter_at_offset(start_offset),
-                                  rCurrBuffer->get_iter_at_offset(end_offset));
-        ct_text_view.scroll_to(rCurrBuffer->get_insert(), CtTextView::TEXT_SCROLL_MARGIN);
+        ct_text_view.set_selection_at_offset_n_delta(start_offset, end_offset - start_offset, rCurrBuffer);
+        ct_text_view.mm().scroll_to(rCurrBuffer->get_insert(), CtTextView::TEXT_SCROLL_MARGIN);
 
         const CtAnchWidgType anch_type = list_iter->get_value(s_state.match_store->columns.anch_type);
         //spdlog::debug("anch_type={}", static_cast<int>(anch_type));
