@@ -1,7 +1,7 @@
 /*
  * ct_export2pdf.h
  *
- * Copyright 2009-2022
+ * Copyright 2009-2024
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -95,7 +95,7 @@ class CtExport2Pango
 public:
     CtExport2Pango(CtMainWin* pCtMainWin);
 
-    Glib::ustring pango_get_from_code_buffer(Glib::RefPtr<Gsv::Buffer> code_buffer,
+    Glib::ustring pango_get_from_code_buffer(Glib::RefPtr<Gtk::TextBuffer> code_buffer,
                                              int sel_start,
                                              int sel_end,
                                              const std::string& syntax_highlighting);
