@@ -1,7 +1,7 @@
 /*
   ct_filesystem.cc
  *
- * Copyright 2009-2023
+ * Copyright 2009-2024
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -22,6 +22,7 @@
  */
 
 #include <glibmm/miscutils.h>
+#include <giomm/file.h>
 #include <glib/gstdio.h>
 #include <curl/curl.h>
 #include <system_error>
@@ -98,24 +99,39 @@ bool alter_PATH_env_var()
     }
     return false;
 }
-#else // !_WIN32
+#endif /* _WIN32 */
+
 const char* get_latex_dvipng_console_bin_prefix()
 {
     auto _get_latex_dvipng_console_bin_prefix = []()->const char*{
+#if defined(_WIN32)
+        if (not _mingw64Dir.empty()) {
+            const fs::path binDir = _mingw64Dir / "bin";
+            const fs::path latexBin = binDir / "latex.exe";
+            const fs::path dvipngBin = binDir / "dvipng.exe";
+            if (fs::is_regular_file(latexBin) and fs::is_regular_file(dvipngBin)) {
+                spdlog::debug("found latex and dvipng in {}", binDir.c_str());
+                return g_strdup(binDir.c_str());
+            }
+            spdlog::debug("?? NOT FOUND latex and dvipng in {}", binDir.c_str());
+        }
+#else /* !_WIN32 */
         const fs::path tinytex_bin_x86_64_linux = _exePath.parent_path() / "x86_64-linux";
         if (fs::is_directory(tinytex_bin_x86_64_linux)) {
             const fs::path tinytex_latex = tinytex_bin_x86_64_linux / "latex";
             const fs::path tinytex_dvipng = tinytex_bin_x86_64_linux / "dvipng";
             if (fs::is_regular_file(tinytex_latex) and fs::is_regular_file(tinytex_dvipng)) {
+                spdlog::debug("found latex and dvipng in {}", tinytex_bin_x86_64_linux.c_str());
                 return g_strdup_printf("cd %s && ./", tinytex_bin_x86_64_linux.c_str());
             }
+            spdlog::debug("?? NOT FOUND latex and dvipng in {}", tinytex_bin_x86_64_linux.c_str());
         }
+#endif /* !_WIN32 */
         return g_strdup("");
     };
     static const char* latex_dvipng_console_bin_prefix = _get_latex_dvipng_console_bin_prefix();
     return latex_dvipng_console_bin_prefix;
 }
-#endif // !_WIN32
 
 void register_exe_path_detect_if_portable(const char* exe_path)
 {
@@ -148,13 +164,13 @@ bool remove(const fs::path& path2rm)
 {
     if (fs::is_directory(path2rm)) {
         if (g_rmdir(path2rm.c_str()) != 0) {
-            spdlog::error("fs::remove: g_rmdir failed to remove {}", path2rm);
+            spdlog::error("fs::remove: g_rmdir failed to remove {}", path2rm.string());
             return false;
         }
     }
     else if (fs::exists(path2rm)) {
         if (::g_remove(path2rm.c_str()) != 0) {
-            spdlog::error("fs::remove: g_remove failed to remove {}", path2rm);
+            spdlog::error("fs::remove: g_remove failed to remove {}", path2rm.string());
             return false;
         }
     }
@@ -187,7 +203,7 @@ bool copy_file(const path& from, const path& to)
         return rFileFrom->copy(rFileTo, Gio::FILE_COPY_OVERWRITE);
     }
     catch (Gio::Error& error) {
-        spdlog::debug("fs::copy_file, error: {}, from: {}, to: {}", error.what(), from.string(), to.string());
+        spdlog::debug("fs::copy_file, error: {}, from: {}, to: {}", error.what().raw(), from.string(), to.string());
         return false;
     }
 }
@@ -234,13 +250,13 @@ time_t getmtime(const path& p)
 std::uintmax_t file_size(const path& p)
 {
     if (fs::is_directory(p)) {
-        spdlog::error("fs::file_size: path is a directory, {}", p);
+        spdlog::error("fs::file_size: path is a directory, {}", p.string());
         return 0;
     }
 
     GStatBuf st;
     if (g_stat(p.c_str(), &st) != 0) {
-        spdlog::error("fs::file_size: g_stat failed, {}", p);
+        spdlog::error("fs::file_size: g_stat failed, {}", p.string());
         return 0;
     }
 
@@ -302,7 +318,7 @@ void _open_path_with_default_app(const fs::path& file_or_folder_path)
 // Open Filepath with External App
 void open_filepath(const fs::path& filepath, bool open_folder_if_file_not_exists, CtConfig* config)
 {
-    spdlog::debug("fs::open_filepath {}", filepath);
+    spdlog::debug("fs::open_filepath {}", filepath.string());
     if (config->filelinkCustomOn) {
         std::string cmd = fmt::sprintf(config->filelinkCustomAct, filepath.string());
         _locale_env_vars_set_for_external_cmd(true/*isPre*/);
@@ -329,7 +345,7 @@ void open_filepath(const fs::path& filepath, bool open_folder_if_file_not_exists
 // Open Folderpath with External App
 void open_folderpath(const fs::path& folderpath, CtConfig* config)
 {
-    spdlog::debug("fs::open_folderpath {}", folderpath);
+    spdlog::debug("fs::open_folderpath {}", folderpath.string());
     if (config->folderlinkCustomOn) {
         std::string cmd = fmt::sprintf(config->folderlinkCustomAct, folderpath.string());
         _locale_env_vars_set_for_external_cmd(true/*isPre*/);
@@ -346,12 +362,12 @@ void open_folderpath(const fs::path& folderpath, CtConfig* config)
 
 path prepare_export_folder(const path& dir_place, path new_folder, bool overwrite_existing)
 {
-    if (fs::is_directory(dir_place / new_folder))
-    {
+    const fs::path dir_place_new_folder = dir_place / new_folder;
+    if (fs::is_directory(dir_place_new_folder)) {
         // todo:
         if (overwrite_existing) {
-            spdlog::debug("fs::prepare_export_folder: removing dir {}", dir_place / new_folder);
-            remove_all(dir_place / new_folder);
+            spdlog::debug("fs::prepare_export_folder: removing dir {}", dir_place_new_folder.string());
+            remove_all(dir_place_new_folder);
         }
         else {
             int n = 2;
@@ -398,6 +414,9 @@ fs::path get_cherrytree_datadir()
     //      cherrytree_0.99.9_win64_portable\mingw64\usr\share\cherrytree\icons
     return _mingw64Dir / "usr" / "share" / "cherrytree";
 #else
+    if (not _AppImageUsrDir.empty()) {
+        return _AppImageUsrDir / "share" / "cherrytree";
+    }
     return CHERRYTREE_DATADIR;
 #endif // _WIN32
 }
@@ -496,6 +515,7 @@ std::string download_file(const std::string& filepath)
             return realsize;
         }
     };
+    CtConfig* pCtConfig = CtConfig::GetCtConfig();
 
     spdlog::debug("fs::download_file: start downloading {}", filepath);
 
@@ -507,6 +527,15 @@ std::string download_file(const std::string& filepath)
     CURL* pCurlHandle = curl_easy_init();
 
     curl_easy_setopt(pCurlHandle, CURLOPT_URL, filepath.c_str());
+    if (not pCtConfig->proxyUrlColonPort.empty()) {
+        curl_easy_setopt(pCurlHandle, CURLOPT_PROXY, pCtConfig->proxyUrlColonPort.c_str());
+        if (not pCtConfig->proxyUsername.empty()) {
+            curl_easy_setopt(pCurlHandle, CURLOPT_PROXYUSERNAME, pCtConfig->proxyUsername.c_str());
+            if (not pCtConfig->proxyPassword.empty()) {
+                curl_easy_setopt(pCurlHandle, CURLOPT_PROXYPASSWORD, pCtConfig->proxyPassword.c_str());
+            }
+        }
+    }
     curl_easy_setopt(pCurlHandle, CURLOPT_WRITEFUNCTION, local::write_memory_callback);
     curl_easy_setopt(pCurlHandle, CURLOPT_WRITEDATA, (void*)&buffer);
     curl_easy_setopt(pCurlHandle, CURLOPT_TIMEOUT, 3);
