@@ -1,7 +1,7 @@
 /*
  * ct_image.cc
  *
- * Copyright 2009-2023
+ * Copyright 2009-2024
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -205,21 +205,47 @@ bool CtImagePng::_on_button_press_event(GdkEventButton* event)
 
 CtImageAnchor::CtImageAnchor(CtMainWin* pCtMainWin,
                              const Glib::ustring& anchorName,
+                             const CtAnchorExpCollState expCollState,
                              const int charOffset,
                              const std::string& justification)
- : CtImage{pCtMainWin, "ct_anchor", pCtMainWin->get_ct_config()->anchorSize, charOffset, justification}
+ : CtImage{pCtMainWin,
+           _get_stock_id_for_exp_coll_state(expCollState),
+           pCtMainWin->get_ct_config()->anchorSize,
+           charOffset,
+           justification}
  , _anchorName{anchorName}
+ , _expCollState{expCollState}
 {
     signal_button_press_event().connect(sigc::mem_fun(*this, &CtImageAnchor::_on_button_press_event), false);
     update_tooltip();
 }
 
+/*static*/const char* CtImageAnchor::_get_stock_id_for_exp_coll_state(const CtAnchorExpCollState expCollState)
+{
+    if (CtAnchorExpCollState::None == expCollState) return "ct_anchor";
+    if (CtAnchorExpCollState::Collapsed == expCollState) return "ct_visible";
+    return "ct_invisible";
+}
+
+void CtImageAnchor::_set_exp_coll_state(const CtAnchorExpCollState expCollState)
+{
+    if (expCollState != _expCollState) {
+        _expCollState = expCollState;
+        const char* stockImage = _get_stock_id_for_exp_coll_state(expCollState);
+        _rPixbuf = _pCtMainWin->get_icon_theme()->load_icon(stockImage, _pCtMainWin->get_ct_config()->anchorSize);
+        _image.set(_rPixbuf);
+    }
+}
+
 void CtImageAnchor::to_xml(xmlpp::Element* p_node_parent, const int offset_adjustment, CtStorageCache*, const std::string&/*multifile_dir*/)
 {
     xmlpp::Element* p_image_node = p_node_parent->add_child("encoded_png");
     p_image_node->set_attribute("char_offset", std::to_string(_charOffset+offset_adjustment));
     p_image_node->set_attribute(CtConst::TAG_JUSTIFICATION, _justification);
     p_image_node->set_attribute("anchor", _anchorName);
+    if (CtAnchorExpCollState::Collapsed == _expCollState) {
+        p_image_node->set_attribute("state", "coll");
+    }
 }
 
 bool CtImageAnchor::to_sqlite(sqlite3* pDb, const gint64 node_id, const int offset_adjustment, CtStorageCache*)
@@ -238,7 +264,12 @@ bool CtImageAnchor::to_sqlite(sqlite3* pDb, const gint64 node_id, const int offs
         sqlite3_bind_text(p_stmt, 4, anchor_name.c_str(), anchor_name.size(), SQLITE_STATIC);
         sqlite3_bind_blob(p_stmt, 5, nullptr, 0, SQLITE_STATIC);
         sqlite3_bind_text(p_stmt, 6, "", -1, SQLITE_STATIC); // filename
-        sqlite3_bind_text(p_stmt, 7, "", -1, SQLITE_STATIC); // link
+        if (CtAnchorExpCollState::Collapsed == _expCollState) {
+            sqlite3_bind_text(p_stmt, 7, "state:coll", 10, SQLITE_STATIC); // link field used in anchors for else
+        }
+        else {
+            sqlite3_bind_text(p_stmt, 7, "", -1, SQLITE_STATIC); // link
+        }
         sqlite3_bind_int64(p_stmt, 8, 0); // time
         if (sqlite3_step(p_stmt) != SQLITE_DONE) {
             spdlog::error("{}: {}", CtStorageSqlite::ERR_SQLITE_STEP, sqlite3_errmsg(pDb));
@@ -259,15 +290,69 @@ void CtImageAnchor::update_tooltip()
     set_tooltip_text(_anchorName);
 }
 
+void CtImageAnchor::toggle_exp_coll_state()
+{
+    Glib::RefPtr<Gtk::TextBuffer> pTextBuffer = _pCtMainWin->curr_buffer();
+    Gtk::TextIter textIterAnchor = pTextBuffer->get_iter_at_child_anchor(getTextChildAnchor());
+    const Glib::ustring& anchorName = get_anchor_name();
+    const int headerNum = CtStrUtil::is_header_anchor_name(anchorName);
+    if (0 == headerNum) {
+        spdlog::warn("!! unexp {} expCollState {}", anchorName.c_str(), CtAnchorExpCollState::Collapsed == _expCollState ? "coll" : "exp");
+    }
+    else {
+        const std::string tagPropVal{"h" + std::to_string(headerNum)};
+        const std::string tagNameH = _pCtMainWin->get_text_tag_name_exist_or_create(CtConst::TAG_SCALE, tagPropVal);
+        const std::string tagNameInvis = _pCtMainWin->get_text_tag_name_exist_or_create(CtConst::TAG_INVISIBLE, tagPropVal);
+        Glib::RefPtr<Gtk::TextTag> pTextTagH = _pCtMainWin->get_text_tag_table()->lookup(tagNameH);
+        if (CtAnchorExpCollState::Expanded == _expCollState) {
+            spdlog::debug("exp2coll {}", headerNum);
+            (void)textIterAnchor.forward_to_line_end();
+            (void)textIterAnchor.forward_char();
+            Gtk::TextIter textIterEnd{textIterAnchor};
+            (void)textIterEnd.forward_to_tag_toggle(pTextTagH);
+            //(void)textIterEnd.backward_char();
+            //spdlog::debug("'{}'", pTextBuffer->get_text(textIterAnchor, textIterEnd).c_str());
+            pTextBuffer->apply_tag_by_name(tagNameInvis, textIterAnchor, textIterEnd);
+            _set_exp_coll_state(CtAnchorExpCollState::Collapsed);
+            std::list<CtAnchoredWidget*> anchoredWidgets = _pCtMainWin->curr_tree_iter().get_anchored_widgets(
+                textIterAnchor.get_offset(), textIterEnd.get_offset());
+            for (CtAnchoredWidget* pCtAnchoredWidget : anchoredWidgets) {
+                pCtAnchoredWidget->set_hidden(true);
+            }
+        }
+        else {
+            spdlog::debug("coll2exp {}", headerNum);
+            Glib::RefPtr<Gtk::TextTag> pTextTagInvis = _pCtMainWin->get_text_tag_table()->lookup(tagNameInvis);
+            (void)textIterAnchor.forward_to_tag_toggle(pTextTagInvis);
+            Gtk::TextIter textIterEnd{textIterAnchor};
+            (void)textIterEnd.forward_to_tag_toggle(pTextTagInvis);
+            pTextBuffer->remove_tag_by_name(tagNameInvis, textIterAnchor, textIterEnd);
+            _set_exp_coll_state(CtAnchorExpCollState::Expanded);
+            std::list<CtAnchoredWidget*> anchoredWidgets = _pCtMainWin->curr_tree_iter().get_anchored_widgets(
+                textIterAnchor.get_offset(), textIterEnd.get_offset());
+            for (CtAnchoredWidget* pCtAnchoredWidget : anchoredWidgets) {
+                pCtAnchoredWidget->set_hidden(false);
+            }
+        }
+        _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true/*new_machine_state*/);
+    }
+}
+
 bool CtImageAnchor::_on_button_press_event(GdkEventButton* event)
 {
     _pCtMainWin->get_ct_actions()->curr_anchor_anchor = this;
     _pCtMainWin->get_ct_actions()->object_set_selection(this);
-    if (event->button == 3)
+    if (3 == event->button) {
         _pCtMainWin->get_ct_menu().get_popup_menu(CtMenu::POPUP_MENU_TYPE::Anchor)->popup(event->button, event->time);
-    else if (event->type == GDK_2BUTTON_PRESS)
-        _pCtMainWin->get_ct_actions()->anchor_edit();
-
+    }
+    else if (1 == event->button) {
+        if (event->type == GDK_2BUTTON_PRESS) {
+            _pCtMainWin->get_ct_actions()->anchor_edit();
+        }
+        else if (CtAnchorExpCollState::None != _expCollState) {
+            toggle_exp_coll_state();
+        }
+    }
     return true; // do not propagate the event
 }
 
@@ -347,7 +432,7 @@ void CtImageLatex::update_tooltip()
 
 #if defined(_WIN32)
 #define CONSOLE_SILENCE_OUTPUT  " > nul"
-#define CONSOLE_BIN_PREFIX      ""
+#define CONSOLE_BIN_PREFIX      fs::get_latex_dvipng_console_bin_prefix()
 #else // !_WIN32
 #define CONSOLE_SILENCE_OUTPUT  " > /dev/null"
 #if defined(_FLATPAK_BUILD)
@@ -358,10 +443,39 @@ void CtImageLatex::update_tooltip()
 #define CONSOLE_BIN_PREFIX      fs::get_latex_dvipng_console_bin_prefix()
 #endif // !_FLATPAK_BUILD
 #endif // !_WIN32
+
+static const char* get_latex_bin_cmd()
+{
+    auto _get_latex_bin_cmd = []()->const char*{
+#if defined(_WIN32)
+        return CONSOLE_BIN_PREFIX[0] ? g_strdup(".\\latex.exe") : g_strdup("latex.exe");
+#else /* !_WIN32 */
+        return g_strdup_printf("%slatex", CONSOLE_BIN_PREFIX);
+#endif /* !_WIN32 */
+    };
+    static const char* latex_bin_cmd = _get_latex_bin_cmd();
+    return latex_bin_cmd;
+}
+
+static const char* get_dvipng_bin_cmd()
+{
+    auto _get_dvipng_bin_cmd = []()->const char*{
+#if defined(_WIN32)
+        return CONSOLE_BIN_PREFIX[0] ? g_strdup(".\\dvipng.exe") : g_strdup("dvipng.exe");
+#else /* !_WIN32 */
+        return g_strdup_printf("%sdvipng", CONSOLE_BIN_PREFIX);
+#endif /* !_WIN32 */
+    };
+    static const char* dvipng_bin_cmd = _get_dvipng_bin_cmd();
+    return dvipng_bin_cmd;
+}
+
 /*static*/Glib::RefPtr<Gdk::Pixbuf> CtImageLatex::_get_latex_image(CtMainWin* pCtMainWin, const Glib::ustring& latexText, const size_t uniqueId, const int zoom)
 {
-    if (not _renderingBinariesTested) {
-        _renderingBinariesTested = true;
+    CtImageLatex::ensureRenderingBinariesTested();
+    if (not _renderingBinariesLatexOk or not _renderingBinariesDviPngOk) {
+        // fallback
+        return pCtMainWin->get_icon_theme()->load_icon("ct_warning", 48);
     }
     const fs::path filename = std::to_string(uniqueId) +
                               CtConst::CHAR_MINUS + std::to_string(getpid()) +
@@ -370,65 +484,41 @@ void CtImageLatex::update_tooltip()
     const fs::path tmp_filepath_tex = pCtMainWin->get_ct_tmp()->getHiddenFilePath(filename);
     Glib::file_set_contents(tmp_filepath_tex.string(), latexText);
     const fs::path tmp_dirpath = tmp_filepath_tex.parent_path();
-    std::string cmd = fmt::sprintf("%slatex --interaction=batchmode -output-directory=%s %s" CONSOLE_SILENCE_OUTPUT,
-                                   CONSOLE_BIN_PREFIX, tmp_dirpath.c_str(), tmp_filepath_tex.c_str());
-#if defined(_WIN32)
-    glong utf16text_len = 0;
-    g_autofree gunichar2* utf16text = g_utf8_to_utf16(cmd.c_str(), (glong)Glib::ustring{cmd.c_str()}.bytes(), nullptr, &utf16text_len, nullptr);
-    STARTUPINFOW si;
-    PROCESS_INFORMATION pi;
-    ZeroMemory(&si, sizeof(si));
-    si.cb = sizeof(si);
-    ZeroMemory(&pi, sizeof(pi));
-    bool success = CreateProcessW(NULL, (LPWSTR)utf16text, NULL, NULL, FALSE, CREATE_NO_WINDOW, NULL, NULL, &si, &pi);
-    if (success) {
-        WaitForSingleObject(pi.hProcess, INFINITE);
-        CloseHandle(pi.hProcess);
-        CloseHandle(pi.hThread);
+    std::string cmd = fmt::sprintf("%s --interaction=batchmode -output-directory=%s %s"
+#ifndef _WIN32
+                                   CONSOLE_SILENCE_OUTPUT
+#endif /* !_WIN32 */
+                                   , get_latex_bin_cmd(), tmp_dirpath.c_str(), tmp_filepath_tex.c_str());
+    bool success = CtMiscUtil::system_cmd(cmd.c_str(), CONSOLE_BIN_PREFIX);
+    std::string tmp_filepath_noext = tmp_filepath_tex.string();
+    tmp_filepath_noext = tmp_filepath_noext.substr(0, tmp_filepath_noext.size() - 3);
+    const fs::path tmp_filepath_dvi = tmp_filepath_noext + "dvi";
+    if (not success or not fs::is_regular_file(tmp_filepath_dvi)) {
+        if (success) spdlog::debug("!! cmd '{}' ok but missing {}", cmd, tmp_filepath_dvi.c_str());
+        // fallback
+        return pCtMainWin->get_icon_theme()->load_icon("ct_bug", 48);
     }
-    int retVal;
-    if (not success) {
-        spdlog::error("!! CreateProcessW({})", cmd);
-#else
-    int retVal = std::system(cmd.c_str());
-    if (retVal != 0) {
-        spdlog::error("system({}) returned {}", cmd, retVal);
-#endif
-        if (_renderingBinariesLatexOk) {
-            _renderingBinariesLatexOk = false;
-            if (_renderingBinariesDviPngOk and 0 != system(fmt::sprintf("%sdvipng --version" CONSOLE_SILENCE_OUTPUT, CONSOLE_BIN_PREFIX).c_str())) {
-                _renderingBinariesDviPngOk = false;
-            }
-        }
+    const fs::path tmp_filepath_png = tmp_filepath_noext + "png";
+    const int latexSizeDpi = zoom * pCtMainWin->get_ct_config()->latexSizeDpi;
+    cmd = fmt::sprintf("%s -q -T tight -D %d %s -o %s"
+#ifndef _WIN32
+                       CONSOLE_SILENCE_OUTPUT
+#endif /* !_WIN32 */
+                       , get_dvipng_bin_cmd(), latexSizeDpi, tmp_filepath_dvi.c_str(), tmp_filepath_png.c_str());
+    success = CtMiscUtil::system_cmd(cmd.c_str(), CONSOLE_BIN_PREFIX);
+    if (not success or not fs::is_regular_file(tmp_filepath_png)) {
+        if (success) spdlog::debug("!! cmd '{}' ok but missing {}", cmd, tmp_filepath_png.c_str());
+        _renderingBinariesDviPngOk = false;
+        // fallback
+        return pCtMainWin->get_icon_theme()->load_icon("ct_warning", 48);
     }
-    else {
-        std::string tmp_filepath_noext = tmp_filepath_tex.string();
-        tmp_filepath_noext = tmp_filepath_noext.substr(0, tmp_filepath_noext.size() - 3);
-        const fs::path tmp_filepath_dvi = tmp_filepath_noext + "dvi";
-        const fs::path tmp_filepath_png = tmp_filepath_noext + "png";
-        const int latexSizeDpi = zoom * pCtMainWin->get_ct_config()->latexSizeDpi;
-        cmd = fmt::sprintf("%sdvipng -q -T tight -D %d %s -o %s" CONSOLE_SILENCE_OUTPUT,
-                           CONSOLE_BIN_PREFIX, latexSizeDpi, tmp_filepath_dvi.c_str(), tmp_filepath_png.c_str());
-        retVal = std::system(cmd.c_str());
-        if (retVal != 0) {
-            spdlog::error("system({}) returned {}", cmd, retVal);
-            if (_renderingBinariesDviPngOk) {
-                _renderingBinariesDviPngOk = false;
-            }
-        }
-        else {
-            Glib::RefPtr<Gdk::Pixbuf> rPixbuf;
-            try {
-                rPixbuf = Gdk::Pixbuf::create_from_file(tmp_filepath_png.c_str());
-            }
-            catch (Glib::Error& error) {
-                spdlog::error("{} {}", __FUNCTION__, error.what());
-            }
-            if (rPixbuf) {
-                // success
-                return rPixbuf;
-            }
-        }
+    Glib::RefPtr<Gdk::Pixbuf> rPixbuf;
+    try {
+        rPixbuf = Gdk::Pixbuf::create_from_file(tmp_filepath_png.c_str());
+        return rPixbuf;
+    }
+    catch (Glib::Error& error) {
+        spdlog::error("{} {}", __FUNCTION__, error.what().raw());
     }
     // fallback
     return pCtMainWin->get_icon_theme()->load_icon("ct_warning", 48);
@@ -440,8 +530,16 @@ void CtImageLatex::update_tooltip()
         return;
     }
     _renderingBinariesTested = true;
-    _renderingBinariesLatexOk = 0 == system(fmt::sprintf("%slatex --version" CONSOLE_SILENCE_OUTPUT, CONSOLE_BIN_PREFIX).c_str());
-    _renderingBinariesDviPngOk = 0 == system(fmt::sprintf("%sdvipng --version" CONSOLE_SILENCE_OUTPUT, CONSOLE_BIN_PREFIX).c_str());
+    _renderingBinariesLatexOk = CtMiscUtil::system_cmd(fmt::sprintf("%s --version"
+#ifndef _WIN32
+                                                                    CONSOLE_SILENCE_OUTPUT
+#endif /* !_WIN32 */
+                                                                    , get_latex_bin_cmd()).c_str(), CONSOLE_BIN_PREFIX);
+    _renderingBinariesDviPngOk = CtMiscUtil::system_cmd(fmt::sprintf("%s --version"
+#ifndef _WIN32
+                                                                    CONSOLE_SILENCE_OUTPUT
+#endif /* !_WIN32 */
+                                                                    , get_dvipng_bin_cmd()).c_str(), CONSOLE_BIN_PREFIX);
 }
 
 /*static*/Glib::ustring CtImageLatex::getRenderingErrorMessage()
