@@ -26,14 +26,26 @@
 #include "ct_storage_control.h"
 #include "ct_clipboard.h"
 
+void CtStatusBar::new_cursor_pos(const int r, const int c)
+{
+    if (_r != r or _c != c) {
+#if GLIBMM_MAJOR_VERSION > 2 || (GLIBMM_MAJOR_VERSION == 2 && GLIBMM_MINOR_VERSION >= 62)
+        cursorPos.set_text(Glib::ustring::sprintf(" (%d,%d)", r, c));
+#else /* glibmm < 2.62 */
+        cursorPos.set_text(fmt::format(" ({},{})", r, c));
+#endif /* glibmm < 2.62 */
+        _r = r;
+        _c = c;
+    }
+}
+
 CtMainWin::CtMainWin(bool                            no_gui,
                      CtConfig*                       pCtConfig,
                      CtTmp*                          pCtTmp,
                      Gtk::IconTheme*                 pGtkIconTheme,
                      Glib::RefPtr<Gtk::TextTagTable> rGtkTextTagTable,
                      Glib::RefPtr<Gtk::CssProvider>  rGtkCssProvider,
-                     Gsv::LanguageManager*           pGsvLanguageManager,
-                     Gsv::StyleSchemeManager*        pGsvStyleSchemeManager,
+                     GtkSourceLanguageManager*       pGtkSourceLanguageManager,
                      CtStatusIcon*                   pCtStatusIcon)
  : Gtk::ApplicationWindow{}
  , _no_gui{no_gui}
@@ -42,8 +54,7 @@ CtMainWin::CtMainWin(bool                            no_gui,
  , _pGtkIconTheme{pGtkIconTheme}
  , _rGtkTextTagTable{rGtkTextTagTable}
  , _rGtkCssProvider{rGtkCssProvider}
- , _pGsvLanguageManager{pGsvLanguageManager}
- , _pGsvStyleSchemeManager{pGsvStyleSchemeManager}
+ , _pGtkSourceLanguageManager{pGtkSourceLanguageManager}
  , _pCtStatusIcon{pCtStatusIcon}
  , _ctTextview{this}
  , _ctStateMachine{this}
@@ -60,7 +71,7 @@ CtMainWin::CtMainWin(bool                            no_gui,
     _scrolledwindowTree.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
     _scrolledwindowTree.get_style_context()->add_class("ct-tree-scroll-panel");
     _scrolledwindowText.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
-    _scrolledwindowText.add(_ctTextview);
+    _scrolledwindowText.add(_ctTextview.mm());
     _vboxText.pack_start(_init_window_header(), false, false);
     _vboxText.pack_start(_scrolledwindowText);
     if (_pCtConfig->treeRightSide) {
@@ -119,15 +130,16 @@ CtMainWin::CtMainWin(bool                            no_gui,
 
     _reset_CtTreestore_CtTreeview();
 
-    _ctTextview.get_style_context()->add_class("ct-view-panel");
-    _ctTextview.set_sensitive(false);
+    auto& textView = _ctTextview.mm();
+    textView.get_style_context()->add_class("ct-view-panel");
+    textView.set_sensitive(false);
 
-    _ctTextview.signal_populate_popup().connect(sigc::mem_fun(*this, &CtMainWin::_on_textview_populate_popup));
-    _ctTextview.signal_motion_notify_event().connect(sigc::mem_fun(*this, &CtMainWin::_on_textview_motion_notify_event));
-    _ctTextview.signal_visibility_notify_event().connect(sigc::mem_fun(*this, &CtMainWin::_on_textview_visibility_notify_event));
-    _ctTextview.signal_event().connect(sigc::mem_fun(*this, &CtMainWin::_on_textview_event));
-    _ctTextview.signal_event_after().connect(sigc::mem_fun(*this, &CtMainWin::_on_textview_event_after));
-    _ctTextview.signal_scroll_event().connect(sigc::mem_fun(*this, &CtMainWin::_on_textview_scroll_event));
+    textView.signal_populate_popup().connect(sigc::mem_fun(*this, &CtMainWin::_on_textview_populate_popup));
+    textView.signal_motion_notify_event().connect(sigc::mem_fun(*this, &CtMainWin::_on_textview_motion_notify_event));
+    textView.signal_visibility_notify_event().connect(sigc::mem_fun(*this, &CtMainWin::_on_textview_visibility_notify_event));
+    textView.signal_event().connect(sigc::mem_fun(*this, &CtMainWin::_on_textview_event));
+    textView.signal_event_after().connect(sigc::mem_fun(*this, &CtMainWin::_on_textview_event_after));
+    textView.signal_scroll_event().connect(sigc::mem_fun(*this, &CtMainWin::_on_textview_scroll_event));
 
     _uCtPairCodeboxMainWin.reset(new CtPairCodeboxMainWin{nullptr, this});
     g_signal_connect(G_OBJECT(_ctTextview.gobj()), "cut-clipboard", G_CALLBACK(CtClipboard::on_cut_clipboard), _uCtPairCodeboxMainWin.get());
@@ -181,7 +193,7 @@ CtMainWin::CtMainWin(bool                            no_gui,
         Glib::signal_idle().connect_once([this](){
             _hPaned.property_position() = _pCtConfig->hpanedPos; // must be after present() + process events pending (#1534, #1918, #2126)
             _vPaned.property_position() = _pCtConfig->vpanedPos;
-            _ctTextview.signal_size_allocate().connect(sigc::mem_fun(*this, &CtMainWin::_on_textview_size_allocate));
+            _ctTextview.mm().signal_size_allocate().connect(sigc::mem_fun(*this, &CtMainWin::_on_textview_size_allocate));
             signal_configure_event().connect(sigc::mem_fun(*this, &CtMainWin::_on_window_configure_event), false);
 
             // show status icon if needed
@@ -318,14 +330,16 @@ void CtMainWin::config_apply()
 
     menu_set_visible_exit_app(_pCtConfig->systrayOn);
 
-    _ctTextview.set_show_line_numbers(_pCtConfig->showLineNumbers);
-    _ctTextview.set_insert_spaces_instead_of_tabs(_pCtConfig->spacesInsteadTabs);
-    _ctTextview.set_tab_width(_pCtConfig->tabsWidth);
-    _ctTextview.set_indent(_pCtConfig->wrappingIndent);
-    _ctTextview.set_pixels_above_lines(_pCtConfig->spaceAroundLines);
-    _ctTextview.set_pixels_below_lines(_pCtConfig->spaceAroundLines);
+    auto pGtkSourceView = GTK_SOURCE_VIEW(_ctTextview.gobj());
+    auto& textView = _ctTextview.mm();
+    gtk_source_view_set_show_line_numbers(pGtkSourceView, _pCtConfig->showLineNumbers);
+    gtk_source_view_set_insert_spaces_instead_of_tabs(pGtkSourceView, _pCtConfig->spacesInsteadTabs);
+    gtk_source_view_set_tab_width(pGtkSourceView, _pCtConfig->tabsWidth);
+    textView.set_indent(_pCtConfig->wrappingIndent);
+    textView.set_pixels_above_lines(_pCtConfig->spaceAroundLines);
+    textView.set_pixels_below_lines(_pCtConfig->spaceAroundLines);
     _ctTextview.set_pixels_inside_wrap(_pCtConfig->spaceAroundLines, _pCtConfig->relativeWrappedSpace);
-    _ctTextview.set_wrap_mode(_pCtConfig->lineWrapping ? Gtk::WrapMode::WRAP_WORD_CHAR : Gtk::WrapMode::WRAP_NONE);
+    textView.set_wrap_mode(_pCtConfig->lineWrapping ? Gtk::WrapMode::WRAP_WORD_CHAR : Gtk::WrapMode::WRAP_NONE);
 
     if (2 != _pCtConfig->cursorBlink) {
         Gtk::Settings::get_default()->property_gtk_cursor_blink() = _pCtConfig->cursorBlink;
@@ -345,16 +359,43 @@ void CtMainWin::config_update_data_from_curr_status()
 
 void CtMainWin::update_theme()
 {
-    auto font_to_string = [](const Pango::FontDescription& font, const Glib::ustring& fallbackFont)->std::string{
+    auto font_to_string = [](const Pango::FontDescription& font, const Glib::ustring&
+#if defined(_WIN32)
+                                                                                      fallbackFont
+#endif /* _WIN32 */
+                            )->std::string{
         // adds fallback font on Win32; on Linux, fonts work ok without explicit fallback
-#ifdef _WIN32
-        return " { font-family: \"" + Glib::locale_from_utf8(font.get_family()) + "\",\"" + fallbackFont +  "\""
-                    "; font-size: " + std::to_string(font.get_size()/Pango::SCALE) + "pt; } ";
-#else
-        (void)fallbackFont; // to silence the warning
-        return std::string{" { font-family: "} + Glib::locale_from_utf8(font.get_family()) +
-                 "; font-size: " + std::to_string(font.get_size()/Pango::SCALE) + "pt; } ";
-#endif
+        // https://docs.gtk.org/gtk3/css-properties.html#font-properties
+        // NOTE: {{ and }} are fmt::format escapes for { and }
+        std::string retStr = fmt::format(" {{ font-family: \"{}\"", Glib::locale_from_utf8(font.get_family()));
+#if defined(_WIN32)
+        retStr += fmt::format(",\"{}\"", fallbackFont.raw());
+#endif /* _WIN32 */
+        const Pango::Style style_enum = font.get_style();
+        const char* style_str = "normal";
+        switch (style_enum) {
+            case Pango::Style::STYLE_OBLIQUE: style_str = "oblique"; break;
+            case Pango::Style::STYLE_ITALIC: style_str = "italic"; break;
+            default: break;
+        }
+        const Pango::Stretch stretch_enum = font.get_stretch();
+        const char* stretch_str = "normal";
+        switch (stretch_enum) {
+            case Pango::Stretch::STRETCH_ULTRA_CONDENSED: stretch_str = "ultra-condensed"; break;
+            case Pango::Stretch::STRETCH_EXTRA_CONDENSED: stretch_str = "extra-condensed"; break;
+            case Pango::Stretch::STRETCH_CONDENSED: stretch_str = "condensed"; break;
+            case Pango::Stretch::STRETCH_SEMI_CONDENSED: stretch_str = "semi-condensed"; break;
+            case Pango::Stretch::STRETCH_SEMI_EXPANDED: stretch_str = "semi-expanded"; break;
+            case Pango::Stretch::STRETCH_EXPANDED: stretch_str = "expanded"; break;
+            case Pango::Stretch::STRETCH_EXTRA_EXPANDED: stretch_str = "extra-expanded"; break;
+            case Pango::Stretch::STRETCH_ULTRA_EXPANDED: stretch_str = "ultra-expanded"; break;
+            default: break;
+        }
+        const Pango::Variant variant_enum = font.get_variant();
+        const char* variant_str = Pango::Variant::VARIANT_SMALL_CAPS == variant_enum ? "small-caps" : "normal";
+        retStr += fmt::format("; font-size: {}pt; font-weight: {}; font-style: {}; font-stretch: {}; font-variant: {}; }} ",
+            std::to_string(font.get_size()/Pango::SCALE), std::to_string(font.get_weight()), style_str, stretch_str, variant_str);
+        return retStr;
     };
 
     std::string rtFont = font_to_string(Pango::FontDescription(_pCtConfig->rtFont), _pCtConfig->fallbackFontFamily);
@@ -412,6 +453,7 @@ Gtk::HBox& CtMainWin::_init_status_bar()
     _ctStatusBar.frame.set_shadow_type(Gtk::SHADOW_NONE);
     _ctStatusBar.frame.add(_ctStatusBar.progressBar);
     _ctStatusBar.stopButton.set_image_from_icon_name("ct_stop", Gtk::ICON_SIZE_MENU);
+    _ctStatusBar.hbox.pack_start(_ctStatusBar.cursorPos, false, false);
     _ctStatusBar.hbox.pack_start(_ctStatusBar.statusBar, true, true);
     _ctStatusBar.hbox.pack_start(_ctStatusBar.frame, false, true);
     _ctStatusBar.hbox.pack_start(_ctStatusBar.stopButton, false, true);
@@ -480,7 +522,7 @@ void CtMainWin::window_header_update()
                 if (node_id != _ctWinHeader.button_to_node_id.end()) {
                     if (CtTreeIter tree_iter = get_tree_store().get_node_from_node_id(node_id->second))
                         _uCtTreeview->set_cursor_safe(tree_iter);
-                    _ctTextview.grab_focus();
+                    _ctTextview.mm().grab_focus();
                 }
             };
             button->signal_clicked().connect(sigc::bind(click, button));
@@ -674,14 +716,33 @@ void CtMainWin::config_switch_tree_side()
     _pCtConfig->hpanedPos = _hPaned.property_position();
 }
 
-void CtMainWin::_zoom_tree(bool is_increase)
+void CtMainWin::_zoom_tree(const std::optional<bool> is_increase)
 {
-    Glib::RefPtr<Gtk::StyleContext> context = _uCtTreeview->get_style_context();
-    const Pango::FontDescription fontDesc = context->get_font(context->get_state());
-    int size = fontDesc.get_size() / Pango::SCALE + (is_increase ? 1 : -1);
-    if (size < 6) size = 6;
-    _pCtConfig->treeFont = CtFontUtil::get_font_str(CtFontUtil::get_font_family(_pCtConfig->treeFont), size);
-    signal_app_apply_for_each_window([](CtMainWin* win) { win->update_theme(); win->window_header_update(); });
+    Glib::RefPtr<Gtk::StyleContext> pContext = _uCtTreeview->get_style_context();
+    const Pango::FontDescription fontDesc = pContext->get_font(pContext->get_state());
+    const int size_pre = fontDesc.get_size() / Pango::SCALE;
+    int size_new = 0;
+    if (is_increase.has_value()) {
+        if (0 == _pCtConfig->treeResetFontSize) {
+            _pCtConfig->treeResetFontSize = size_pre;
+            spdlog::debug("{} set reset to {}", __FUNCTION__, size_pre);
+        }
+        size_new = size_pre + (is_increase.value() ? 1 : -1);
+    }
+    else {
+        // it's a reset
+        if (0 == _pCtConfig->treeResetFontSize || size_pre == _pCtConfig->treeResetFontSize) {
+            spdlog::debug("{} reset not necessary", __FUNCTION__);
+        }
+        else {
+            size_new = _pCtConfig->treeResetFontSize;
+        }
+    }
+    if (size_new > 0) {
+        if (size_new < 6) size_new = 6;
+        _pCtConfig->treeFont = CtFontUtil::get_font_str(CtFontUtil::get_font_family(_pCtConfig->treeFont), size_new);
+        signal_app_apply_for_each_window([](CtMainWin* win) { win->update_theme(); win->window_header_update(); });
+    }
 }
 
 void CtMainWin::reset()
@@ -711,7 +772,7 @@ void CtMainWin::reset()
     _ctTextview.set_buffer(Glib::RefPtr<Gtk::TextBuffer>{});
     _ctTextview.set_spell_check(false);
     if (not _no_gui) {
-        _ctTextview.set_sensitive(false);
+        _ctTextview.mm().set_sensitive(false);
     }
 }
 
