@@ -41,7 +41,7 @@ void CtMainWin::_on_treeview_cursor_changed()
             return;
         }
         const gint64 prevNodeIdDataHolder = _prevTreeIter.get_node_id_data_holder();
-        Glib::RefPtr<Gsv::Buffer> rTextBuffer = _prevTreeIter.get_node_text_buffer();
+        Glib::RefPtr<Gtk::TextBuffer> rTextBuffer = _prevTreeIter.get_node_text_buffer();
         if (rTextBuffer->get_modified()) {
             _fileSaveNeeded = true;
             rTextBuffer->set_modified(false);
@@ -54,9 +54,9 @@ void CtMainWin::_on_treeview_cursor_changed()
         //spdlog::debug("W[{}] scr={}, cur={}", prevNodeIdDataHolder, scr, cur);
     }
 
-    Glib::RefPtr<Gsv::Buffer> rTextBuffer = treeIter.get_node_text_buffer();
+    Glib::RefPtr<Gtk::TextBuffer> rTextBuffer = treeIter.get_node_text_buffer();
     if (not rTextBuffer) {
-        CtDialogs::error_dialog(str::format(_("Failed to retrieve the content of the node '%s'"), treeIter.get_node_name()), *this);
+        CtDialogs::error_dialog(str::format(_("Failed to retrieve the content of the node '%s'"), treeIter.get_node_name().raw()), *this);
         if (_prevTreeIter) {
             _uCtTreeview->set_cursor_safe(_prevTreeIter);
         }
@@ -117,7 +117,7 @@ void CtMainWin::_on_treeview_event_after(GdkEvent* event)
 {
     if (event->type == GDK_BUTTON_PRESS and event->button.button == 1) {
         if (_pCtConfig->treeClickFocusText) {
-            _ctTextview.grab_focus();
+            _ctTextview.mm().grab_focus();
         }
         if (_pCtConfig->treeClickExpand) {
             _tree_just_auto_expanded = false;
@@ -199,33 +199,35 @@ bool CtMainWin::_on_treeview_key_press_event(GdkEventKey* event)
                 get_tree_view().set_cursor_safe(fist_sibling);
             return true;
         }
-        else if (GDK_KEY_Down == event->keyval) {
+        if (GDK_KEY_Down == event->keyval) {
             auto last_sibling = reduce(curr_tree_iter(), [](Gtk::TreeIter iter) { return ++iter;});
             if (last_sibling)
                 get_tree_view().set_cursor_safe(last_sibling);
             return true;
         }
-        else if (GDK_KEY_Left == event->keyval) {
+        if (GDK_KEY_Left == event->keyval) {
             auto fist_parent = reduce(curr_tree_iter(), [](Gtk::TreeIter iter) { return iter->parent();});
             if (fist_parent)
                 get_tree_view().set_cursor_safe(fist_parent);
             return true;
         }
-        else if (GDK_KEY_Right == event->keyval) {
+        if (GDK_KEY_Right == event->keyval) {
             auto last_child = reduce(curr_tree_iter(), [](Gtk::TreeIter iter) { return iter->children().begin();});
             if (last_child)
                 get_tree_view().set_cursor_safe(last_child);
             return true;
         }
-        else {
-            if (GDK_KEY_plus == event->keyval or GDK_KEY_KP_Add == event->keyval or GDK_KEY_equal == event->keyval) {
-                _zoom_tree(true);
-                return true;
-            }
-            else if (GDK_KEY_minus == event->keyval or GDK_KEY_KP_Subtract == event->keyval) {
-                _zoom_tree(false);
-                return true;
-            }
+        if (GDK_KEY_plus == event->keyval or GDK_KEY_KP_Add == event->keyval or GDK_KEY_equal == event->keyval) {
+            _zoom_tree(true);
+            return true;
+        }
+        if (GDK_KEY_minus == event->keyval or GDK_KEY_KP_Subtract == event->keyval) {
+            _zoom_tree(false);
+            return true;
+        }
+        if (GDK_KEY_0 == event->keyval or GDK_KEY_KP_0 == event->keyval) {
+            _zoom_tree(std::nullopt);
+            return true;
         }
     }
     else {
@@ -236,27 +238,27 @@ bool CtMainWin::_on_treeview_key_press_event(GdkEventKey* event)
                 get_tree_view().set_cursor_safe(curr_tree_iter().parent());
             return true;
         }
-        else if (GDK_KEY_Right == event->keyval) {
+        if (GDK_KEY_Right == event->keyval) {
             get_tree_view().expand_row(get_tree_store().get_path(curr_tree_iter()), false);
             return true;
         }
-        else if (GDK_KEY_Return == event->keyval or GDK_KEY_KP_Enter == event->keyval) {
-            auto path = get_tree_store().get_path(curr_tree_iter());
-            if (_uCtTreeview->row_expanded(path))
-                _uCtTreeview->collapse_row(path);
+        if (GDK_KEY_Return == event->keyval or GDK_KEY_KP_Enter == event->keyval) {
+            auto p = get_tree_store().get_path(curr_tree_iter());
+            if (_uCtTreeview->row_expanded(p))
+                _uCtTreeview->collapse_row(p);
             else
-                _uCtTreeview->expand_row(path, false);
+                _uCtTreeview->expand_row(p, false);
             return true;
         }
-        else if (GDK_KEY_Menu == event->keyval) {
+        if (GDK_KEY_Menu == event->keyval) {
             _uCtMenu->get_popup_menu(CtMenu::POPUP_MENU_TYPE::Node)->popup(0, event->time);
             return true;
         }
-        else if (GDK_KEY_Tab == event->keyval or GDK_KEY_ISO_Left_Tab == event->keyval) {
+        if (GDK_KEY_Tab == event->keyval or GDK_KEY_ISO_Left_Tab == event->keyval) {
             _uCtActions->toggle_focus_tree_text();
             return true;
         }
-        else if (GDK_KEY_Delete == event->keyval) {
+        if (GDK_KEY_Delete == event->keyval) {
             _uCtActions->node_delete();
             return true;
         }
@@ -326,16 +328,16 @@ void CtMainWin::_on_textview_populate_popup(Gtk::Menu* menu)
 // Update the cursor image if the pointer moved
 bool CtMainWin::_on_textview_motion_notify_event(GdkEventMotion* event)
 {
-    if (not _ctTextview.get_cursor_visible())
-        _ctTextview.set_cursor_visible(true);
+    if (not _ctTextview.mm().get_cursor_visible())
+        _ctTextview.mm().set_cursor_visible(true);
     if (curr_tree_iter().get_node_syntax_highlighting() != CtConst::RICH_TEXT_ID
         and curr_tree_iter().get_node_syntax_highlighting() != CtConst::PLAIN_TEXT_ID)
     {
-        _ctTextview.get_window(Gtk::TEXT_WINDOW_TEXT)->set_cursor(Gdk::Cursor::create(Gdk::XTERM));
+        _ctTextview.mm().get_window(Gtk::TEXT_WINDOW_TEXT)->set_cursor(Gdk::Cursor::create(Gdk::XTERM));
         return false;
     }
     int x, y;
-    _ctTextview.window_to_buffer_coords(Gtk::TEXT_WINDOW_TEXT, (int)event->x, (int)event->y, x, y);
+    _ctTextview.mm().window_to_buffer_coords(Gtk::TEXT_WINDOW_TEXT, (int)event->x, (int)event->y, x, y);
     _ctTextview.cursor_and_tooltips_handler(x, y);
     return false;
 }
@@ -349,13 +351,13 @@ bool CtMainWin::_on_textview_visibility_notify_event(GdkEventVisibility*)
     }
     const auto syntax_highl = ct_tree_iter.get_node_syntax_highlighting();
     if (CtConst::RICH_TEXT_ID != syntax_highl and CtConst::PLAIN_TEXT_ID != syntax_highl) {
-        _ctTextview.get_window(Gtk::TEXT_WINDOW_TEXT)->set_cursor(Gdk::Cursor::create(Gdk::XTERM));
+        _ctTextview.mm().get_window(Gtk::TEXT_WINDOW_TEXT)->set_cursor(Gdk::Cursor::create(Gdk::XTERM));
         return false;
     }
     int x, y, bx, by;
     Gdk::ModifierType mask;
-    _ctTextview.get_window(Gtk::TEXT_WINDOW_TEXT)->get_pointer(x, y, mask);
-    _ctTextview.window_to_buffer_coords(Gtk::TEXT_WINDOW_TEXT, x, y, bx, by);
+    _ctTextview.mm().get_window(Gtk::TEXT_WINDOW_TEXT)->get_pointer(x, y, mask);
+    _ctTextview.mm().window_to_buffer_coords(Gtk::TEXT_WINDOW_TEXT, x, y, bx, by);
     _ctTextview.cursor_and_tooltips_handler(bx, by);
     return false;
 }
@@ -472,7 +474,7 @@ bool CtMainWin::_on_textview_event(GdkEvent* event)
             }
             if (dynamic_cast<CtTableCommon*>(widgets.front())) {
                 curr_buffer->place_cursor(iter_sel_end);
-                _ctTextview.grab_focus();
+                _ctTextview.mm().grab_focus();
                 return true;
             }
             return false;
@@ -498,10 +500,14 @@ bool CtMainWin::_on_textview_event(GdkEvent* event)
                 _ctTextview.zoom_text(true, curr_tree_iter().get_node_syntax_highlighting());
                 return true;
             }
-            else if (GDK_KEY_minus == event->key.keyval or GDK_KEY_KP_Subtract == event->key.keyval) {
+            if (GDK_KEY_minus == event->key.keyval or GDK_KEY_KP_Subtract == event->key.keyval) {
                 _ctTextview.zoom_text(false, curr_tree_iter().get_node_syntax_highlighting());
                 return true;
             }
+            if (GDK_KEY_0 == event->key.keyval or GDK_KEY_KP_0 == event->key.keyval) {
+                _ctTextview.zoom_text(std::nullopt, curr_tree_iter().get_node_syntax_highlighting());
+                return true;
+            }
         }
     }
     return false;
