@@ -77,7 +77,7 @@ void CtMainWin::update_window_save_not_needed()
     _fileSaveNeeded = false;
     CtTreeIter treeIter = curr_tree_iter();
     if (treeIter) {
-        Glib::RefPtr<Gsv::Buffer> rTextBuffer = treeIter.get_node_text_buffer();
+        Glib::RefPtr<Gtk::TextBuffer> rTextBuffer = treeIter.get_node_text_buffer();
         rTextBuffer->set_modified(false);
         std::list<CtAnchoredWidget*> anchoredWidgets = treeIter.get_anchored_widgets_fast();
         for (CtAnchoredWidget* pAnchoredWidget : anchoredWidgets) {
@@ -165,23 +165,56 @@ bool CtMainWin::file_open(const fs::path& filepath,
         return false;
     }
 
-    fs::path prev_path = _uCtStorage->get_file_path();
-
     _ensure_curr_doc_in_recent_docs();
     reset(); // cannot reset after load_from because load_from fill tree store
 
-    Glib::ustring error;
-    CtStorageControl* new_storage = CtStorageControl::load_from(this, filepath, doc_type, error, password);
+    Glib::ustring error_or_warning;
+    CtStorageControl* new_storage = CtStorageControl::load_from(this, filepath, doc_type, error_or_warning, password);
     if (not new_storage) {
-        if (not error.empty()) {
-            CtDialogs::error_dialog(str::format(_("Error Parsing the CherryTree Path:\n\"%s\""), str::xml_escape(error)), *this);
+        if (not error_or_warning.empty()) {
+            CtDialogs::error_dialog(str::format(_("Error Parsing the CherryTree Path:\n\"%s\""), str::xml_escape(error_or_warning)), *this);
         }
-
-        // trying to recover prevous document
-        if (not prev_path.empty()) {
-            file_open(prev_path, ""/*node*/, ""/*anchor*/); // it won't be in loop because storage is empty
+        // an empty error_or_warning means that the user pressed cancel on the request for password dialog
+        if (not error_or_warning.empty() and CtDocType::MultiFile != doc_type) {
+            // NOTE: MultiFile storage has a different recover mechanism from the backups
+            if (CtDialogs::question_dialog(_("Do you want to Open the Last Backup?"), *this)) {
+                fs::path filepath_parked{filepath};
+                filepath_parked += (std::to_string(g_get_monotonic_time()) + filepath.extension());
+                fs::move_file(filepath, filepath_parked);
+                spdlog::debug("parked {} -> {}", filepath.string(), filepath_parked.string());
+                std::string first_backup_file;
+                CtStorageControl::get_first_backup_file_or_dir(first_backup_file, filepath.string(), _pCtConfig);
+                int missing_backup{0};
+                for (int b = 0; b < 100; ++b) {
+                    const fs::path curr_backup_file = first_backup_file + str::repeat(CtConst::CHAR_TILDE, b).raw();
+                    if (fs::is_regular_file(curr_backup_file)) {
+                        missing_backup = 0;
+                        error_or_warning.clear();
+                        fs::move_file(curr_backup_file, filepath);
+                        spdlog::debug("trying {} -> {}", curr_backup_file.string(), filepath.string());
+                        new_storage = CtStorageControl::load_from(this, filepath, doc_type, error_or_warning, password);
+                        if (new_storage) {
+                            spdlog::debug("OK recover from {}", curr_backup_file.string());
+                            break;
+                        }
+                        fs::move_file(filepath, curr_backup_file);
+                        spdlog::debug("moved back {} -> {}", filepath.string(), curr_backup_file.string());
+                    }
+                    else {
+                        spdlog::debug("?? backed up data, {} missing", curr_backup_file.string());
+                        if (++missing_backup > 3) break;
+                    }
+                }
+                if (not new_storage) {
+                    CtDialogs::error_dialog(_("Failed to Load from Backup Data"), *this);
+                    fs::move_file(filepath_parked, filepath);
+                    spdlog::debug("unparked {} -> {}", filepath_parked.string(), filepath.string());
+                }
+            }
+        }
+        if (not new_storage) {
+            return false; // show the given document is not loaded
         }
-        return false; // show the given document is not loaded
     }
 
     _uCtStorage.reset(new_storage);
@@ -213,7 +246,7 @@ bool CtMainWin::file_open(const fs::path& filepath,
         CtTreeIter node = get_tree_store().get_node_from_node_name(node_to_focus);
         if (node) {
             _uCtTreeview->set_cursor_safe(node);
-            _ctTextview.grab_focus();
+            _ctTextview.mm().grab_focus();
             node_is_set = true;
             if (not anchor_to_focus.empty()) {
                 _uCtActions->current_node_scroll_to_anchor(anchor_to_focus);
@@ -236,7 +269,7 @@ bool CtMainWin::file_open(const fs::path& filepath,
         else {
             _uCtTreestore->treeview_set_tree_path_n_text_cursor(_uCtTreeview.get(), "0", 0, 0);
         }
-        _ctTextview.grab_focus();
+        _ctTextview.mm().grab_focus();
     }
 
     if (iterDocsRestore != _pCtConfig->recentDocsRestore.end()) {
@@ -250,6 +283,10 @@ bool CtMainWin::file_open(const fs::path& filepath,
     _pCtConfig->recentDocsFilepaths.move_or_push_front(fs::canonical(filepath));
     menu_set_items_recent_documents();
 
+    if (not error_or_warning.empty()) {
+        CtDialogs::warning_dialog(str::xml_escape(error_or_warning), *this);
+    }
+
     return true;
 }
 
@@ -408,19 +445,18 @@ void CtMainWin::mod_time_sentinel_restart()
 
 bool CtMainWin::file_insert_plain_text(const fs::path& filepath)
 {
-    spdlog::debug("trying to insert text file as node: {}", filepath);
+    spdlog::debug("trying to insert text file as node: {}", filepath.string());
     try {
-        std::string node_contents = Glib::file_get_contents(filepath.string());
-        if (not node_contents.empty()) {
-            CtStrUtil::convert_if_not_utf8(node_contents, true/*sanitise*/);
-            std::string name = filepath.filename().string();
+        Glib::ustring utf8_text;
+        if (CtStrUtil::file_any_encoding_to_utf8(filepath.string(), utf8_text)) {
+            const std::string name = filepath.filename().string();
             _uCtActions->node_child_exist_or_create(Gtk::TreeIter{}, name);
-            _ctTextview.get_buffer()->insert(_ctTextview.get_buffer()->end(), node_contents);
+            _ctTextview.get_buffer()->insert(_ctTextview.get_buffer()->end(), utf8_text);
             return true;
         }
     }
     catch (std::exception& ex) {
-        spdlog::error("{}, what: {}, file: {}", __FUNCTION__, ex.what(), filepath);
+        spdlog::error("{}, what: {}, file: {}", __FUNCTION__, ex.what(), filepath.string());
     }
     return false;
 }
@@ -436,7 +472,7 @@ void CtMainWin::_ensure_curr_doc_in_recent_docs()
         const CtTreeIter prevTreeIter = curr_tree_iter();
         if (prevTreeIter) {
             prevDocRestore.node_path = _uCtTreestore->get_path(prevTreeIter).to_string();
-            const Glib::RefPtr<Gsv::Buffer> rTextBuffer = prevTreeIter.get_node_text_buffer();
+            const Glib::RefPtr<Gtk::TextBuffer> rTextBuffer = prevTreeIter.get_node_text_buffer();
             prevDocRestore.cursor_pos = rTextBuffer->property_cursor_position();
             prevDocRestore.v_adj_val = round(_scrolledwindowText.get_vadjustment()->get_value());
         }
