@@ -1,7 +1,7 @@
 /*
  * ct_menu.cc
  *
- * Copyright 2009-2023
+ * Copyright 2009-2024
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -107,7 +107,7 @@ CtMenu::CtMenu(CtMainWin* pCtMainWin)
     return nullptr;
 }
 
-std::vector<Gtk::Toolbar*> CtMenu::build_toolbars(Gtk::MenuToolButton*& pRecentDocsMenuToolButton)
+std::vector<Gtk::Toolbar*> CtMenu::build_toolbars(Gtk::MenuToolButton*& pRecentDocsMenuToolButton, Gtk::ToolButton*& pToolButtonSave)
 {
     pRecentDocsMenuToolButton = nullptr;
     std::vector<Gtk::Toolbar*> toolbars;
@@ -119,6 +119,9 @@ std::vector<Gtk::Toolbar*> CtMenu::build_toolbars(Gtk::MenuToolButton*& pRecentD
         if (not pRecentDocsMenuToolButton) {
             _rGtkBuilder->get_widget("RecentDocs", pRecentDocsMenuToolButton);
         }
+        if (not pToolButtonSave) {
+            _rGtkBuilder->get_widget("ct_save", pToolButtonSave);
+        }
     }
     return toolbars;
 }
@@ -253,6 +256,7 @@ void CtMenu::build_popup_menu(Gtk::Menu* pMenu, POPUP_MENU_TYPE popupMenuType)
             _add_menu_separator(pMenu);
             _add_menu_item(pMenu, find_action("codebox_cut"));
             _add_menu_item(pMenu, find_action("codebox_copy"));
+            _add_menu_item(pMenu, find_action("codebox_copy_content"));
             _add_menu_item(pMenu, find_action("codebox_delete"));
             _add_menu_item(pMenu, find_action("codebox_delete_keeping_text"));
             _add_menu_separator(pMenu);
