@@ -46,7 +46,10 @@
 #ifdef _WIN32
 #include <windows.h>
 #include <shellapi.h>
-#endif // _WIN32
+#define WEXITSTATUS(x) x
+#else // !_WIN32
+#include <sys/wait.h> // WEXITSTATUS __FreeBSD__ (#1550)
+#endif // !_WIN32
 
 CtCSV::CtStringTable CtCSV::table_from_csv(const std::string& filepath)
 {
@@ -277,6 +280,54 @@ CtMiscUtil::URI_TYPE CtMiscUtil::get_uri_type(const std::string &uri)
     else return URI_TYPE::UNKNOWN;
 }
 
+bool CtMiscUtil::system_cmd(const char* shell_cmd, const char* cwd)
+{
+    bool success{false};
+#ifdef _WIN32
+    glong utf16text_len;
+    g_autofree gunichar2* utf16_lpCommandLine = g_utf8_to_utf16(shell_cmd, (glong)Glib::ustring{shell_cmd}.bytes(), nullptr, &utf16text_len, nullptr);
+    g_autofree gunichar2* utf16_lpCurrentDirectory = cwd[0] ? g_utf8_to_utf16(cwd, (glong)Glib::ustring{cwd}.bytes(), nullptr, &utf16text_len, nullptr) : NULL;
+    STARTUPINFOW si;
+    PROCESS_INFORMATION pi;
+    ZeroMemory(&si, sizeof(si));
+    si.cb = sizeof(si);
+    ZeroMemory(&pi, sizeof(pi));
+    success = CreateProcessW(NULL/*lpApplicationName*/,
+                             (LPWSTR)utf16_lpCommandLine,
+                             NULL/*lpProcessAttributes*/,
+                             NULL/*lpThreadAttributes*/,
+                             FALSE/*bInheritHandles*/,
+                             CREATE_NO_WINDOW/*dwCreationFlags*/,
+                             NULL/*lpEnvironment*/,
+                             (LPCWSTR)utf16_lpCurrentDirectory,
+                             &si, &pi);
+    if (success) {
+        WaitForSingleObject(pi.hProcess, INFINITE);
+        DWORD exit_code;
+        GetExitCodeProcess(pi.hProcess, &exit_code);
+        CloseHandle(pi.hProcess);
+        CloseHandle(pi.hThread);
+        if (0 != exit_code) {
+            spdlog::error("!! GetExitCodeProcess(cmd='{}' cwd='{}') returned {}", shell_cmd, cwd, exit_code);
+            success = false;
+        }
+    }
+    else {
+        spdlog::error("!! CreateProcessW(cmd='{}' cwd='{}')", shell_cmd, cwd);
+    }
+#else /* !_WIN32 */
+    (void)cwd;
+    const int retVal = std::system(shell_cmd);
+    if (WEXITSTATUS(retVal) != 0) {
+        spdlog::error("!! system({}) returned {}", shell_cmd, retVal);
+    }
+    else {
+        success = true;
+    }
+#endif /* !_WIN32 */
+    return success;
+}
+
 // analog to tbb::parallel_for
 void CtMiscUtil::parallel_for(size_t first, size_t last, std::function<void(size_t)> f)
 {
@@ -315,6 +366,19 @@ void CtMiscUtil::parallel_for(size_t first, size_t last, std::function<void(size
         task.join();
 }
 
+std::optional<Glib::ustring> CtTextIterUtil::iter_get_tag_startingwith(const Gtk::TextIter& iter, const Glib::ustring& tag_startwith)
+{
+    for (const auto& iter_tag : iter.get_tags()) {
+        Glib::ustring tag_name;
+        iter_tag->get_property("name", tag_name);
+        //spdlog::debug("TAG: {}", tag_name);
+        if (str::startswith(tag_name, tag_startwith)) {
+            return tag_name;
+        }
+    }
+    return std::nullopt;
+}
+
 Glib::ustring CtTextIterUtil::get_selected_text(Glib::RefPtr<Gtk::TextBuffer> pTextBuffer)
 {
     Gtk::TextIter iter_sel_start, iter_sel_end;
@@ -324,33 +388,24 @@ Glib::ustring CtTextIterUtil::get_selected_text(Glib::RefPtr<Gtk::TextBuffer> pT
     return Glib::ustring{};
 }
 
-// Returns True if the characters compose a camel case word
-bool CtTextIterUtil::get_is_camel_case(Gtk::TextIter iter_start, int num_chars)
+bool CtTextIterUtil::get_is_camel_case(Gtk::TextIter text_iter, int num_chars)
 {
-    Gtk::TextIter text_iter = iter_start;
-    int curr_state = 0;
-    auto re = Glib::Regex::create("\\w");
-    for (int i = 0; i < num_chars; ++i)
-    {
-        auto curr_char = text_iter.get_char();
-        bool alphanumeric = re->match(Glib::ustring(1, curr_char));
-        if (not alphanumeric)
-        {
+    int curr_state{0};
+    for (int i = 0; i < num_chars; ++i) {
+        const gunichar curr_char = text_iter.get_char();
+        if (not g_unichar_isalnum(curr_char)) {
             curr_state = -1;
             break;
         }
-        if (curr_state == 0)
-        {
+        if (curr_state == 0) {
             if (g_unichar_islower(curr_char))
                 curr_state = 1;
         }
-        else if (curr_state == 1)
-        {
+        else if (curr_state == 1) {
             if (g_unichar_isupper(curr_char))
                 curr_state = 2;
         }
-        else if (curr_state == 2)
-        {
+        else if (curr_state == 2) {
             if (g_unichar_islower(curr_char))
                 curr_state = 3;
         }
@@ -359,6 +414,85 @@ bool CtTextIterUtil::get_is_camel_case(Gtk::TextIter iter_start, int num_chars)
     return curr_state == 3;
 }
 
+bool CtTextIterUtil::startswith(Gtk::TextIter text_iter, const gchar* pChar)
+{
+    gunichar ch = g_utf8_get_char(pChar);
+    while (true) {
+        if (text_iter.get_char() != ch) {
+            return false;
+        }
+        pChar = g_utf8_next_char(pChar);
+        ch = g_utf8_get_char(pChar);
+        if (0 == ch) {
+            return true;
+        }
+        if (not text_iter.forward_char()) {
+            return false;
+        }
+    }
+}
+
+bool str::startswith_url(const gchar* pChar)
+{
+    // look for alpha://anything
+    int curr_state{0};
+    while (true) {
+        gunichar curr_char = g_utf8_get_char(pChar);
+        if (0 == curr_state) {
+            if (not g_unichar_isalpha(curr_char)) {
+                if (':' == curr_char) {
+                    ++curr_state;
+                }
+                else return false;
+            }
+        }
+        else if (1 == curr_state or 2 == curr_state) {
+            if ('/' == curr_char) {
+                ++curr_state;
+            }
+            else return false;
+        }
+        else if (3 == curr_state) {
+            return true;
+        }
+        pChar = g_utf8_next_char(pChar);
+        if (not pChar) {
+            return false;
+        }
+    }
+    return false;
+}
+
+bool CtTextIterUtil::startswith_url(Gtk::TextIter text_iter)
+{
+    // look for alpha://anything
+    int curr_state{0};
+    while (true) {
+        const gunichar curr_char = text_iter.get_char();
+        if (0 == curr_state) {
+            if (not g_unichar_isalpha(curr_char)) {
+                if (':' == curr_char) {
+                    ++curr_state;
+                }
+                else return false;
+            }
+        }
+        else if (1 == curr_state or 2 == curr_state) {
+            if ('/' == curr_char) {
+                ++curr_state;
+            }
+            else return false;
+        }
+        else if (3 == curr_state) {
+            return true;
+        }
+        if (not text_iter.forward_char()) {
+            return false;
+        }
+    }
+    return false;
+}
+
 bool CtTextIterUtil::rich_text_attributes_update(const Gtk::TextIter& text_iter, const CtCurrAttributesMap& curr_attributes, CtCurrAttributesMap& delta_attributes)
 {
     delta_attributes.clear();
@@ -368,17 +502,18 @@ bool CtTextIterUtil::rich_text_attributes_update(const Gtk::TextIter& text_iter,
         if (tag_name.empty() or CtConst::GTKSPELLCHECK_TAG_NAME == tag_name) {
             continue;
         }
-        if (str::startswith(tag_name, "weight_")) delta_attributes[CtConst::TAG_WEIGHT] = "";
-        else if (str::startswith(tag_name, "foreground_")) delta_attributes[CtConst::TAG_FOREGROUND] = "";
-        else if (str::startswith(tag_name, "background_")) delta_attributes[CtConst::TAG_BACKGROUND] = "";
-        else if (str::startswith(tag_name, "style_")) delta_attributes[CtConst::TAG_STYLE] = "";
-        else if (str::startswith(tag_name, "underline_")) delta_attributes[CtConst::TAG_UNDERLINE] = "";
-        else if (str::startswith(tag_name, "strikethrough_")) delta_attributes[CtConst::TAG_STRIKETHROUGH] = "";
-        else if (str::startswith(tag_name, "indent_")) delta_attributes[CtConst::TAG_INDENT] = "";
-        else if (str::startswith(tag_name, "scale_")) delta_attributes[CtConst::TAG_SCALE] = "";
-        else if (str::startswith(tag_name, "justification_")) delta_attributes[CtConst::TAG_JUSTIFICATION] = "";
-        else if (str::startswith(tag_name, "link_")) delta_attributes[CtConst::TAG_LINK] = "";
-        else if (str::startswith(tag_name, "family_")) delta_attributes[CtConst::TAG_FAMILY] = "";
+        if (str::startswith(tag_name, "weight_")) delta_attributes[CtConst::TAG_WEIGHT].clear();
+        else if (str::startswith(tag_name, "foreground_")) delta_attributes[CtConst::TAG_FOREGROUND].clear();
+        else if (str::startswith(tag_name, "background_")) delta_attributes[CtConst::TAG_BACKGROUND].clear();
+        else if (str::startswith(tag_name, "style_")) delta_attributes[CtConst::TAG_STYLE].clear();
+        else if (str::startswith(tag_name, "underline_")) delta_attributes[CtConst::TAG_UNDERLINE].clear();
+        else if (str::startswith(tag_name, "strikethrough_")) delta_attributes[CtConst::TAG_STRIKETHROUGH].clear();
+        else if (str::startswith(tag_name, "indent_")) delta_attributes[CtConst::TAG_INDENT].clear();
+        else if (str::startswith(tag_name, "scale_")) delta_attributes[CtConst::TAG_SCALE].clear();
+        else if (str::startswith(tag_name, "invisible_")) delta_attributes[CtConst::TAG_INVISIBLE].clear();
+        else if (str::startswith(tag_name, "justification_")) delta_attributes[CtConst::TAG_JUSTIFICATION].clear();
+        else if (str::startswith(tag_name, "link_")) delta_attributes[CtConst::TAG_LINK].clear();
+        else if (str::startswith(tag_name, "family_")) delta_attributes[CtConst::TAG_FAMILY].clear();
     }
     std::vector<Glib::RefPtr<const Gtk::TextTag>> toggled_on = text_iter.get_toggled_tags(true/*toggled_on*/);
     for (const auto& r_curr_tag : toggled_on) {
@@ -390,6 +525,7 @@ bool CtTextIterUtil::rich_text_attributes_update(const Gtk::TextIter& text_iter,
         else if (str::startswith(tag_name, "foreground_")) delta_attributes[CtConst::TAG_FOREGROUND] = tag_name.substr(11);
         else if (str::startswith(tag_name, "background_")) delta_attributes[CtConst::TAG_BACKGROUND] = tag_name.substr(11);
         else if (str::startswith(tag_name, "scale_")) delta_attributes[CtConst::TAG_SCALE] = tag_name.substr(6);
+        else if (str::startswith(tag_name, "invisible_")) delta_attributes[CtConst::TAG_INVISIBLE] = tag_name.substr(10);
         else if (str::startswith(tag_name, "justification_")) delta_attributes[CtConst::TAG_JUSTIFICATION] = tag_name.substr(14);
         else if (str::startswith(tag_name, "style_")) delta_attributes[CtConst::TAG_STYLE] = tag_name.substr(6);
         else if (str::startswith(tag_name, "underline_")) delta_attributes[CtConst::TAG_UNDERLINE] = tag_name.substr(10);
@@ -657,6 +793,19 @@ bool CtStrUtil::is_str_true(const Glib::ustring& inStr)
     return retVal;
 }
 
+int CtStrUtil::is_header_anchor_name(const Glib::ustring& anchorName)
+{
+    static Glib::RefPtr<Glib::Regex> pRegExpAnchorNamePattern = Glib::Regex::create("h(\\d+)-\\d+");
+    Glib::MatchInfo matchInfo;
+    if (pRegExpAnchorNamePattern->match(anchorName, matchInfo)) {
+        const int h_num = atoi(matchInfo.fetch(1).c_str());
+        if (h_num >= 1 and h_num <= 6) {
+            return h_num;
+        }
+    }
+    return 0;
+}
+
 gint64 CtStrUtil::gint64_from_gstring(const gchar* inGstring, bool hexPrefix)
 {
     gint64 retVal;
@@ -870,6 +1019,10 @@ void CtStrUtil::convert_if_not_utf8(std::string& inOutText, const bool sanitise)
                 inOutText = std::string{pConverted, bytes_written};
             }
         }
+        else {
+            spdlog::debug("!! {} pConverted", __FUNCTION__);
+            return;
+        }
     }
     else if (Glib::str_has_prefix(inOutText, "\xEF\xBB\xBF")) {
         // remove UTF-8 BOM
@@ -880,6 +1033,108 @@ void CtStrUtil::convert_if_not_utf8(std::string& inOutText, const bool sanitise)
     }
 }
 
+static bool _g_file_load_into_source_buffer(GFile* pGFile, GtkSourceBuffer* pGtkSourceBuffer)
+{
+    GtkSourceFile* pGtkSourceFile = gtk_source_file_new();
+    gtk_source_file_set_location(pGtkSourceFile, pGFile);
+    GtkSourceFileLoader* pGtkSourceFileLoader = gtk_source_file_loader_new(pGtkSourceBuffer, pGtkSourceFile);
+    int operationStatus{0};
+    auto f_GAsyncReadyCallback = [](GObject* pSourceObject, GAsyncResult* pRes, gpointer user_data){
+        g_autoptr(GError) pError{nullptr};
+        const bool retVal = gtk_source_file_loader_load_finish((GtkSourceFileLoader*)pSourceObject,
+                                                               pRes,
+                                                               &pError);
+        if (not retVal and pError) {
+            spdlog::warn("!! {} {}", __FUNCTION__, pError->message);
+        }
+        int* pOperationStatus = (int*)user_data;
+        *pOperationStatus = retVal ? 1 : -1;
+    };
+    gtk_source_file_loader_load_async(pGtkSourceFileLoader,
+                                      G_PRIORITY_HIGH,
+                                      NULL/*cancellable*/,
+                                      NULL/*progress_callback*/,
+                                      NULL/*progress_callback_data*/,
+                                      NULL/*progress_callback_notify*/,
+                                      f_GAsyncReadyCallback,
+                                      &operationStatus/*user_data*/);
+    while (0 == operationStatus) {
+        g_usleep(10000); // wait 10 msec
+        while (gtk_events_pending()) gtk_main_iteration();
+    }
+    g_object_unref(pGtkSourceFileLoader);
+    g_object_unref(pGtkSourceFile);
+    return operationStatus > 0;
+}
+
+bool CtStrUtil::file_any_encoding_load_into_source_buffer(const std::string& filepath, GtkSourceBuffer* pGtkSourceBuffer)
+{
+    GFile* pGFile = g_file_new_for_path(filepath.c_str());
+    const bool retVal = _g_file_load_into_source_buffer(pGFile, pGtkSourceBuffer);
+    g_object_unref(pGFile);
+    return retVal;
+}
+
+bool CtStrUtil::string_any_encoding_load_into_source_buffer(const char* pChar, GtkSourceBuffer* pGtkSourceBuffer)
+{
+    GFileIOStream* pGFileIOStream{NULL};
+    GFile* pGFile = g_file_new_tmp(NULL/*tmpl*/, &pGFileIOStream, NULL/*GError***/);
+    if (not pGFile or not pGFileIOStream or not g_output_stream_write_all(
+            g_io_stream_get_output_stream(G_IO_STREAM(pGFileIOStream)),
+            pChar,
+            strlen(pChar),
+            NULL/*bytes_written*/,
+            NULL/*cancellable*/,
+            NULL/*GError***/))
+    {
+        return false;
+    }
+    const bool retVal = _g_file_load_into_source_buffer(pGFile, pGtkSourceBuffer);
+    g_object_unref(pGFileIOStream);
+    g_object_unref(pGFile);
+    return retVal;
+}
+
+bool CtStrUtil::string_any_encoding_to_utf8(const char* pChar, Glib::ustring& utf8_text)
+{
+    GtkSourceBuffer* pGtkSourceBuffer = gtk_source_buffer_new(NULL);
+    if (CtStrUtil::string_any_encoding_load_into_source_buffer(pChar, pGtkSourceBuffer)) {
+        auto pGtkTextBuffer = GTK_TEXT_BUFFER(pGtkSourceBuffer);
+        GtkTextIter start, end;
+        gtk_text_buffer_get_start_iter(pGtkTextBuffer, &start);
+        gtk_text_buffer_get_end_iter(pGtkTextBuffer, &end);
+        g_autofree gchar* pText = gtk_text_buffer_get_text(pGtkTextBuffer, &start, &end, false/*include_hidden_chars*/);
+        if (pText) {
+            utf8_text = pText;
+            return true;
+        }
+    }
+    return false;
+}
+
+bool CtStrUtil::file_any_encoding_to_utf8(const std::string& filepath, Glib::ustring& utf8_text)
+{
+    GtkSourceBuffer* pGtkSourceBuffer = gtk_source_buffer_new(NULL);
+    if (CtStrUtil::file_any_encoding_load_into_source_buffer(filepath, pGtkSourceBuffer)) {
+        auto pGtkTextBuffer = GTK_TEXT_BUFFER(pGtkSourceBuffer);
+        GtkTextIter start, end;
+        gtk_text_buffer_get_start_iter(pGtkTextBuffer, &start);
+        gtk_text_buffer_get_end_iter(pGtkTextBuffer, &end);
+        g_autofree gchar* pText = gtk_text_buffer_get_text(pGtkTextBuffer, &start, &end, false/*include_hidden_chars*/);
+        if (pText) {
+            if (g_str_has_prefix(pText, "\xEF\xBB\xBF")) {
+                // remove UTF-8 BOM
+                utf8_text = pText+3;
+            }
+            else {
+                utf8_text = pText;
+            }
+            return true;
+        }
+    }
+    return false;
+}
+
 Glib::ustring CtFontUtil::get_font_family(const Glib::ustring& fontStr)
 {
     try {
@@ -1056,7 +1311,7 @@ int str::indexOf(const Glib::ustring& str, const gunichar& uc)
     return index != std::string::npos ? static_cast<int>(index) : -1;
 }
 
-Glib::ustring str::xml_escape(const Glib::ustring& text)
+std::string str::xml_escape(const Glib::ustring& text)
 {
     Glib::ustring buffer;
     buffer.reserve(text.size());
@@ -1071,13 +1326,13 @@ Glib::ustring str::xml_escape(const Glib::ustring& text)
             default:   buffer.append(1, *ch);        break;
         }
     }
-    return buffer;
+    return buffer.raw();
 }
 
 Glib::ustring str::sanitize_bad_symbols(const Glib::ustring& xml_content)
 {
     // remove everything forbidden by XML 1.0 specifications
-    Glib::RefPtr<Glib::Regex> re_pattern = Glib::Regex::create("[^\x09\x0A\x0D\x20-\xFF\x85\xA0-\uD7FF\uE000-\uFDCF\uFDE0-\uFFFD]");
+    static Glib::RefPtr<Glib::Regex> re_pattern = Glib::Regex::create("[^\x09\x0A\x0D\x20-\xFF\x85\xA0-\uD7FF\uE000-\uFDCF\uFDE0-\uFFFD]");
     return re_pattern->replace(xml_content, 0/*start_position*/, "", static_cast<Glib::RegexMatchFlags>(0u));
 }
 
