@@ -25,9 +25,9 @@
 
 #include "ct_types.h"
 #include "ct_logging.h"
-#include <gtksourceviewmm.h>
 #include <gtkmm/treeiter.h>
 #include <gtkmm/treestore.h>
+#include <gtksourceview/gtksource.h>
 
 class CtConfig;
 class CtTreeIter;
@@ -44,6 +44,8 @@ std::string table_to_csv(const CtStringTable& table);
 
 namespace CtMiscUtil {
 
+bool system_cmd(const char* shell_cmd, const char* cwd);
+
 std::string get_ct_language();
 
 std::string get_doc_extension(const CtDocType ctDocType, const CtDocEncrypt ctDocEncrypt);
@@ -117,23 +119,13 @@ bool text_file_set_contents_add_cr_on_win(const std::string& filepath, const std
 
 namespace CtTextIterUtil {
 
+std::optional<Glib::ustring> iter_get_tag_startingwith(const Gtk::TextIter& iter, const Glib::ustring& tag_startwith);
+
 bool get_is_camel_case(Gtk::TextIter iter_start, int num_chars);
 
-inline bool startswith(Gtk::TextIter text_iter, const gchar* str)
-{
-    gunichar ch = g_utf8_get_char(str);
-    while (true)
-    {
-        if (text_iter.get_char() != ch)
-            return false;
-        str = g_utf8_next_char(str);
-        ch = g_utf8_get_char(str);
-        if (ch == 0)
-            return true;
-        if (!text_iter.forward_char())
-            return false;
-    }
-}
+bool startswith(Gtk::TextIter text_iter, const gchar* pChar);
+
+bool startswith_url(Gtk::TextIter text_iter);
 
 Glib::ustring get_selected_text(Glib::RefPtr<Gtk::TextBuffer> pTextBuffer);
 
@@ -197,6 +189,8 @@ std::vector<bool> get_rtl_for_lines(const Glib::ustring& text);
 
 bool is_str_true(const Glib::ustring& inStr);
 
+int is_header_anchor_name(const Glib::ustring& anchorName);
+
 gint64 gint64_from_gstring(const gchar* inGstring, bool hexPrefix=false);
 
 guint32 guint32_from_hex_chars(const char* hexChars, guint8 numChars);
@@ -260,6 +254,12 @@ bool is_codeset_not_utf8(const std::string& codeset);
 
 void convert_if_not_utf8(std::string& inOutText, const bool sanitise);
 
+bool string_any_encoding_load_into_source_buffer(const char* pChar, GtkSourceBuffer* pGtkSourceBuffer);
+bool string_any_encoding_to_utf8(const char* pChar, Glib::ustring& utf8_text);
+
+bool file_any_encoding_load_into_source_buffer(const std::string& filepath, GtkSourceBuffer* pGtkSourceBuffer);
+bool file_any_encoding_to_utf8(const std::string& filepath, Glib::ustring& utf8_text);
+
 } // namespace CtStrUtil
 
 namespace CtFontUtil {
@@ -298,6 +298,8 @@ namespace str {
 
 bool startswith(const std::string& str, const std::string& starting);
 
+bool startswith_url(const gchar* pChar);
+
 template<class container>
 bool startswith_any(const Glib::ustring& text, const container& chars_list)
 {
@@ -322,7 +324,7 @@ int indexOf(const std::array<T, size>& array, const T& uc)
     return -1;
 }
 
-Glib::ustring xml_escape(const Glib::ustring& text);
+std::string xml_escape(const Glib::ustring& text);
 
 Glib::ustring sanitize_bad_symbols(const Glib::ustring& xml_content);
 
