@@ -1,7 +1,7 @@
 /*
  * ct_parser_html.cc
  *
- * Copyright 2009-2023
+ * Copyright 2009-2024
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -504,7 +504,7 @@ void CtHtml2Xml::_pop_tag_styles()
 {
     // every tag has at least one style
     int tag_id = _tag_styles.back().tag_id;
-    while (_tag_styles.back().tag_id == tag_id)
+    while (!_tag_styles.empty() && _tag_styles.back().tag_id == tag_id)
         _tag_styles.pop_back();
 }
 
@@ -566,7 +566,7 @@ std::string CtHtml2Xml::_convert_html_color(const std::string& html_color)
         return ""; // though I think it should explicitly return black/white
 
 
-    return CtRgbUtil::rgb_any_to_24(rgba);
+    return CtRgbUtil::rgb_to_string_24(rgba);
 }
 
 // Insert Image in Buffer
