@@ -1,7 +1,7 @@
 /*
  * ct_parser_md.cc
  *
- * Copyright 2009-2021
+ * Copyright 2009-2022
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -56,8 +56,7 @@ std::vector<CtTextParser::token_schema> CtMDParser::_token_schemas()
     };
     auto add_list = [this](const std::string& text) {
         doc_builder().add_list(_list_level, "");
-        std::istringstream ss(text);
-        feed(ss);
+        feed(text);
         doc_builder().add_newline();
         _list_level = 0;
     };
@@ -192,31 +191,24 @@ std::vector<CtTextParser::token_schema> CtMDParser::_token_schemas()
 
 void CtMDParser::_place_free_text()
 {
-    std::string free_txt = _free_text.str();
-    if (!free_txt.empty()) {
-        auto iter = free_txt.crbegin();
-        for (;iter != free_txt.crend(); ++iter) {
+    if (!_free_text.empty()) {
+        auto iter = _free_text.rbegin();
+        for (; iter != _free_text.rend(); ++iter) {
             if (*iter == '\n') break;
         }
-        std::string last_line(iter.base(), free_txt.cend());
-        std::string other_txt(free_txt.cbegin(), iter.base());
+        Glib::ustring last_line{iter.base(), _free_text.end()};
+        Glib::ustring other_txt{_free_text.begin(), iter.base()};
         doc_builder().add_text(other_txt);
         doc_builder().add_text(last_line); // This may be needed for headers
 
-        std::ostringstream tmp_ss;
-        _free_text.swap(tmp_ss);
+        _free_text.clear();
     }
 }
 
-void CtMDParser::feed(std::istream& stream)
+void CtMDParser::feed(const std::string& buffer)
 {
-    std::string line;
-    std::ostringstream in_stream;
-    in_stream << stream.rdbuf();
-
-    // Feed the line
     try {
-        auto tokens_raw = _text_parser->tokenize(in_stream.str());
+        auto tokens_raw = _text_parser->tokenize(buffer);
         auto tokens     = _text_parser->parse_tokens(tokens_raw);
 
         for (auto iter = tokens.begin(); iter != tokens.end(); ++iter) {
@@ -233,16 +225,16 @@ void CtMDParser::feed(std::istream& stream)
                         continue;
                     }
                 }
-
                 iter->first->action(iter->second);
-            } else {
+            }
+            else {
                 if (!iter->second.empty()) {
                     if (!_current_table.empty() && iter->second == "\n") {
                         _pop_table();
                         doc_builder().add_newline();
                     }
                     if (_current_table.empty()) {
-                        _free_text.write(iter->second.c_str(), iter->second.size());
+                        _free_text += iter->second;
                     }
                 }
             }
@@ -250,12 +242,13 @@ void CtMDParser::feed(std::istream& stream)
         }
         if (!_current_table.empty()) _pop_table();
         _place_free_text();
-    } catch (std::exception& e) {
-        spdlog::error("Exception while parsing line: '{}': {}", line, e.what());
+    }
+    catch (std::exception& e) {
+        spdlog::error("Exception while parsing '{}': {}", buffer, e.what());
     }
 }
 
-void CtMDParser::_add_table_cell(std::string text)
+void CtMDParser::_add_table_cell(const std::string& text)
 {
     if (!text.empty()) {
         // Parse it to see if a cell or end of row
