@@ -1,7 +1,7 @@
 /*
  * ct_pref_dlg_misc.cc
  *
- * Copyright 2009-2023
+ * Copyright 2009-2024
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -26,22 +26,10 @@
 
 Gtk::Widget* CtPrefDlg::build_tab_misc()
 {
-    auto vbox_system_tray = Gtk::manage(new Gtk::Box{Gtk::ORIENTATION_VERTICAL});
-    auto checkbutton_systray = Gtk::manage(new Gtk::CheckButton{_("Enable System Tray Docking")});
-    auto checkbutton_start_on_systray = Gtk::manage(new Gtk::CheckButton{_("Start Minimized in the System Tray")});
-    vbox_system_tray->pack_start(*checkbutton_systray, false, false);
-    vbox_system_tray->pack_start(*checkbutton_start_on_systray, false, false);
-
-    Gtk::Frame* frame_system_tray = new_managed_frame_with_align(_("System Tray"), vbox_system_tray);
-
-    checkbutton_systray->set_active(_pConfig->systrayOn);
-    checkbutton_start_on_systray->set_active(_pConfig->startOnSystray);
-    checkbutton_start_on_systray->set_sensitive(_pConfig->systrayOn);
-
     auto vbox_saving = Gtk::manage(new Gtk::Box{Gtk::ORIENTATION_VERTICAL});
     auto hbox_autosave = Gtk::manage(new Gtk::Box{Gtk::ORIENTATION_HORIZONTAL, 4/*spacing*/});
     auto checkbutton_autosave = Gtk::manage(new Gtk::CheckButton{_("Autosave Every")});
-    Glib::RefPtr<Gtk::Adjustment> adjustment_autosave = Gtk::Adjustment::create(_pConfig->autosaveVal, 1, 1000, 1);
+    Glib::RefPtr<Gtk::Adjustment> adjustment_autosave = Gtk::Adjustment::create(_pConfig->autosaveMinutes, 1, 1000, 1);
     auto spinbutton_autosave = Gtk::manage(new Gtk::SpinButton(adjustment_autosave));
     auto label_autosave = Gtk::manage(new Gtk::Label{_("Minutes")});
     hbox_autosave->pack_start(*checkbutton_autosave, false, false);
@@ -71,7 +59,7 @@ Gtk::Widget* CtPrefDlg::build_tab_misc()
     vbox_saving->pack_start(*hbox_custom_backup_dir, false, false);
 
     checkbutton_autosave->set_active(_pConfig->autosaveOn);
-    spinbutton_autosave->set_value(_pConfig->autosaveVal);
+    spinbutton_autosave->set_value(_pConfig->autosaveMinutes);
     spinbutton_autosave->set_sensitive(_pConfig->autosaveOn);
     checkbutton_autosave_on_quit->set_active(_pConfig->autosaveOnQuit);
     checkbutton_backup_before_saving->set_active(_pConfig->backupCopy);
@@ -84,12 +72,8 @@ Gtk::Widget* CtPrefDlg::build_tab_misc()
 
     auto vbox_misc_misc = Gtk::manage(new Gtk::Box{Gtk::ORIENTATION_VERTICAL});
     auto checkbutton_newer_version = Gtk::manage(new Gtk::CheckButton{_("Automatically Check for Newer Version")});
-    auto checkbutton_word_count = Gtk::manage(new Gtk::CheckButton{_("Enable Word Count in Statusbar")});
     auto checkbutton_reload_doc_last = Gtk::manage(new Gtk::CheckButton{_("Reload Document From Last Session")});
     auto checkbutton_mod_time_sentinel = Gtk::manage(new Gtk::CheckButton{_("Reload After External Update to CT* File")});
-    auto checkbutton_win_title_doc_dir = Gtk::manage(new Gtk::CheckButton{_("Show the Document Directory in the Window Title")});
-    auto checkbutton_nn_header_full_path = Gtk::manage(new Gtk::CheckButton{_("Show the Full Path in the Node Name Header")});
-    auto checkbutton_bookmarks_top_menu = Gtk::manage(new Gtk::CheckButton{_("Dedicated Bookmarks Menu in Menubar")});
     auto checkbutton_debug_log = Gtk::manage(new Gtk::CheckButton{_("Enable Debug Log")});
     auto file_chooser_button_debug_log_dir = Gtk::manage(new Gtk::FileChooserButton{_("Debug Log Directory"),
                                                                                     Gtk::FileChooserAction::FILE_CHOOSER_ACTION_SELECT_FOLDER});
@@ -107,24 +91,28 @@ Gtk::Widget* CtPrefDlg::build_tab_misc()
     hbox_debug_log->pack_start(*checkbutton_debug_log, false, false);
     hbox_debug_log->pack_start(*file_chooser_button_debug_log_dir);
     vbox_misc_misc->pack_start(*checkbutton_newer_version, false, false);
-    vbox_misc_misc->pack_start(*checkbutton_word_count, false, false);
     vbox_misc_misc->pack_start(*checkbutton_reload_doc_last, false, false);
     vbox_misc_misc->pack_start(*checkbutton_mod_time_sentinel, false, false);
-    vbox_misc_misc->pack_start(*checkbutton_win_title_doc_dir, false, false);
-    vbox_misc_misc->pack_start(*checkbutton_nn_header_full_path, false, false);
-    vbox_misc_misc->pack_start(*checkbutton_bookmarks_top_menu, false, false);
     vbox_misc_misc->pack_start(*hbox_debug_log, false, false);
 
     checkbutton_newer_version->set_active(_pConfig->checkVersion);
-    checkbutton_word_count->set_active(_pConfig->wordCountOn);
     checkbutton_reload_doc_last->set_active(_pConfig->reloadDocLast);
     checkbutton_mod_time_sentinel->set_active(_pConfig->modTimeSentinel);
-    checkbutton_win_title_doc_dir->set_active(_pConfig->winTitleShowDocDir);
-    checkbutton_nn_header_full_path->set_active(_pConfig->nodeNameHeaderShowFullPath);
-    checkbutton_bookmarks_top_menu->set_active(_pConfig->bookmarksInTopMenu);
 
     Gtk::Frame* frame_misc_misc = new_managed_frame_with_align(_("Miscellaneous"), vbox_misc_misc);
 
+    auto vbox_system_tray = Gtk::manage(new Gtk::Box{Gtk::ORIENTATION_VERTICAL});
+    auto checkbutton_systray = Gtk::manage(new Gtk::CheckButton{_("Enable System Tray Docking")});
+    auto checkbutton_start_on_systray = Gtk::manage(new Gtk::CheckButton{_("Start Minimized in the System Tray")});
+    vbox_system_tray->pack_start(*checkbutton_systray, false, false);
+    vbox_system_tray->pack_start(*checkbutton_start_on_systray, false, false);
+
+    Gtk::Frame* frame_system_tray = new_managed_frame_with_align(_("System Tray"), vbox_system_tray);
+
+    checkbutton_systray->set_active(_pConfig->systrayOn);
+    checkbutton_start_on_systray->set_active(_pConfig->startOnSystray);
+    checkbutton_start_on_systray->set_sensitive(_pConfig->systrayOn);
+
 #ifdef HAVE_NLS
     auto f_getButtonLabel = [this](const std::string langCode)->Glib::ustring{
         auto it = _mapCountryLanguages.find(langCode);
@@ -144,49 +132,20 @@ Gtk::Widget* CtPrefDlg::build_tab_misc()
     auto pMainBox = Gtk::manage(new Gtk::Box{Gtk::ORIENTATION_VERTICAL, 3/*spacing*/});
     pMainBox->set_margin_left(6);
     pMainBox->set_margin_top(6);
-    pMainBox->pack_start(*frame_system_tray, false, false);
     pMainBox->pack_start(*frame_saving, false, false);
     pMainBox->pack_start(*frame_misc_misc, false, false);
+    pMainBox->pack_start(*frame_system_tray, false, false);
 #ifdef HAVE_NLS
     pMainBox->pack_start(*frame_language, false, false);
 #endif
 
-    // cannot just turn on systray icon, we have to check if systray exists
-    checkbutton_systray->signal_toggled().connect([this, checkbutton_systray, checkbutton_start_on_systray](){
-        if (checkbutton_systray->get_active()) {
-            _pCtMainWin->get_status_icon()->set_visible(true);
-#if defined(_WIN32)
-            _pConfig->systrayOn = true; // windows does support the systray
-#else // !_WIN32
-            _pConfig->systrayOn = CtDialogs::question_dialog(_("Has the System Tray appeared on the panel?"), *this);
-#endif // !_WIN32
-            if (_pConfig->systrayOn) {
-                checkbutton_start_on_systray->set_sensitive(true);
-                apply_for_each_window([](CtMainWin* win) { win->menu_set_visible_exit_app(true); });
-            }
-            else {
-                CtDialogs::warning_dialog(_("Your system does not support the System Tray"), *this);
-                checkbutton_systray->set_active(false);
-            }
-        }
-        else {
-            _pConfig->systrayOn = false;
-            _pCtMainWin->get_status_icon()->set_visible(false);
-            apply_for_each_window([](CtMainWin* win) { win->menu_set_visible_exit_app(false); });
-            checkbutton_start_on_systray->set_sensitive(false);
-        }
-        checkbutton_systray->get_parent()->grab_focus();
-    });
-    checkbutton_start_on_systray->signal_toggled().connect([this, checkbutton_start_on_systray](){
-        _pConfig->startOnSystray = checkbutton_start_on_systray->get_active();
-    });
     checkbutton_autosave->signal_toggled().connect([this, checkbutton_autosave, spinbutton_autosave](){
         _pConfig->autosaveOn = checkbutton_autosave->get_active();
         _pCtMainWin->file_autosave_restart();
         spinbutton_autosave->set_sensitive(_pConfig->autosaveOn);
     });
     spinbutton_autosave->signal_value_changed().connect([this, spinbutton_autosave](){
-        _pConfig->autosaveVal = spinbutton_autosave->get_value_as_int();
+        _pConfig->autosaveMinutes = spinbutton_autosave->get_value_as_int();
         _pCtMainWin->file_autosave_restart();
     });
     checkbutton_autosave_on_quit->signal_toggled().connect([this, checkbutton_autosave_on_quit](){
@@ -230,25 +189,40 @@ Gtk::Widget* CtPrefDlg::build_tab_misc()
         _pConfig->modTimeSentinel = checkbutton_mod_time_sentinel->get_active();
         _pCtMainWin->mod_time_sentinel_restart();
     });
-    checkbutton_win_title_doc_dir->signal_toggled().connect([this, checkbutton_win_title_doc_dir](){
-        _pConfig->winTitleShowDocDir = checkbutton_win_title_doc_dir->get_active();
-        _pCtMainWin->window_title_update();
-    });
-    checkbutton_nn_header_full_path->signal_toggled().connect([this, checkbutton_nn_header_full_path](){
-        _pConfig->nodeNameHeaderShowFullPath = checkbutton_nn_header_full_path->get_active();
-        _pCtMainWin->window_header_update();
-    });
-    checkbutton_bookmarks_top_menu->signal_toggled().connect([this, checkbutton_bookmarks_top_menu](){
-        _pConfig->bookmarksInTopMenu = checkbutton_bookmarks_top_menu->get_active();
-        _pCtMainWin->menu_top_optional_bookmarks_enforce();
-    });
     checkbutton_newer_version->signal_toggled().connect([this, checkbutton_newer_version](){
         _pConfig->checkVersion = checkbutton_newer_version->get_active();
     });
-    checkbutton_word_count->signal_toggled().connect([this, checkbutton_word_count](){
-        _pConfig->wordCountOn = checkbutton_word_count->get_active();
-        apply_for_each_window([](CtMainWin* win) { win->update_selected_node_statusbar_info(); });
+
+    // cannot just turn on systray icon, we have to check if systray exists
+    checkbutton_systray->signal_toggled().connect([this, checkbutton_systray, checkbutton_start_on_systray](){
+        if (checkbutton_systray->get_active()) {
+            _pCtMainWin->get_status_icon()->set_visible(true);
+#if defined(_WIN32)
+            _pConfig->systrayOn = true; // windows does support the systray
+#else // !_WIN32
+            _pConfig->systrayOn = CtDialogs::question_dialog(_("Has the System Tray appeared on the panel?"), *this);
+#endif // !_WIN32
+            if (_pConfig->systrayOn) {
+                checkbutton_start_on_systray->set_sensitive(true);
+                apply_for_each_window([](CtMainWin* win) { win->menu_set_visible_exit_app(true); });
+            }
+            else {
+                CtDialogs::warning_dialog(_("Your system does not support the System Tray"), *this);
+                checkbutton_systray->set_active(false);
+            }
+        }
+        else {
+            _pConfig->systrayOn = false;
+            _pCtMainWin->get_status_icon()->set_visible(false);
+            apply_for_each_window([](CtMainWin* win) { win->menu_set_visible_exit_app(false); });
+            checkbutton_start_on_systray->set_sensitive(false);
+        }
+        checkbutton_systray->get_parent()->grab_focus();
     });
+    checkbutton_start_on_systray->signal_toggled().connect([this, checkbutton_start_on_systray](){
+        _pConfig->startOnSystray = checkbutton_start_on_systray->get_active();
+    });
+
 #ifdef HAVE_NLS
     button_country_language->signal_clicked().connect([this, button_country_language, f_getStockId, f_getButtonLabel](){
 
@@ -286,5 +260,6 @@ Gtk::Widget* CtPrefDlg::build_tab_misc()
         }
     });
 #endif
+
     return pMainBox;
 }
