@@ -33,6 +33,8 @@
 
 //#define DEBUG_BACKUP_ENCRYPT
 
+static const std::string BAD_ARCHIVE{"_BAD_ARC_"};
+
 /*static*/std::unique_ptr<CtStorageEntity> CtStorageControl::_get_entity_by_type(CtMainWin* pCtMainWin, CtDocType file_type)
 {
     if (CtDocType::SQLite == file_type) {
@@ -75,14 +77,17 @@
                     // user canceled operation
                     return nullptr;
                 }
+                if (extracted_file_path.string() == BAD_ARCHIVE) {
+                    throw std::runtime_error(str::format(_("'%s' is Not a Valid Archive"), file_path.string()));
+                }
             }
         }
 
-        // choose storage type
+        // detect storage type
         std::unique_ptr<CtStorageEntity> pStorage = CtStorageControl::_get_entity_by_type(pCtMainWin, doc_type);
         if (not pStorage) throw std::runtime_error("no storage");
 
-        // load from file
+        // load from file / folder
         if (not pStorage->populate_treestore(extracted_file_path, error)) throw std::runtime_error(error);
 
         // it's ready
@@ -113,6 +118,42 @@
     return storage->populate_treestore(file_path, error);
 }
 
+/*static*/void CtStorageControl::get_first_backup_file_or_dir(std::string& out_first_backup_file_or_dir,
+                                                              const std::string& file_or_dir_path,
+                                                              const CtConfig* pCtConfig)
+{
+    // backups with tildas can either be in the same directory where the db is or in a custom backup dir
+    // main_backup is always in the same directory of the main db
+    auto get_custom_backup_file_or_dir = [&]()->std::string {
+        // backup path in custom dir: /custom_dir/full_file_path/filename.ext~
+        std::string hash_dir = file_or_dir_path;
+        for (auto str : {"\\", "/", ":", "?"}) {
+            hash_dir = str::replace(hash_dir, str, "_");
+        }
+        std::string first_backup_dir = Glib::build_filename(pCtConfig->customBackupDir, hash_dir);
+        Glib::RefPtr<Gio::File> dir_file = Gio::File::create_for_path(first_backup_dir);
+        try {
+            if (not dir_file->query_exists() and not dir_file->make_directory_with_parents()) {
+                spdlog::error("failed to create backup directory: {}", first_backup_dir);
+                return "";
+            }
+            return Glib::build_filename(first_backup_dir, CtConst::CHAR_DOT + Glib::path_get_basename(file_or_dir_path)) + CtConst::CHAR_TILDE;
+        }
+        catch (Glib::Error& ex) {
+            spdlog::error("failed to create backup directory: {}, \n{}", first_backup_dir, ex.what().raw());
+            return "";
+        }
+    };
+
+    if (pCtConfig->customBackupDirOn and not pCtConfig->customBackupDir.empty()) {
+        out_first_backup_file_or_dir = get_custom_backup_file_or_dir();
+    }
+    if (out_first_backup_file_or_dir.empty()) {
+        out_first_backup_file_or_dir = Glib::build_filename(Glib::path_get_dirname(file_or_dir_path),
+            CtConst::CHAR_DOT + Glib::path_get_basename(file_or_dir_path) + CtConst::CHAR_TILDE);
+    }
+}
+
 /*static*/CtStorageControl* CtStorageControl::save_as(CtMainWin* pCtMainWin,
                                                       const fs::path& file_path,
                                                       const CtDocType doc_type,
@@ -363,13 +404,13 @@ bool CtStorageControl::save(bool need_vacuum, Glib::ustring &error)
     }
 }
 
-Glib::RefPtr<Gsv::Buffer> CtStorageControl::get_delayed_text_buffer(const gint64 node_id,
-                                                                    const std::string& syntax,
-                                                                    std::list<CtAnchoredWidget*>& widgets) const
+Glib::RefPtr<Gtk::TextBuffer> CtStorageControl::get_delayed_text_buffer(const gint64 node_id,
+                                                                        const std::string& syntax,
+                                                                        std::list<CtAnchoredWidget*>& widgets) const
 {
     if (not _storage) {
         spdlog::error("!! storage is not initialized");
-        return Glib::RefPtr<Gsv::Buffer>{};
+        return Glib::RefPtr<Gtk::TextBuffer>{};
     }
     return _storage->get_delayed_text_buffer(node_id, syntax, widgets);
 }
@@ -392,7 +433,8 @@ Glib::RefPtr<Gsv::Buffer> CtStorageControl::get_delayed_text_buffer(const gint64
             }
             password = dialogTextEntry.get_entry_text();
         }
-        if (0 == CtP7zaIface::p7za_extract(file_path.c_str(), temp_dir.c_str(), password.c_str(), false)) {
+        const int retVal = CtP7zaIface::p7za_extract(file_path.c_str(), temp_dir.c_str(), password.c_str(), false);
+        if (0 == retVal) {
             if (fs::is_regular_file(temp_file_path)) {
                 return temp_file_path;
             }
@@ -401,12 +443,15 @@ Glib::RefPtr<Gsv::Buffer> CtStorageControl::get_delayed_text_buffer(const gint64
                 fs::get_doc_type_from_file_ext(filesInTmpDir.front()) == fs::get_doc_type_from_file_ext(temp_file_path) and
                 fs::move_file(filesInTmpDir.front(), temp_file_path))
             {
-                spdlog::debug("encrypt doc renamed {} -> {}", filesInTmpDir.front().filename(), temp_file_path.filename());
+                spdlog::debug("encrypt doc renamed {} -> {}", filesInTmpDir.front().filename().string(), temp_file_path.filename().string());
                 return temp_file_path;
             }
         }
         else {
-            spdlog::debug("!! CtP7zaIface::p7za_extract");
+            spdlog::debug("!! CtP7zaIface::p7za_extract retVal={}", retVal);
+            if (3 == retVal) {
+                return fs::path{BAD_ARCHIVE};
+            }
         }
         password.clear();
     }
@@ -431,7 +476,7 @@ Glib::RefPtr<Gsv::Buffer> CtStorageControl::get_delayed_text_buffer(const gint64
         return false;
     }
     if (not fs::is_regular_file(file_to)) {
-        spdlog::debug("!! is_regular_file {}", file_to);
+        spdlog::debug("!! is_regular_file {}", file_to.string());
         if (not tmp_prev_archive.empty()) {
             (void)fs::move_file(tmp_prev_archive, file_to);
         }
@@ -488,14 +533,14 @@ void CtStorageControl::_backupEncryptThread()
                 // move back the latest file version
                 (void)fs::move_file(pBackupEncryptData->main_backup, pBackupEncryptData->file_path);
 #if defined(DEBUG_BACKUP_ENCRYPT)
-                spdlog::debug("{} -> {}", pBackupEncryptData->main_backup, pBackupEncryptData->file_path);
+                spdlog::debug("{} -> {}", pBackupEncryptData->main_backup, pBackupEncryptData->file_path.string());
 #endif // DEBUG_BACKUP_ENCRYPT
                 _pCtMainWin->errorsDEQueue.push_back(_("Failed to encrypt the file"));
                 _pCtMainWin->dispatcherErrorMsg.emit();
                 continue;
             }
 #if defined(DEBUG_BACKUP_ENCRYPT)
-            spdlog::debug("{} => {}", pBackupEncryptData->extracted_copy, pBackupEncryptData->file_path);
+            spdlog::debug("{} => {}", pBackupEncryptData->extracted_copy, pBackupEncryptData->file_path.string());
 #endif // DEBUG_BACKUP_ENCRYPT
         }
 
@@ -516,52 +561,20 @@ void CtStorageControl::_backupEncryptThread()
 #endif // DEBUG_BACKUP_ENCRYPT
         }
 
-        // backups with tildas can either be in the same directory where the db is or in a custom backup dir
-        // main_backup is always in the same directory of the main db
-        auto get_custom_backup_file_or_dir = [&]()->std::string {
-            // backup path in custom dir: /custom_dir/full_file_path/filename.ext~
-            std::string hash_dir = pBackupEncryptData->file_path;
-            for (auto str : {"\\", "/", ":", "?"}) {
-                hash_dir = str::replace(hash_dir, str, "_");
-            }
-            std::string new_backup_dir = Glib::build_filename(_pCtConfig->customBackupDir, hash_dir);
-            Glib::RefPtr<Gio::File> dir_file = Gio::File::create_for_path(new_backup_dir);
-            try {
-                if (not dir_file->query_exists() and not dir_file->make_directory_with_parents()) {
-                    spdlog::error("failed to create backup directory: {}", new_backup_dir);
-                    return "";
-                }
-                return Glib::build_filename(new_backup_dir, CtConst::CHAR_DOT + Glib::path_get_basename(pBackupEncryptData->file_path)) + CtConst::CHAR_TILDE;
-            }
-            catch (Glib::Error& ex) {
-                spdlog::error("failed to create backup directory: {}, \n{}", new_backup_dir, ex.what());
-                return "";
-            }
-        };
-
-        std::string new_backup_file_or_dir;
-        if (_pCtConfig->customBackupDirOn and not _pCtConfig->customBackupDir.empty()) {
-            const std::string custom_backup_file_or_dir = get_custom_backup_file_or_dir();
-            if (not custom_backup_file_or_dir.empty()) {
-                new_backup_file_or_dir = custom_backup_file_or_dir;
-            }
-        }
-        if (new_backup_file_or_dir.empty()) {
-            new_backup_file_or_dir = Glib::build_filename(Glib::path_get_dirname(pBackupEncryptData->file_path),
-                CtConst::CHAR_DOT + Glib::path_get_basename(pBackupEncryptData->file_path) + CtConst::CHAR_TILDE);
-        }
+        std::string first_backup_file_or_dir;
+        CtStorageControl::get_first_backup_file_or_dir(first_backup_file_or_dir, pBackupEncryptData->file_path, _pCtConfig);
 #if defined(DEBUG_BACKUP_ENCRYPT)
-        spdlog::debug("new_backup_file_or_dir = {}", new_backup_file_or_dir);
+        spdlog::debug("first_backup_file_or_dir = {}", first_backup_file_or_dir);
 #endif // DEBUG_BACKUP_ENCRYPT
 
         if (CtBackupType::SingleFile == pBackupEncryptData->backupType) {
             // shift backups with tilda
             if (_pCtConfig->backupNum >= 2) {
-                fs::path tilda_filepath = new_backup_file_or_dir + str::repeat(CtConst::CHAR_TILDE, _pCtConfig->backupNum - 2).raw();
+                fs::path tilda_filepath = first_backup_file_or_dir + str::repeat(CtConst::CHAR_TILDE, _pCtConfig->backupNum - 2).raw();
                 while (str::endswith(tilda_filepath.string(), CtConst::CHAR_TILDE)) {
                     if (fs::is_regular_file(tilda_filepath)) {
                         if (not fs::move_file(tilda_filepath, tilda_filepath.string() + CtConst::CHAR_TILDE)) {
-                            _pCtMainWin->errorsDEQueue.push_back(str::format(_("You Have No Write Access to %s"), fs::path{new_backup_file_or_dir}.parent_path().string()));
+                            _pCtMainWin->errorsDEQueue.push_back(str::format(_("You Have No Write Access to %s"), fs::path{first_backup_file_or_dir}.parent_path().string()));
                             _pCtMainWin->dispatcherErrorMsg.emit();
                             break;
                         }
@@ -573,13 +586,13 @@ void CtStorageControl::_backupEncryptThread()
                 }
             }
 
-            if (not fs::move_file(pBackupEncryptData->main_backup, new_backup_file_or_dir)) {
-                _pCtMainWin->errorsDEQueue.push_back(str::format(_("You Have No Write Access to %s"), fs::path{new_backup_file_or_dir}.parent_path().string()));
+            if (not fs::move_file(pBackupEncryptData->main_backup, first_backup_file_or_dir)) {
+                _pCtMainWin->errorsDEQueue.push_back(str::format(_("You Have No Write Access to %s"), fs::path{first_backup_file_or_dir}.parent_path().string()));
                 _pCtMainWin->dispatcherErrorMsg.emit();
             }
 #if defined(DEBUG_BACKUP_ENCRYPT)
             else {
-                spdlog::debug("{} -> {}", pBackupEncryptData->main_backup, new_backup_file_or_dir);
+                spdlog::debug("{} -> {}", pBackupEncryptData->main_backup, first_backup_file_or_dir);
             }
 #endif // DEBUG_BACKUP_ENCRYPT
         }
@@ -592,12 +605,12 @@ void CtStorageControl::_backupEncryptThread()
 #endif // DEBUG_BACKUP_ENCRYPT
             }
             else {
-                const fs::path new_backup_dir{new_backup_file_or_dir};
+                const fs::path first_backup_dir{first_backup_file_or_dir};
                 const std::string node_dirname = str::endswith(pBackupEncryptData->main_backup, CtStorageMultiFile::BEFORE_SAVE) ?
                     Glib::path_get_basename(Glib::path_get_dirname(pBackupEncryptData->main_backup)) : Glib::path_get_basename(pBackupEncryptData->main_backup);
                 // shift backups with tilda
                 if (_pCtConfig->backupNum >= 2) {
-                    fs::path tilda_dirpath = new_backup_file_or_dir + str::repeat(CtConst::CHAR_TILDE, _pCtConfig->backupNum - 2).raw();
+                    fs::path tilda_dirpath = first_backup_file_or_dir + str::repeat(CtConst::CHAR_TILDE, _pCtConfig->backupNum - 2).raw();
                     while (str::endswith(tilda_dirpath.string(), CtConst::CHAR_TILDE)) {
                         const fs::path tilda_node_dir_from = tilda_dirpath / node_dirname;
                         if (fs::is_directory(tilda_node_dir_from)) {
@@ -610,31 +623,31 @@ void CtStorageControl::_backupEncryptThread()
                                   g_mkdir_with_parents(tilda_dirpath_to.c_str(), 0755) < 0) or
                                   not fs::move_file(tilda_node_dir_from, tilda_node_dir_to) )
                             {
-                                _pCtMainWin->errorsDEQueue.push_back(str::format(_("You Have No Write Access to %s"), new_backup_dir.parent_path().string()));
+                                _pCtMainWin->errorsDEQueue.push_back(str::format(_("You Have No Write Access to %s"), first_backup_dir.parent_path().string()));
                                 _pCtMainWin->dispatcherErrorMsg.emit();
                                 break;
                             }
 #if defined(DEBUG_BACKUP_ENCRYPT)
-                            spdlog::debug("{} -> {}", tilda_node_dir_from, tilda_node_dir_to);
+                            spdlog::debug("{} -> {}", tilda_node_dir_from.string(), tilda_node_dir_to.string());
 #endif // DEBUG_BACKUP_ENCRYPT
                         }
                         tilda_dirpath = tilda_dirpath.string().substr(0, tilda_dirpath.string().size()-1);
                     }
                 }
-                const fs::path tilda_node_dir_to = new_backup_dir / node_dirname;
+                const fs::path tilda_node_dir_to = first_backup_dir / node_dirname;
                 if (fs::is_directory(tilda_node_dir_to)) {
                     (void)fs::remove_all(tilda_node_dir_to);
                 }
-                if ( (not fs::is_directory(new_backup_dir) and
-                      g_mkdir_with_parents(new_backup_dir.c_str(), 0755) < 0) or
+                if ( (not fs::is_directory(first_backup_dir) and
+                      g_mkdir_with_parents(first_backup_dir.c_str(), 0755) < 0) or
                       not fs::move_file(pBackupEncryptData->main_backup, tilda_node_dir_to) )
                 {
-                    _pCtMainWin->errorsDEQueue.push_back(str::format(_("You Have No Write Access to %s"), fs::path{new_backup_file_or_dir}.parent_path().string()));
+                    _pCtMainWin->errorsDEQueue.push_back(str::format(_("You Have No Write Access to %s"), fs::path{first_backup_file_or_dir}.parent_path().string()));
                     _pCtMainWin->dispatcherErrorMsg.emit();
                 }
 #if defined(DEBUG_BACKUP_ENCRYPT)
                 else {
-                    spdlog::debug("{} -> {}", pBackupEncryptData->main_backup, tilda_node_dir_to);
+                    spdlog::debug("{} -> {}", pBackupEncryptData->main_backup, tilda_node_dir_to.string());
                 }
 #endif // DEBUG_BACKUP_ENCRYPT
             }
@@ -716,12 +729,12 @@ void CtStorageControl::add_nodes_from_storage(const fs::path& file_path,
 {
     if (is_folder) {
         if (not fs::is_directory(file_path)) {
-            throw std::runtime_error(fmt::format("{} not a dir", file_path));
+            throw std::runtime_error(fmt::format("{} not a dir", file_path.string()));
         }
     }
     else {
         if (not fs::is_regular_file(file_path)) {
-            throw std::runtime_error(fmt::format("{} not a file", file_path));
+            throw std::runtime_error(fmt::format("{} not a file", file_path.string()));
         }
     }
 
@@ -733,6 +746,9 @@ void CtStorageControl::add_nodes_from_storage(const fs::path& file_path,
             // user canceled operation
             return;
         }
+        if (extracted_file_path.string() == BAD_ARCHIVE) {
+            throw std::runtime_error(str::format(_("'%s' is Not a Valid Archive"), file_path.string()));
+        }
     }
 
     std::unique_ptr<CtStorageEntity> pStorage;
@@ -760,9 +776,9 @@ void CtStorageCache::generate_cache(CtMainWin* pCtMainWin, const CtStorageSyncPe
         std::string error;
         store.get_store()->foreach([&](const Gtk::TreePath&, const Gtk::TreeIter& iter)->bool{
             CtTreeIter ct_tree_iter = store.to_ct_tree_iter(iter);
-            Glib::RefPtr<Gsv::Buffer> rTextBuffer = ct_tree_iter.get_node_text_buffer();
+            Glib::RefPtr<Gtk::TextBuffer> rTextBuffer = ct_tree_iter.get_node_text_buffer();
             if (not rTextBuffer) {
-                error = str::format(_("Failed to retrieve the content of the node '%s'"), ct_tree_iter.get_node_name());
+                error = str::format(_("Failed to retrieve the content of the node '%s'"), ct_tree_iter.get_node_name().raw());
                 return true; /* true for stop */
             }
             for (auto widget : ct_tree_iter.get_anchored_widgets_fast())
@@ -777,9 +793,9 @@ void CtStorageCache::generate_cache(CtMainWin* pCtMainWin, const CtStorageSyncPe
         for (const auto& node_pair : pending->nodes_to_write_dict) {
             CtTreeIter ct_tree_iter = store.get_node_from_node_id(node_pair.first);
             if (node_pair.second.buff && ct_tree_iter.get_node_is_rich_text()) {
-                Glib::RefPtr<Gsv::Buffer> rTextBuffer = ct_tree_iter.get_node_text_buffer();
+                Glib::RefPtr<Gtk::TextBuffer> rTextBuffer = ct_tree_iter.get_node_text_buffer();
                 if (not rTextBuffer) {
-                    throw std::runtime_error(str::format(_("Failed to retrieve the content of the node '%s'"), ct_tree_iter.get_node_name()));
+                    throw std::runtime_error(str::format(_("Failed to retrieve the content of the node '%s'"), ct_tree_iter.get_node_name().raw()));
                 }
                 for (auto widget : ct_tree_iter.get_anchored_widgets_fast())
                     if (widget->get_type() == CtAnchWidgType::ImagePng) // important to check type
