@@ -49,6 +49,9 @@ public:
     static bool document_integrity_check_pass(CtMainWin* pCtMainWin,
                                               const fs::path& file_path,
                                               Glib::ustring& error);
+    static void get_first_backup_file_or_dir(std::string& out_first_backup_file_or_dir,
+                                             const std::string& file_or_dir_path,
+                                             const CtConfig* pCtConfig);
 
     static std::list<std::pair<CtTreeIter, CtStorageNodeState>> get_sorted_by_level_nodes_to_write(
         CtTreeStore* pCtTreeStore,
@@ -60,9 +63,9 @@ public:
 
     bool save(bool need_vacuum, Glib::ustring& error);
     bool try_reopen(Glib::ustring& error);
-    Glib::RefPtr<Gsv::Buffer> get_delayed_text_buffer(const gint64 node_id,
-                                                      const std::string& syntax,
-                                                      std::list<CtAnchoredWidget*>& widgets) const;
+    Glib::RefPtr<Gtk::TextBuffer> get_delayed_text_buffer(const gint64 node_id,
+                                                          const std::string& syntax,
+                                                          std::list<CtAnchoredWidget*>& widgets) const;
 
     const fs::path& get_file_path() { return _file_path; }
     time_t get_mod_time() { return _mod_time; }
