@@ -108,8 +108,8 @@ const char CtStorageSqlite::TABLE_BOOKMARK_CREATE[]{"CREATE TABLE bookmark ("
 const char CtStorageSqlite::TABLE_BOOKMARK_INSERT[]{"INSERT INTO bookmark VALUES(?,?)"};
 const char CtStorageSqlite::TABLE_BOOKMARK_DELETE[]{"DELETE FROM bookmark"};
 
-const Glib::ustring CtStorageSqlite::ERR_SQLITE_PREPV2{"!! sqlite3_prepare_v2: "};
-const Glib::ustring CtStorageSqlite::ERR_SQLITE_STEP{"!! sqlite3_step: "};
+/*static*/const std::string CtStorageSqlite::ERR_SQLITE_PREPV2{"!! sqlite3_prepare_v2: "};
+/*static*/const std::string CtStorageSqlite::ERR_SQLITE_STEP{"!! sqlite3_step: "};
 
 class Sqlite3StmtAuto
 {
@@ -158,9 +158,7 @@ bool CtStorageSqlite::_check_database_integrity()
     }
     spdlog::error(log_msg);
 
-    const auto error_msg = _("The database file %s is corrupt, see log for more details.") + std::string{"\n\n"} +
-        _("Backup files are by default 3 in the same folder of the corrupted document, with the same name plus trailing tildes (~, ~~, ~~~). Try first the backup with one tilde: copy the file to another directory, remove the trailing tilde and open with cherrytree. If it still fails, try the one with two tildes and if it still fails try the one with three tildes.");
-    spdlog::error(error_msg);
+    const auto error_msg = _("The database file %s is corrupt, see log for more details.");
 
     CtDialogs::error_dialog(str::format(error_msg, str::xml_escape(_file_path.string())), *_pCtMainWin);
     return false;
@@ -209,10 +207,10 @@ void CtStorageSqlite::test_connection()
     }
     catch(std::exception& e) {
         spdlog::debug("{} {}", __FUNCTION__, e.what());
-        throw std::runtime_error(str::format(_("%s write failed - file is missing. Reattach USB drive or shared resource!"), _file_path));
+        throw std::runtime_error(str::format(_("%s write failed - file is missing. Reattach USB drive or shared resource."), _file_path.string()));
     }
     if (not test_readwrite())
-        throw std::runtime_error(str::format(_("%s write failed - is file blocked by a sync program?"), _file_path));
+        throw std::runtime_error(str::format(_("%s write failed - is file blocked by a sync program?"), _file_path.string()));
     (void)_check_database_integrity();
 }
 
@@ -225,7 +223,7 @@ void CtStorageSqlite::try_reopen()
     }
     catch(std::exception& e) {
         spdlog::debug("{} {}", __FUNCTION__, e.what());
-        throw std::runtime_error(str::format(_("%s reopen failed - file is missing. Reattach USB drive or shared resource!"), _file_path));
+        throw std::runtime_error(str::format(_("%s reopen failed - file is missing. Reattach USB drive or shared resource."), _file_path.string()));
     }
     (void)_check_database_integrity();
 }
@@ -479,23 +477,23 @@ Gtk::TreeIter CtStorageSqlite::_node_from_db(const gint64 node_id,
     return _pCtMainWin->get_tree_store().append_node(&nodeData, &parent_iter);
 }
 
-Glib::RefPtr<Gsv::Buffer> CtStorageSqlite::get_delayed_text_buffer(const gint64 node_id,
-                                                                   const std::string& syntax,
-                                                                   std::list<CtAnchoredWidget*>& widgets) const
+Glib::RefPtr<Gtk::TextBuffer> CtStorageSqlite::get_delayed_text_buffer(const gint64 node_id,
+                                                                       const std::string& syntax,
+                                                                       std::list<CtAnchoredWidget*>& widgets) const
 {
     Sqlite3StmtAuto stmt{_pDb, "SELECT txt, has_codebox, has_table, has_image FROM node WHERE node_id=?"};
     if (stmt.is_bad()) {
         spdlog::error("{}: {}", ERR_SQLITE_PREPV2, sqlite3_errmsg(_pDb));
-        return Glib::RefPtr<Gsv::Buffer>();
+        return Glib::RefPtr<Gtk::TextBuffer>{};
     }
 
     sqlite3_bind_int64(stmt, 1, node_id);
     if (sqlite3_step(stmt) != SQLITE_ROW) {
         spdlog::error("!! missing node properties for id {}", node_id);
-        return Glib::RefPtr<Gsv::Buffer>();
+        return Glib::RefPtr<Gtk::TextBuffer>{};
     }
 
-    Glib::RefPtr<Gsv::Buffer> rRetTextBuffer;
+    Glib::RefPtr<Gtk::TextBuffer> rRetTextBuffer;
     const char* textContent = safe_sqlite3_column_text(stmt, 0);
     if (CtConst::RICH_TEXT_ID != syntax) {
         rRetTextBuffer = _pCtMainWin->get_new_text_buffer(textContent);
@@ -511,11 +509,12 @@ Glib::RefPtr<Gsv::Buffer> CtStorageSqlite::get_delayed_text_buffer(const gint64
         if (sqlite3_column_int64(stmt, 3)) _image_from_db(node_id, widgets);
 
         widgets.sort([](const CtAnchoredWidget* w1, const CtAnchoredWidget* w2) { return w1->getOffset() < w2->getOffset(); });
-        rRetTextBuffer->begin_not_undoable_action();
+        auto pGtkSourceBuffer = GTK_SOURCE_BUFFER(rRetTextBuffer->gobj());
+        gtk_source_buffer_begin_not_undoable_action(pGtkSourceBuffer);
         for (auto widget : widgets) {
             widget->insertInTextBuffer(rRetTextBuffer);
         }
-        rRetTextBuffer->end_not_undoable_action();
+        gtk_source_buffer_end_not_undoable_action(pGtkSourceBuffer);
         rRetTextBuffer->set_modified(false);
     }
     return rRetTextBuffer;
@@ -538,7 +537,13 @@ void CtStorageSqlite::_image_from_db(const gint64& nodeId, std::list<CtAnchoredW
         // image
         const Glib::ustring anchorName = safe_sqlite3_column_text(stmt, 3);
         if (not anchorName.empty()) {
-            anchoredWidgets.push_back(new CtImageAnchor{_pCtMainWin, anchorName, charOffset, justification});
+            CtAnchorExpCollState expCollState{CtAnchorExpCollState::None};
+            if (0 != CtStrUtil::is_header_anchor_name(anchorName)) {
+                const Glib::ustring link = safe_sqlite3_column_text(stmt, 6); // link field used in anchors for else
+                if (strstr(link.c_str(), "state:coll")) expCollState = CtAnchorExpCollState::Collapsed;
+                else expCollState = CtAnchorExpCollState::Expanded;
+            }
+            anchoredWidgets.push_back(new CtImageAnchor{_pCtMainWin, anchorName, expCollState, charOffset, justification});
         }
         else {
             fs::path fileName = safe_sqlite3_column_text(stmt, 5);
