@@ -1,7 +1,7 @@
 /*
  * ct_text_view.h
  *
- * Copyright 2009-2023
+ * Copyright 2009-2024
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -26,23 +26,31 @@
 #include "ct_types.h"
 #include "ct_column_edit.h"
 
-#include <gtksourceviewmm.h>
+#include <gtkmm/textview.h>
 #include <gspell/gspell.h>
 #include <memory>
 #include <unordered_map>
 
 class CtMainWin;
+class CtStatusBar;
 
-class CtTextView : public Gsv::View
+class CtTextView
 {
 public:
     CtTextView(CtMainWin* pCtMainWin);
+    virtual ~CtTextView();
+
+    GtkSourceView* gobj() { return _pGtkSourceView; }
+    Gtk::TextView& mm() { return *_pTextView; }
+    const Gtk::TextView& mm() const { return *_pTextView; }
+    Glib::RefPtr<Gtk::TextBuffer> get_buffer() { return _pTextView->get_buffer(); }
+    Glib::RefPtr<const Gtk::TextBuffer> get_buffer() const { return _pTextView->get_buffer(); }
 
     void setup_for_syntax(const std::string& syntaxHighlighting); // pygtk: sourceview_set_properties
     void set_pixels_inside_wrap(int space_around_lines, int relative_wrapped_space);
-    void set_selection_at_offset_n_delta(int offset,
-                                         int delta,
-                                         Glib::RefPtr<Gtk::TextBuffer> text_buffer = Glib::RefPtr<Gtk::TextBuffer>{});
+    void set_selection_at_offset_n_delta(const int offset,
+                                         const int delta,
+                                         Glib::RefPtr<Gtk::TextBuffer> pTextBuffer = Glib::RefPtr<Gtk::TextBuffer>{});
     void list_change_level(Gtk::TextIter iter_insert, const CtListInfo& list_info, bool level_increase);
     void replace_text(const Glib::ustring& text, int start_offset, int end_offset);
 
@@ -53,7 +61,7 @@ public:
 
     void cursor_and_tooltips_handler(int x, int y);
     void cursor_and_tooltips_reset();
-    void zoom_text(const bool is_increase, const std::string& syntaxHighlighting);
+    void zoom_text(const std::optional<bool> is_increase, const std::string& syntaxHighlighting);
     void set_spell_check(bool allow_on);
     void synch_spell_check_change_from_gspell_right_click_menu();
 
@@ -99,12 +107,12 @@ private:
     void          _special_char_replace(Glib::ustring special_char, Gtk::TextIter iter_start, Gtk::TextIter iter_end);
     void          _set_highlight_current_line_enabled(const bool enabled);
 
-    void on_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context,
-                               int x,
-                               int y,
-                               const Gtk::SelectionData& selection_data,
-                               guint info,
-                               guint time) override;
+    void _on_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context,
+                                int x,
+                                int y,
+                                const Gtk::SelectionData& selection_data,
+                                guint info,
+                                guint time);
 
 #ifdef MD_AUTO_REPLACEMENT
     bool          _markdown_filter_active();
@@ -123,6 +131,9 @@ private:
 #endif // MD_AUTO_REPLACEMENT
     CtMainWin* const _pCtMainWin;
     CtConfig* const _pCtConfig;
+    CtStatusBar* const _pCtStatusBar;
+    GtkSourceView* const _pGtkSourceView;
+    Gtk::TextView* _pTextView;
     CtColumnEdit _columnEdit;
     guint32      _todoRotateTime{0};
     std::string  _syntaxHighlighting;
