@@ -33,7 +33,7 @@
 #include <condition_variable>
 #include <type_traits>
 #include <glibmm/ustring.h>
-#include <gtksourceviewmm/buffer.h>
+#include <gtkmm/textbuffer.h>
 #include "ct_const.h"
 
 namespace fs {
@@ -48,6 +48,8 @@ enum class CtDocEncrypt { None, True, False };
 
 enum class CtAnchWidgType { None, CodeBox, TableHeavy, TableLight, ImagePng, ImageAnchor, ImageLatex, ImageEmbFile };
 
+enum class CtAnchorExpCollState { None, Expanded, Collapsed };
+
 enum class CtPixTabCBox { Pixbuf, Table, CodeBox };
 
 enum class CtSaveNeededUpdType { None, nbuf, npro, ndel, book };
@@ -246,8 +248,8 @@ public:
     template<typename T>
     bool contains(const T& item) const { return std::find(_internal_vec.begin(), _internal_vec.end(), item) != _internal_vec.end(); }
 
-    typename vect_t::const_iterator end() const noexcept { return _internal_vec.end(); }
-    typename vect_t::const_iterator begin() const noexcept { return _internal_vec.begin(); }
+    typename vect_t::const_iterator end() const { return _internal_vec.end(); }
+    typename vect_t::const_iterator begin() const { return _internal_vec.begin(); }
 
     const Glib::ustring& item() const { return _string_cache; }
 
@@ -308,9 +310,9 @@ public:
     virtual void vacuum() = 0;
     virtual void import_nodes(const fs::path& path, const Gtk::TreeIter& parent_iter) = 0;
 
-    virtual Glib::RefPtr<Gsv::Buffer> get_delayed_text_buffer(const gint64 node_id,
-                                                              const std::string& syntax,
-                                                              std::list<CtAnchoredWidget*>& widgets) const = 0;
+    virtual Glib::RefPtr<Gtk::TextBuffer> get_delayed_text_buffer(const gint64 node_id,
+                                                                  const std::string& syntax,
+                                                                  std::list<CtAnchoredWidget*>& widgets) const = 0;
 
     void set_is_dry_run() { _isDryRun = true; }
 
