@@ -48,11 +48,24 @@ TEST(MiscUtilsGroup, convert_if_not_utf8)
         CtStrUtil::convert_if_not_utf8(ioString, true/*sanitise*/);
         return ioString;
     };
-    ASSERT_STREQ("Привет\n", _get_file_converted(UT::testBomUtf8Path).c_str());
+    Glib::ustring utf8_text;
+    {
+        ASSERT_STREQ("Привет\n", _get_file_converted(UT::testBomUtf8Path).c_str());
+        ASSERT_TRUE(CtStrUtil::file_any_encoding_to_utf8(UT::testBomUtf8Path, utf8_text));
+        ASSERT_STREQ("Привет", utf8_text.c_str());
+    }
     ASSERT_STREQ("Привет\n", _get_file_converted(UT::testBomUtf32BEPath).c_str());
     ASSERT_STREQ("Привет\n", _get_file_converted(UT::testBomUtf32LEPath).c_str());
-    ASSERT_STREQ("Привет\n", _get_file_converted(UT::testBomUtf16BEPath).c_str());
-    ASSERT_STREQ("Привет\n", _get_file_converted(UT::testBomUtf16LEPath).c_str());
+    {
+        ASSERT_STREQ("Привет\n", _get_file_converted(UT::testBomUtf16BEPath).c_str());
+        ASSERT_TRUE(CtStrUtil::file_any_encoding_to_utf8(UT::testBomUtf16BEPath, utf8_text));
+        ASSERT_STREQ("Привет", utf8_text.c_str());
+    }
+    {
+        ASSERT_STREQ("Привет\n", _get_file_converted(UT::testBomUtf16LEPath).c_str());
+        ASSERT_TRUE(CtStrUtil::file_any_encoding_to_utf8(UT::testBomUtf16LEPath, utf8_text));
+        ASSERT_STREQ("Привет", utf8_text.c_str());
+    }
 }
 
 TEST(MiscUtilsGroup, is_str_true)
@@ -67,6 +80,21 @@ TEST(MiscUtilsGroup, is_str_true)
     ASSERT_TRUE(not CtStrUtil::is_str_true("0"));
 }
 
+TEST(MiscUtilsGroup, is_header_anchor_name)
+{
+    ASSERT_EQ(0, CtStrUtil::is_header_anchor_name("ciao"));
+    ASSERT_EQ(0, CtStrUtil::is_header_anchor_name("h0-2"));
+    ASSERT_EQ(0, CtStrUtil::is_header_anchor_name("h7-10"));
+    ASSERT_EQ(0, CtStrUtil::is_header_anchor_name("h710"));
+    ASSERT_EQ(0, CtStrUtil::is_header_anchor_name("h-710"));
+    ASSERT_EQ(1, CtStrUtil::is_header_anchor_name("h1-1"));
+    ASSERT_EQ(2, CtStrUtil::is_header_anchor_name("h2-10"));
+    ASSERT_EQ(3, CtStrUtil::is_header_anchor_name("h3-20"));
+    ASSERT_EQ(4, CtStrUtil::is_header_anchor_name("h4-30"));
+    ASSERT_EQ(5, CtStrUtil::is_header_anchor_name("h5-40"));
+    ASSERT_EQ(6, CtStrUtil::is_header_anchor_name("h6-50"));
+}
+
 TEST(MiscUtilsGroup, str__replace)
 {
     {
@@ -138,26 +166,92 @@ TEST(MiscUtilsGroup, gstring_split_to_int64)
 TEST(MiscUtilsGroup, iter_util__startswith)
 {
     Glib::init();
-    auto buffer = Gsv::Buffer::create();
-    buffer->set_text("Saitama さいたま市");
-    ASSERT_TRUE(CtTextIterUtil::startswith(buffer->begin(), "Sai"));
-    ASSERT_TRUE(not CtTextIterUtil::startswith(buffer->begin(), "さ"));
-    buffer->set_text("さいたま市 Saitama");
-    ASSERT_TRUE(CtTextIterUtil::startswith(buffer->begin(), "さ"));
-    ASSERT_TRUE(not CtTextIterUtil::startswith(buffer->begin(), "Sai"));
+    // I'm struggling to Glib::wrap the GtkSourceBuffer from here, this is otherwise incorrect and should
+    // never be used in application code as all text buffers must be source buffers
+    Glib::RefPtr<Gtk::TextBuffer> pTextBuffer = Gtk::TextBuffer::create();
+    pTextBuffer->set_text("Saitama さいたま市");
+    ASSERT_TRUE(CtTextIterUtil::startswith(pTextBuffer->begin(), "Sai"));
+    ASSERT_TRUE(not CtTextIterUtil::startswith(pTextBuffer->begin(), "さ"));
+    pTextBuffer->set_text("さいたま市 Saitama");
+    ASSERT_TRUE(CtTextIterUtil::startswith(pTextBuffer->begin(), "さ"));
+    ASSERT_TRUE(not CtTextIterUtil::startswith(pTextBuffer->begin(), "Sai"));
 }
 
 TEST(MiscUtilsGroup, iter_util__startswith_any)
 {
     Glib::init();
-    auto buffer = Gsv::Buffer::create();
-    buffer->set_text("Saitama さいたま市");
+    // I'm struggling to Glib::wrap the GtkSourceBuffer from here, this is otherwise incorrect and should
+    // never be used in application code as all text buffers must be source buffers
+    Glib::RefPtr<Gtk::TextBuffer> pTextBuffer = Gtk::TextBuffer::create();
+    pTextBuffer->set_text("Saitama さいたま市");
 
-    ASSERT_TRUE(CtTextIterUtil::startswith_any(buffer->begin(), std::array<const gchar*, 3>{"M", "Sai", "さ"}));
-    ASSERT_TRUE(not CtTextIterUtil::startswith_any(buffer->begin(), std::array<const gchar*, 3>{"M", "21", "さ"}));
-    buffer->set_text("さいたま市 Saitama");
-    ASSERT_TRUE(CtTextIterUtil::startswith_any(buffer->begin(), std::array<const gchar*, 3>{"M", "Sai", "さ"}));
-    ASSERT_TRUE(not CtTextIterUtil::startswith_any(buffer->begin(), std::array<const gchar*, 3>{"M", "Sai", "123"}));
+    ASSERT_TRUE(CtTextIterUtil::startswith_any(pTextBuffer->begin(), std::array<const gchar*, 3>{"M", "Sai", "さ"}));
+    ASSERT_TRUE(not CtTextIterUtil::startswith_any(pTextBuffer->begin(), std::array<const gchar*, 3>{"M", "21", "さ"}));
+    pTextBuffer->set_text("さいたま市 Saitama");
+    ASSERT_TRUE(CtTextIterUtil::startswith_any(pTextBuffer->begin(), std::array<const gchar*, 3>{"M", "Sai", "さ"}));
+    ASSERT_TRUE(not CtTextIterUtil::startswith_any(pTextBuffer->begin(), std::array<const gchar*, 3>{"M", "Sai", "123"}));
+}
+
+TEST(MiscUtilsGroup, iter_util__startswith_url)
+{
+    Glib::init();
+    // I'm struggling to Glib::wrap the GtkSourceBuffer from here, this is otherwise incorrect and should
+    // never be used in application code as all text buffers must be source buffers
+    Glib::RefPtr<Gtk::TextBuffer> pTextBuffer = Gtk::TextBuffer::create();
+    {
+        Glib::ustring curr_text{"http://ciao"};
+        pTextBuffer->set_text(curr_text);
+        ASSERT_TRUE(CtTextIterUtil::startswith_url(pTextBuffer->begin()));
+        ASSERT_TRUE(str::startswith_url(curr_text.c_str()));
+    }
+    {
+        Glib::ustring curr_text{"https://ciao"};
+        pTextBuffer->set_text(curr_text);
+        ASSERT_TRUE(CtTextIterUtil::startswith_url(pTextBuffer->begin()));
+        ASSERT_TRUE(str::startswith_url(curr_text.c_str()));
+    }
+    {
+        Glib::ustring curr_text{"ftp://ciao"};
+        pTextBuffer->set_text(curr_text);
+        ASSERT_TRUE(CtTextIterUtil::startswith_url(pTextBuffer->begin()));
+        ASSERT_TRUE(str::startswith_url(curr_text.c_str()));
+    }
+    {
+        Glib::ustring curr_text{"ciaociao"};
+        pTextBuffer->set_text(curr_text);
+        ASSERT_FALSE(CtTextIterUtil::startswith_url(pTextBuffer->begin()));
+        ASSERT_FALSE(str::startswith_url(curr_text.c_str()));
+    }
+    {
+        Glib::ustring curr_text{"ciao:ciao"};
+        pTextBuffer->set_text(curr_text);
+        ASSERT_FALSE(CtTextIterUtil::startswith_url(pTextBuffer->begin()));
+        ASSERT_FALSE(str::startswith_url(curr_text.c_str()));
+    }
+    {
+        Glib::ustring curr_text{"ciao/ciao"};
+        pTextBuffer->set_text(curr_text);
+        ASSERT_FALSE(CtTextIterUtil::startswith_url(pTextBuffer->begin()));
+        ASSERT_FALSE(str::startswith_url(curr_text.c_str()));
+    }
+    {
+        Glib::ustring curr_text{"ciao:/ciao"};
+        pTextBuffer->set_text(curr_text);
+        ASSERT_FALSE(CtTextIterUtil::startswith_url(pTextBuffer->begin()));
+        ASSERT_FALSE(str::startswith_url(curr_text.c_str()));
+    }
+    {
+        Glib::ustring curr_text{"ciao/:ciao"};
+        pTextBuffer->set_text(curr_text);
+        ASSERT_FALSE(CtTextIterUtil::startswith_url(pTextBuffer->begin()));
+        ASSERT_FALSE(str::startswith_url(curr_text.c_str()));
+    }
+    {
+        Glib::ustring curr_text{"ciao\nciao://ciao"};
+        pTextBuffer->set_text(curr_text);
+        ASSERT_FALSE(CtTextIterUtil::startswith_url(pTextBuffer->begin()));
+        ASSERT_FALSE(str::startswith_url(curr_text.c_str()));
+    }
 }
 
 TEST(MiscUtilsGroup, contains)
@@ -494,6 +588,9 @@ TEST(MiscUtilsGroup, get_link_entry)
 
 TEST(MiscUtilsGroup, get_is_camel_case)
 {
+    Glib::init();
+    // I'm struggling to Glib::wrap the GtkSourceBuffer from here, this is otherwise incorrect and should
+    // never be used in application code as all text buffers must be source buffers
     Glib::RefPtr<Gtk::TextBuffer> pTextBuffer = Gtk::TextBuffer::create();
     {
         const std::string notcamelcase{"notcamelcase"};
